@@ -21,7 +21,6 @@
  */
 
 #include <ccode/valaccodecastexpression.h>
-#include <ccode/valaccodenode.h>
 
 
 
@@ -36,6 +35,7 @@ enum  {
 	VALA_CCODE_CAST_EXPRESSION_DUMMY_PROPERTY
 };
 static void vala_ccode_cast_expression_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
+static void vala_ccode_cast_expression_real_write_inner (ValaCCodeExpression* base, ValaCCodeWriter* writer);
 static gpointer vala_ccode_cast_expression_parent_class = NULL;
 static void vala_ccode_cast_expression_finalize (ValaCCodeNode* obj);
 
@@ -45,7 +45,7 @@ ValaCCodeCastExpression* vala_ccode_cast_expression_construct (GType object_type
 	ValaCCodeCastExpression* self;
 	g_return_val_if_fail (expr != NULL, NULL);
 	g_return_val_if_fail (type != NULL, NULL);
-	self = ((ValaCCodeCastExpression*) (g_type_create_instance (object_type)));
+	self = (ValaCCodeCastExpression*) g_type_create_instance (object_type);
 	vala_ccode_cast_expression_set_inner (self, expr);
 	vala_ccode_cast_expression_set_type_name (self, type);
 	return self;
@@ -59,14 +59,22 @@ ValaCCodeCastExpression* vala_ccode_cast_expression_new (ValaCCodeExpression* ex
 
 static void vala_ccode_cast_expression_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeCastExpression * self;
-	self = ((ValaCCodeCastExpression*) (base));
+	self = (ValaCCodeCastExpression*) base;
 	g_return_if_fail (writer != NULL);
-	vala_ccode_writer_write_string (writer, "((");
+	vala_ccode_writer_write_string (writer, "(");
 	vala_ccode_writer_write_string (writer, self->priv->_type_name);
 	vala_ccode_writer_write_string (writer, ") ");
+	vala_ccode_expression_write_inner (self->priv->_inner, writer);
+}
+
+
+static void vala_ccode_cast_expression_real_write_inner (ValaCCodeExpression* base, ValaCCodeWriter* writer) {
+	ValaCCodeCastExpression * self;
+	self = (ValaCCodeCastExpression*) base;
+	g_return_if_fail (writer != NULL);
 	vala_ccode_writer_write_string (writer, "(");
-	vala_ccode_node_write (((ValaCCodeNode*) (self->priv->_inner)), writer);
-	vala_ccode_writer_write_string (writer, "))");
+	vala_ccode_node_write ((ValaCCodeNode*) self, writer);
+	vala_ccode_writer_write_string (writer, ")");
 }
 
 
@@ -82,7 +90,7 @@ void vala_ccode_cast_expression_set_inner (ValaCCodeCastExpression* self, ValaCC
 	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_inner = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_ccode_node_ref (_tmp1))), (self->priv->_inner == NULL ? NULL : (self->priv->_inner = (vala_ccode_node_unref (self->priv->_inner), NULL))), _tmp2);
+	self->priv->_inner = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : vala_ccode_node_ref (_tmp1)), (self->priv->_inner == NULL) ? NULL : (self->priv->_inner = (vala_ccode_node_unref (self->priv->_inner), NULL)), _tmp2);
 }
 
 
@@ -98,7 +106,7 @@ void vala_ccode_cast_expression_set_type_name (ValaCCodeCastExpression* self, co
 	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_type_name = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_type_name = (g_free (self->priv->_type_name), NULL)), _tmp2);
+	self->priv->_type_name = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : g_strdup (_tmp1)), self->priv->_type_name = (g_free (self->priv->_type_name), NULL), _tmp2);
 }
 
 
@@ -107,6 +115,7 @@ static void vala_ccode_cast_expression_class_init (ValaCCodeCastExpressionClass
 	VALA_CCODE_NODE_CLASS (klass)->finalize = vala_ccode_cast_expression_finalize;
 	g_type_class_add_private (klass, sizeof (ValaCCodeCastExpressionPrivate));
 	VALA_CCODE_NODE_CLASS (klass)->write = vala_ccode_cast_expression_real_write;
+	VALA_CCODE_EXPRESSION_CLASS (klass)->write_inner = vala_ccode_cast_expression_real_write_inner;
 }
 
 
@@ -118,7 +127,7 @@ static void vala_ccode_cast_expression_instance_init (ValaCCodeCastExpression *
 static void vala_ccode_cast_expression_finalize (ValaCCodeNode* obj) {
 	ValaCCodeCastExpression * self;
 	self = VALA_CCODE_CAST_EXPRESSION (obj);
-	(self->priv->_inner == NULL ? NULL : (self->priv->_inner = (vala_ccode_node_unref (self->priv->_inner), NULL)));
+	(self->priv->_inner == NULL) ? NULL : (self->priv->_inner = (vala_ccode_node_unref (self->priv->_inner), NULL));
 	self->priv->_type_name = (g_free (self->priv->_type_name), NULL);
 	VALA_CCODE_NODE_CLASS (vala_ccode_cast_expression_parent_class)->finalize (obj);
 }
