@@ -73,11 +73,11 @@ static void vala_ccode_comma_expression_real_write (ValaCCodeNode* base, ValaCCo
 	first = TRUE;
 	vala_ccode_writer_write_string (writer, "(");
 	{
-		GeeIterator* expr_it;
-		expr_it = gee_iterable_iterator ((GeeIterable*) self->priv->inner);
-		while (gee_iterator_next (expr_it)) {
+		GeeIterator* _expr_it;
+		_expr_it = gee_iterable_iterator ((GeeIterable*) self->priv->inner);
+		while (gee_iterator_next (_expr_it)) {
 			ValaCCodeExpression* expr;
-			expr = (ValaCCodeExpression*) gee_iterator_get (expr_it);
+			expr = (ValaCCodeExpression*) gee_iterator_get (_expr_it);
 			if (!first) {
 				vala_ccode_writer_write_string (writer, ", ");
 			} else {
@@ -86,7 +86,7 @@ static void vala_ccode_comma_expression_real_write (ValaCCodeNode* base, ValaCCo
 			vala_ccode_node_write ((ValaCCodeNode*) expr, writer);
 			(expr == NULL) ? NULL : (expr = (vala_ccode_node_unref (expr), NULL));
 		}
-		(expr_it == NULL) ? NULL : (expr_it = (gee_collection_object_unref (expr_it), NULL));
+		(_expr_it == NULL) ? NULL : (_expr_it = (gee_collection_object_unref (_expr_it), NULL));
 	}
 	vala_ccode_writer_write_string (writer, ")");
 }
