@@ -78,17 +78,17 @@ static void vala_ccode_expression_statement_real_write (ValaCCodeNode* base, Val
 		{
 			GeeList* _tmp2;
 			GeeIterator* _tmp3;
-			GeeIterator* expr_it;
+			GeeIterator* _expr_it;
 			_tmp2 = NULL;
 			_tmp3 = NULL;
-			expr_it = (_tmp3 = gee_iterable_iterator ((GeeIterable*) (_tmp2 = vala_ccode_comma_expression_get_inner (ccomma))), (_tmp2 == NULL) ? NULL : (_tmp2 = (gee_collection_object_unref (_tmp2), NULL)), _tmp3);
-			while (gee_iterator_next (expr_it)) {
+			_expr_it = (_tmp3 = gee_iterable_iterator ((GeeIterable*) (_tmp2 = vala_ccode_comma_expression_get_inner (ccomma))), (_tmp2 == NULL) ? NULL : (_tmp2 = (gee_collection_object_unref (_tmp2), NULL)), _tmp3);
+			while (gee_iterator_next (_expr_it)) {
 				ValaCCodeExpression* expr;
-				expr = (ValaCCodeExpression*) gee_iterator_get (expr_it);
+				expr = (ValaCCodeExpression*) gee_iterator_get (_expr_it);
 				vala_ccode_expression_statement_write_expression (self, writer, expr);
 				(expr == NULL) ? NULL : (expr = (vala_ccode_node_unref (expr), NULL));
 			}
-			(expr_it == NULL) ? NULL : (expr_it = (gee_collection_object_unref (expr_it), NULL));
+			(_expr_it == NULL) ? NULL : (_expr_it = (gee_collection_object_unref (_expr_it), NULL));
 		}
 		(ccomma == NULL) ? NULL : (ccomma = (vala_ccode_node_unref (ccomma), NULL));
 	} else {
