@@ -100,11 +100,11 @@ static void vala_ccode_function_call_real_write (ValaCCodeNode* base, ValaCCodeW
 	vala_ccode_writer_write_string (writer, " (");
 	first = TRUE;
 	{
-		GeeIterator* expr_it;
-		expr_it = gee_iterable_iterator ((GeeIterable*) self->priv->arguments);
-		while (gee_iterator_next (expr_it)) {
+		GeeIterator* _expr_it;
+		_expr_it = gee_iterable_iterator ((GeeIterable*) self->priv->arguments);
+		while (gee_iterator_next (_expr_it)) {
 			ValaCCodeExpression* expr;
-			expr = (ValaCCodeExpression*) gee_iterator_get (expr_it);
+			expr = (ValaCCodeExpression*) gee_iterator_get (_expr_it);
 			if (!first) {
 				vala_ccode_writer_write_string (writer, ", ");
 			} else {
@@ -115,7 +115,7 @@ static void vala_ccode_function_call_real_write (ValaCCodeNode* base, ValaCCodeW
 			}
 			(expr == NULL) ? NULL : (expr = (vala_ccode_node_unref (expr), NULL));
 		}
-		(expr_it == NULL) ? NULL : (expr_it = (gee_collection_object_unref (expr_it), NULL));
+		(_expr_it == NULL) ? NULL : (_expr_it = (gee_collection_object_unref (_expr_it), NULL));
 	}
 	vala_ccode_writer_write_string (writer, ")");
 }
