@@ -44,7 +44,7 @@ static void vala_ccode_include_directive_finalize (ValaCCodeNode* obj);
 ValaCCodeIncludeDirective* vala_ccode_include_directive_construct (GType object_type, const char* _filename, gboolean _local) {
 	ValaCCodeIncludeDirective* self;
 	g_return_val_if_fail (_filename != NULL, NULL);
-	self = ((ValaCCodeIncludeDirective*) (g_type_create_instance (object_type)));
+	self = (ValaCCodeIncludeDirective*) g_type_create_instance (object_type);
 	vala_ccode_include_directive_set_filename (self, _filename);
 	vala_ccode_include_directive_set_local (self, _local);
 	return self;
@@ -58,8 +58,8 @@ ValaCCodeIncludeDirective* vala_ccode_include_directive_new (const char* _filena
 
 static void vala_ccode_include_directive_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeIncludeDirective * self;
-	self = VALA_CCODE_INCLUDE_DIRECTIVE (base);
-	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
+	self = (ValaCCodeIncludeDirective*) base;
+	g_return_if_fail (writer != NULL);
 	vala_ccode_writer_write_indent (writer, NULL);
 	vala_ccode_writer_write_string (writer, "#include ");
 	if (self->priv->_local) {
@@ -76,7 +76,7 @@ static void vala_ccode_include_directive_real_write (ValaCCodeNode* base, ValaCC
 
 
 const char* vala_ccode_include_directive_get_filename (ValaCCodeIncludeDirective* self) {
-	g_return_val_if_fail (VALA_IS_CCODE_INCLUDE_DIRECTIVE (self), NULL);
+	g_return_val_if_fail (self != NULL, NULL);
 	return self->priv->_filename;
 }
 
@@ -84,21 +84,21 @@ const char* vala_ccode_include_directive_get_filename (ValaCCodeIncludeDirective
 void vala_ccode_include_directive_set_filename (ValaCCodeIncludeDirective* self, const char* value) {
 	char* _tmp2;
 	const char* _tmp1;
-	g_return_if_fail (VALA_IS_CCODE_INCLUDE_DIRECTIVE (self));
+	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_filename = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_filename = (g_free (self->priv->_filename), NULL)), _tmp2);
+	self->priv->_filename = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : g_strdup (_tmp1)), self->priv->_filename = (g_free (self->priv->_filename), NULL), _tmp2);
 }
 
 
 gboolean vala_ccode_include_directive_get_local (ValaCCodeIncludeDirective* self) {
-	g_return_val_if_fail (VALA_IS_CCODE_INCLUDE_DIRECTIVE (self), FALSE);
+	g_return_val_if_fail (self != NULL, FALSE);
 	return self->priv->_local;
 }
 
 
 void vala_ccode_include_directive_set_local (ValaCCodeIncludeDirective* self, gboolean value) {
-	g_return_if_fail (VALA_IS_CCODE_INCLUDE_DIRECTIVE (self));
+	g_return_if_fail (self != NULL);
 	self->priv->_local = value;
 }
 
