@@ -52,15 +52,19 @@ struct _ValaCCodeMacroReplacement {
 	ValaCCodeNode parent_instance;
 	ValaCCodeMacroReplacementPrivate * priv;
 };
+
 struct _ValaCCodeMacroReplacementClass {
 	ValaCCodeNodeClass parent_class;
 };
 
+
+ValaCCodeMacroReplacement* vala_ccode_macro_replacement_construct (GType object_type, const char* name, const char* replacement);
 ValaCCodeMacroReplacement* vala_ccode_macro_replacement_new (const char* name, const char* replacement);
+ValaCCodeMacroReplacement* vala_ccode_macro_replacement_construct_with_expression (GType object_type, const char* name, ValaCCodeExpression* replacement_expression);
 ValaCCodeMacroReplacement* vala_ccode_macro_replacement_new_with_expression (const char* name, ValaCCodeExpression* replacement_expression);
-char* vala_ccode_macro_replacement_get_name (ValaCCodeMacroReplacement* self);
+const char* vala_ccode_macro_replacement_get_name (ValaCCodeMacroReplacement* self);
 void vala_ccode_macro_replacement_set_name (ValaCCodeMacroReplacement* self, const char* value);
-char* vala_ccode_macro_replacement_get_replacement (ValaCCodeMacroReplacement* self);
+const char* vala_ccode_macro_replacement_get_replacement (ValaCCodeMacroReplacement* self);
 void vala_ccode_macro_replacement_set_replacement (ValaCCodeMacroReplacement* self, const char* value);
 ValaCCodeExpression* vala_ccode_macro_replacement_get_replacement_expression (ValaCCodeMacroReplacement* self);
 void vala_ccode_macro_replacement_set_replacement_expression (ValaCCodeMacroReplacement* self, ValaCCodeExpression* value);
