@@ -46,7 +46,7 @@ static void vala_ccode_switch_statement_finalize (ValaCCodeNode* obj);
 ValaCCodeSwitchStatement* vala_ccode_switch_statement_construct (GType object_type, ValaCCodeExpression* expression) {
 	ValaCCodeSwitchStatement* self;
 	g_return_val_if_fail (expression != NULL, NULL);
-	self = ((ValaCCodeSwitchStatement*) (g_type_create_instance (object_type)));
+	self = (ValaCCodeSwitchStatement*) g_type_create_instance (object_type);
 	vala_ccode_switch_statement_set_expression (self, expression);
 	return self;
 }
@@ -59,13 +59,13 @@ ValaCCodeSwitchStatement* vala_ccode_switch_statement_new (ValaCCodeExpression*
 
 static void vala_ccode_switch_statement_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeSwitchStatement * self;
-	self = ((ValaCCodeSwitchStatement*) (base));
+	self = (ValaCCodeSwitchStatement*) base;
 	g_return_if_fail (writer != NULL);
-	vala_ccode_writer_write_indent (writer, vala_ccode_node_get_line (((ValaCCodeNode*) (self))));
+	vala_ccode_writer_write_indent (writer, vala_ccode_node_get_line ((ValaCCodeNode*) self));
 	vala_ccode_writer_write_string (writer, "switch (");
-	vala_ccode_node_write (((ValaCCodeNode*) (self->priv->_expression)), writer);
+	vala_ccode_node_write ((ValaCCodeNode*) self->priv->_expression, writer);
 	vala_ccode_writer_write_string (writer, ")");
-	VALA_CCODE_NODE_CLASS (vala_ccode_switch_statement_parent_class)->write (((ValaCCodeNode*) (VALA_CCODE_BLOCK (self))), writer);
+	VALA_CCODE_NODE_CLASS (vala_ccode_switch_statement_parent_class)->write ((ValaCCodeNode*) VALA_CCODE_BLOCK (self), writer);
 }
 
 
@@ -81,7 +81,7 @@ void vala_ccode_switch_statement_set_expression (ValaCCodeSwitchStatement* self,
 	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_expression = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_ccode_node_ref (_tmp1))), (self->priv->_expression == NULL ? NULL : (self->priv->_expression = (vala_ccode_node_unref (self->priv->_expression), NULL))), _tmp2);
+	self->priv->_expression = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : vala_ccode_node_ref (_tmp1)), (self->priv->_expression == NULL) ? NULL : (self->priv->_expression = (vala_ccode_node_unref (self->priv->_expression), NULL)), _tmp2);
 }
 
 
@@ -101,7 +101,7 @@ static void vala_ccode_switch_statement_instance_init (ValaCCodeSwitchStatement
 static void vala_ccode_switch_statement_finalize (ValaCCodeNode* obj) {
 	ValaCCodeSwitchStatement * self;
 	self = VALA_CCODE_SWITCH_STATEMENT (obj);
-	(self->priv->_expression == NULL ? NULL : (self->priv->_expression = (vala_ccode_node_unref (self->priv->_expression), NULL)));
+	(self->priv->_expression == NULL) ? NULL : (self->priv->_expression = (vala_ccode_node_unref (self->priv->_expression), NULL));
 	VALA_CCODE_NODE_CLASS (vala_ccode_switch_statement_parent_class)->finalize (obj);
 }
 
