@@ -57,7 +57,6 @@
 #include <ccode/valaccodeidentifier.h>
 #include <ccode/valaccodefunction.h>
 #include <vala/valaproperty.h>
-#include <vala/valainterface.h>
 #include <ccode/valaccodefunctioncall.h>
 #include <vala/valamemberaccess.h>
 #include <vala/valaformalparameter.h>
@@ -206,8 +205,6 @@ struct _ValaCCodeBaseModule {
 	ValaStruct* gvalue_type;
 	ValaStruct* mutex_type;
 	ValaTypeSymbol* type_module_type;
-	ValaInterface* list_type;
-	ValaInterface* map_type;
 	ValaTypeSymbol* dbus_object_type;
 	gboolean in_plugin;
 	char* module_init_param_name;
