@@ -102,10 +102,11 @@ static void vala_ccode_delegate_module_real_visit_delegate (ValaCCodeModule* bas
 	char* _tmp0;
 	ValaCCodeFunctionDeclarator* _tmp1;
 	ValaCCodeFunctionDeclarator* cfundecl;
-	GeeList* _tmp9;
-	gboolean _tmp10;
-	char* _tmp11;
-	ValaCCodeTypeDefinition* _tmp12;
+	gboolean _tmp9;
+	GeeList* _tmp13;
+	gboolean _tmp14;
+	char* _tmp15;
+	ValaCCodeTypeDefinition* _tmp16;
 	ValaCCodeTypeDefinition* ctypedef;
 	self = (ValaCCodeDelegateModule*) base;
 	g_return_if_fail (d != NULL);
@@ -165,22 +166,50 @@ static void vala_ccode_delegate_module_real_visit_delegate (ValaCCodeModule* bas
 		}
 		(_param_it == NULL) ? NULL : (_param_it = (gee_collection_object_unref (_param_it), NULL));
 	}
+	_tmp9 = FALSE;
+	if (!vala_delegate_get_no_array_length (d)) {
+		_tmp9 = VALA_IS_ARRAY_TYPE (vala_delegate_get_return_type (d));
+	} else {
+		_tmp9 = FALSE;
+	}
+	if (_tmp9) {
+		ValaArrayType* _tmp10;
+		ValaArrayType* array_type;
+		/* return array length if appropriate*/
+		_tmp10 = NULL;
+		array_type = (_tmp10 = VALA_ARRAY_TYPE (vala_delegate_get_return_type (d)), (_tmp10 == NULL) ? NULL : vala_code_node_ref (_tmp10));
+		{
+			gint dim;
+			dim = 1;
+			for (; dim <= vala_array_type_get_rank (array_type); dim++) {
+				char* _tmp11;
+				ValaCCodeFormalParameter* _tmp12;
+				ValaCCodeFormalParameter* cparam;
+				_tmp11 = NULL;
+				_tmp12 = NULL;
+				cparam = (_tmp12 = vala_ccode_formal_parameter_new (_tmp11 = vala_ccode_module_get_array_length_cname (vala_ccode_module_get_head ((ValaCCodeModule*) self), "result", dim), "int*"), _tmp11 = (g_free (_tmp11), NULL), _tmp12);
+				vala_ccode_function_declarator_add_parameter (cfundecl, cparam);
+				(cparam == NULL) ? NULL : (cparam = (vala_ccode_node_unref (cparam), NULL));
+			}
+		}
+		(array_type == NULL) ? NULL : (array_type = (vala_code_node_unref (array_type), NULL));
+	}
 	if (vala_delegate_get_has_target (d)) {
 		ValaCCodeFormalParameter* cparam;
 		cparam = vala_ccode_formal_parameter_new ("user_data", "void*");
 		vala_ccode_function_declarator_add_parameter (cfundecl, cparam);
 		(cparam == NULL) ? NULL : (cparam = (vala_ccode_node_unref (cparam), NULL));
 	}
-	_tmp9 = NULL;
-	if ((_tmp10 = gee_collection_get_size ((GeeCollection*) (_tmp9 = vala_code_node_get_error_types ((ValaCodeNode*) d))) > 0, (_tmp9 == NULL) ? NULL : (_tmp9 = (gee_collection_object_unref (_tmp9), NULL)), _tmp10)) {
+	_tmp13 = NULL;
+	if ((_tmp14 = gee_collection_get_size ((GeeCollection*) (_tmp13 = vala_code_node_get_error_types ((ValaCodeNode*) d))) > 0, (_tmp13 == NULL) ? NULL : (_tmp13 = (gee_collection_object_unref (_tmp13), NULL)), _tmp14)) {
 		ValaCCodeFormalParameter* cparam;
 		cparam = vala_ccode_formal_parameter_new ("error", "GError**");
 		vala_ccode_function_declarator_add_parameter (cfundecl, cparam);
 		(cparam == NULL) ? NULL : (cparam = (vala_ccode_node_unref (cparam), NULL));
 	}
-	_tmp11 = NULL;
-	_tmp12 = NULL;
-	ctypedef = (_tmp12 = vala_ccode_type_definition_new (_tmp11 = vala_data_type_get_cname (vala_delegate_get_return_type (d)), (ValaCCodeDeclarator*) cfundecl), _tmp11 = (g_free (_tmp11), NULL), _tmp12);
+	_tmp15 = NULL;
+	_tmp16 = NULL;
+	ctypedef = (_tmp16 = vala_ccode_type_definition_new (_tmp15 = vala_data_type_get_cname (vala_delegate_get_return_type (d)), (ValaCCodeDeclarator*) cfundecl), _tmp15 = (g_free (_tmp15), NULL), _tmp16);
 	if (!vala_symbol_is_internal_symbol ((ValaSymbol*) d)) {
 		vala_ccode_fragment_append (((ValaCCodeBaseModule*) self)->header_type_declaration, (ValaCCodeNode*) ctypedef);
 	} else {
@@ -486,21 +515,23 @@ static char* vala_ccode_delegate_module_generate_delegate_wrapper (ValaCCodeDele
 	ValaCCodeFunction* function;
 	GeeHashMap* cparam_map;
 	GeeList* d_params;
-	GeeList* _tmp20;
-	gboolean _tmp21;
+	gboolean _tmp20;
+	GeeList* _tmp24;
+	gboolean _tmp25;
 	gint last_pos;
 	gint min_pos;
 	GeeHashMap* carg_map;
 	gint i;
-	GeeList* _tmp44;
-	gboolean _tmp45;
-	ValaCCodeIdentifier* _tmp48;
-	char* _tmp47;
-	ValaCCodeFunctionCall* _tmp49;
+	gboolean _tmp56;
+	GeeList* _tmp61;
+	gboolean _tmp62;
+	ValaCCodeIdentifier* _tmp65;
+	char* _tmp64;
+	ValaCCodeFunctionCall* _tmp66;
 	ValaCCodeFunctionCall* ccall;
 	ValaCCodeBlock* block;
-	ValaCCodeFunction* _tmp57;
-	char* _tmp58;
+	ValaCCodeFunction* _tmp74;
+	char* _tmp75;
 	g_return_val_if_fail (self != NULL, NULL);
 	g_return_val_if_fail (m != NULL, NULL);
 	g_return_val_if_fail (d != NULL, NULL);
@@ -608,8 +639,36 @@ static char* vala_ccode_delegate_module_generate_delegate_wrapper (ValaCCodeDele
 		}
 		(_param_it == NULL) ? NULL : (_param_it = (gee_collection_object_unref (_param_it), NULL));
 	}
-	_tmp20 = NULL;
-	if ((_tmp21 = gee_collection_get_size ((GeeCollection*) (_tmp20 = vala_code_node_get_error_types ((ValaCodeNode*) m))) > 0, (_tmp20 == NULL) ? NULL : (_tmp20 = (gee_collection_object_unref (_tmp20), NULL)), _tmp21)) {
+	_tmp20 = FALSE;
+	if (!vala_delegate_get_no_array_length (d)) {
+		_tmp20 = VALA_IS_ARRAY_TYPE (vala_delegate_get_return_type (d));
+	} else {
+		_tmp20 = FALSE;
+	}
+	if (_tmp20) {
+		ValaArrayType* _tmp21;
+		ValaArrayType* array_type;
+		/* return array length if appropriate*/
+		_tmp21 = NULL;
+		array_type = (_tmp21 = VALA_ARRAY_TYPE (vala_delegate_get_return_type (d)), (_tmp21 == NULL) ? NULL : vala_code_node_ref (_tmp21));
+		{
+			gint dim;
+			dim = 1;
+			for (; dim <= vala_array_type_get_rank (array_type); dim++) {
+				char* _tmp22;
+				ValaCCodeFormalParameter* _tmp23;
+				ValaCCodeFormalParameter* cparam;
+				_tmp22 = NULL;
+				_tmp23 = NULL;
+				cparam = (_tmp23 = vala_ccode_formal_parameter_new (_tmp22 = vala_ccode_module_get_array_length_cname (vala_ccode_module_get_head ((ValaCCodeModule*) self), "result", dim), "int*"), _tmp22 = (g_free (_tmp22), NULL), _tmp23);
+				gee_map_set ((GeeMap*) cparam_map, GINT_TO_POINTER (vala_ccode_base_module_get_param_pos ((ValaCCodeBaseModule*) self, vala_delegate_get_carray_length_parameter_position (d) + (0.01 * dim), FALSE)), cparam);
+				(cparam == NULL) ? NULL : (cparam = (vala_ccode_node_unref (cparam), NULL));
+			}
+		}
+		(array_type == NULL) ? NULL : (array_type = (vala_code_node_unref (array_type), NULL));
+	}
+	_tmp24 = NULL;
+	if ((_tmp25 = gee_collection_get_size ((GeeCollection*) (_tmp24 = vala_code_node_get_error_types ((ValaCodeNode*) m))) > 0, (_tmp24 == NULL) ? NULL : (_tmp24 = (gee_collection_object_unref (_tmp24), NULL)), _tmp25)) {
 		ValaCCodeFormalParameter* cparam;
 		cparam = vala_ccode_formal_parameter_new ("error", "GError**");
 		gee_map_set ((GeeMap*) cparam_map, GINT_TO_POINTER (vala_ccode_base_module_get_param_pos ((ValaCCodeBaseModule*) self, (double) (-1), FALSE)), cparam);
@@ -619,33 +678,33 @@ static char* vala_ccode_delegate_module_generate_delegate_wrapper (ValaCCodeDele
 	last_pos = -1;
 	min_pos = 0;
 	while (TRUE) {
-		ValaCCodeFormalParameter* _tmp26;
+		ValaCCodeFormalParameter* _tmp30;
 		min_pos = -1;
 		{
-			GeeSet* _tmp22;
-			GeeIterator* _tmp23;
+			GeeSet* _tmp26;
+			GeeIterator* _tmp27;
 			GeeIterator* _pos_it;
-			_tmp22 = NULL;
-			_tmp23 = NULL;
-			_pos_it = (_tmp23 = gee_iterable_iterator ((GeeIterable*) (_tmp22 = gee_map_get_keys ((GeeMap*) cparam_map))), (_tmp22 == NULL) ? NULL : (_tmp22 = (gee_collection_object_unref (_tmp22), NULL)), _tmp23);
+			_tmp26 = NULL;
+			_tmp27 = NULL;
+			_pos_it = (_tmp27 = gee_iterable_iterator ((GeeIterable*) (_tmp26 = gee_map_get_keys ((GeeMap*) cparam_map))), (_tmp26 == NULL) ? NULL : (_tmp26 = (gee_collection_object_unref (_tmp26), NULL)), _tmp27);
 			while (gee_iterator_next (_pos_it)) {
 				gint pos;
-				gboolean _tmp24;
+				gboolean _tmp28;
 				pos = GPOINTER_TO_INT (gee_iterator_get (_pos_it));
-				_tmp24 = FALSE;
+				_tmp28 = FALSE;
 				if (pos > last_pos) {
-					gboolean _tmp25;
-					_tmp25 = FALSE;
+					gboolean _tmp29;
+					_tmp29 = FALSE;
 					if (min_pos == (-1)) {
-						_tmp25 = TRUE;
+						_tmp29 = TRUE;
 					} else {
-						_tmp25 = pos < min_pos;
+						_tmp29 = pos < min_pos;
 					}
-					_tmp24 = (_tmp25);
+					_tmp28 = (_tmp29);
 				} else {
-					_tmp24 = FALSE;
+					_tmp28 = FALSE;
 				}
-				if (_tmp24) {
+				if (_tmp28) {
 					min_pos = pos;
 				}
 			}
@@ -654,9 +713,9 @@ static char* vala_ccode_delegate_module_generate_delegate_wrapper (ValaCCodeDele
 		if (min_pos == (-1)) {
 			break;
 		}
-		_tmp26 = NULL;
-		vala_ccode_function_add_parameter (function, _tmp26 = (ValaCCodeFormalParameter*) gee_map_get ((GeeMap*) cparam_map, GINT_TO_POINTER (min_pos)));
-		(_tmp26 == NULL) ? NULL : (_tmp26 = (vala_ccode_node_unref (_tmp26), NULL));
+		_tmp30 = NULL;
+		vala_ccode_function_add_parameter (function, _tmp30 = (ValaCCodeFormalParameter*) gee_map_get ((GeeMap*) cparam_map, GINT_TO_POINTER (min_pos)));
+		(_tmp30 == NULL) ? NULL : (_tmp30 = (vala_ccode_node_unref (_tmp30), NULL));
 		last_pos = min_pos;
 	}
 	/* definition*/
@@ -666,81 +725,107 @@ static char* vala_ccode_delegate_module_generate_delegate_wrapper (ValaCCodeDele
 		ValaCCodeExpression* arg;
 		arg = NULL;
 		if (vala_delegate_get_has_target (d)) {
-			ValaCCodeExpression* _tmp27;
-			_tmp27 = NULL;
-			arg = (_tmp27 = (ValaCCodeExpression*) vala_ccode_identifier_new ("self"), (arg == NULL) ? NULL : (arg = (vala_ccode_node_unref (arg), NULL)), _tmp27);
+			ValaCCodeExpression* _tmp31;
+			_tmp31 = NULL;
+			arg = (_tmp31 = (ValaCCodeExpression*) vala_ccode_identifier_new ("self"), (arg == NULL) ? NULL : (arg = (vala_ccode_node_unref (arg), NULL)), _tmp31);
 		} else {
-			ValaCCodeExpression* _tmp30;
-			ValaFormalParameter* _tmp28;
-			ValaCCodeNode* _tmp29;
+			ValaCCodeExpression* _tmp34;
+			ValaFormalParameter* _tmp32;
+			ValaCCodeNode* _tmp33;
 			/* use first delegate parameter as instance*/
-			_tmp30 = NULL;
-			_tmp28 = NULL;
-			_tmp29 = NULL;
-			arg = (_tmp30 = (ValaCCodeExpression*) vala_ccode_identifier_new (vala_ccode_formal_parameter_get_name (((_tmp29 = vala_code_node_get_ccodenode ((ValaCodeNode*) (_tmp28 = (ValaFormalParameter*) gee_list_get (d_params, 0))), VALA_IS_CCODE_FORMAL_PARAMETER (_tmp29) ? ((ValaCCodeFormalParameter*) _tmp29) : NULL)))), (arg == NULL) ? NULL : (arg = (vala_ccode_node_unref (arg), NULL)), _tmp30);
-			(_tmp28 == NULL) ? NULL : (_tmp28 = (vala_code_node_unref (_tmp28), NULL));
+			_tmp34 = NULL;
+			_tmp32 = NULL;
+			_tmp33 = NULL;
+			arg = (_tmp34 = (ValaCCodeExpression*) vala_ccode_identifier_new (vala_ccode_formal_parameter_get_name (((_tmp33 = vala_code_node_get_ccodenode ((ValaCodeNode*) (_tmp32 = (ValaFormalParameter*) gee_list_get (d_params, 0))), VALA_IS_CCODE_FORMAL_PARAMETER (_tmp33) ? ((ValaCCodeFormalParameter*) _tmp33) : NULL)))), (arg == NULL) ? NULL : (arg = (vala_ccode_node_unref (arg), NULL)), _tmp34);
+			(_tmp32 == NULL) ? NULL : (_tmp32 = (vala_code_node_unref (_tmp32), NULL));
 			i = 1;
 		}
 		gee_map_set ((GeeMap*) carg_map, GINT_TO_POINTER (vala_ccode_base_module_get_param_pos ((ValaCCodeBaseModule*) self, vala_method_get_cinstance_parameter_position (m), FALSE)), arg);
 		(arg == NULL) ? NULL : (arg = (vala_ccode_node_unref (arg), NULL));
 	}
 	{
-		GeeList* _tmp31;
-		GeeIterator* _tmp32;
+		GeeList* _tmp35;
+		GeeIterator* _tmp36;
 		GeeIterator* _param_it;
-		_tmp31 = NULL;
-		_tmp32 = NULL;
-		_param_it = (_tmp32 = gee_iterable_iterator ((GeeIterable*) (_tmp31 = vala_method_get_parameters (m))), (_tmp31 == NULL) ? NULL : (_tmp31 = (gee_collection_object_unref (_tmp31), NULL)), _tmp32);
+		_tmp35 = NULL;
+		_tmp36 = NULL;
+		_param_it = (_tmp36 = gee_iterable_iterator ((GeeIterable*) (_tmp35 = vala_method_get_parameters (m))), (_tmp35 == NULL) ? NULL : (_tmp35 = (gee_collection_object_unref (_tmp35), NULL)), _tmp36);
 		while (gee_iterator_next (_param_it)) {
 			ValaFormalParameter* param;
 			ValaCCodeExpression* arg;
-			ValaCCodeExpression* _tmp35;
-			ValaFormalParameter* _tmp33;
-			ValaCCodeNode* _tmp34;
-			gboolean _tmp36;
+			ValaCCodeExpression* _tmp39;
+			ValaFormalParameter* _tmp37;
+			ValaCCodeNode* _tmp38;
+			gboolean _tmp40;
 			param = (ValaFormalParameter*) gee_iterator_get (_param_it);
 			arg = NULL;
-			_tmp35 = NULL;
-			_tmp33 = NULL;
-			_tmp34 = NULL;
-			arg = (_tmp35 = (ValaCCodeExpression*) vala_ccode_identifier_new (vala_ccode_formal_parameter_get_name (((_tmp34 = vala_code_node_get_ccodenode ((ValaCodeNode*) (_tmp33 = (ValaFormalParameter*) gee_list_get (d_params, i))), VALA_IS_CCODE_FORMAL_PARAMETER (_tmp34) ? ((ValaCCodeFormalParameter*) _tmp34) : NULL)))), (arg == NULL) ? NULL : (arg = (vala_ccode_node_unref (arg), NULL)), _tmp35);
-			(_tmp33 == NULL) ? NULL : (_tmp33 = (vala_code_node_unref (_tmp33), NULL));
+			_tmp39 = NULL;
+			_tmp37 = NULL;
+			_tmp38 = NULL;
+			arg = (_tmp39 = (ValaCCodeExpression*) vala_ccode_identifier_new (vala_ccode_formal_parameter_get_name (((_tmp38 = vala_code_node_get_ccodenode ((ValaCodeNode*) (_tmp37 = (ValaFormalParameter*) gee_list_get (d_params, i))), VALA_IS_CCODE_FORMAL_PARAMETER (_tmp38) ? ((ValaCCodeFormalParameter*) _tmp38) : NULL)))), (arg == NULL) ? NULL : (arg = (vala_ccode_node_unref (arg), NULL)), _tmp39);
+			(_tmp37 == NULL) ? NULL : (_tmp37 = (vala_code_node_unref (_tmp37), NULL));
 			gee_map_set ((GeeMap*) carg_map, GINT_TO_POINTER (vala_ccode_base_module_get_param_pos ((ValaCCodeBaseModule*) self, vala_formal_parameter_get_cparameter_position (param), FALSE)), arg);
-			_tmp36 = FALSE;
+			_tmp40 = FALSE;
 			if (!vala_formal_parameter_get_no_array_length (param)) {
-				_tmp36 = VALA_IS_ARRAY_TYPE (vala_formal_parameter_get_parameter_type (param));
+				_tmp40 = VALA_IS_ARRAY_TYPE (vala_formal_parameter_get_parameter_type (param));
 			} else {
-				_tmp36 = FALSE;
+				_tmp40 = FALSE;
 			}
 			/* handle array arguments*/
-			if (_tmp36) {
-				ValaArrayType* _tmp37;
+			if (_tmp40) {
+				ValaArrayType* _tmp41;
 				ValaArrayType* array_type;
-				_tmp37 = NULL;
-				array_type = (_tmp37 = VALA_ARRAY_TYPE (vala_formal_parameter_get_parameter_type (param)), (_tmp37 == NULL) ? NULL : vala_code_node_ref (_tmp37));
+				_tmp41 = NULL;
+				array_type = (_tmp41 = VALA_ARRAY_TYPE (vala_formal_parameter_get_parameter_type (param)), (_tmp41 == NULL) ? NULL : vala_code_node_ref (_tmp41));
 				{
 					gint dim;
 					dim = 1;
 					for (; dim <= vala_array_type_get_rank (array_type); dim++) {
 						ValaCCodeExpression* clength;
-						ValaFormalParameter* _tmp38;
-						gboolean _tmp39;
+						ValaFormalParameter* _tmp42;
+						gboolean _tmp43;
 						clength = NULL;
-						_tmp38 = NULL;
-						if ((_tmp39 = vala_formal_parameter_get_no_array_length (_tmp38 = (ValaFormalParameter*) gee_list_get (d_params, i)), (_tmp38 == NULL) ? NULL : (_tmp38 = (vala_code_node_unref (_tmp38), NULL)), _tmp39)) {
-							ValaCCodeExpression* _tmp40;
-							_tmp40 = NULL;
-							clength = (_tmp40 = (ValaCCodeExpression*) vala_ccode_constant_new ("-1"), (clength == NULL) ? NULL : (clength = (vala_ccode_node_unref (clength), NULL)), _tmp40);
+						_tmp42 = NULL;
+						if ((_tmp43 = vala_formal_parameter_get_array_null_terminated (_tmp42 = (ValaFormalParameter*) gee_list_get (d_params, i)), (_tmp42 == NULL) ? NULL : (_tmp42 = (vala_code_node_unref (_tmp42), NULL)), _tmp43)) {
+							ValaCCodeIdentifier* _tmp44;
+							ValaCCodeFunctionCall* _tmp45;
+							ValaCCodeFunctionCall* len_call;
+							ValaCCodeIdentifier* _tmp47;
+							ValaFormalParameter* _tmp46;
+							ValaCCodeExpression* _tmp49;
+							ValaCCodeExpression* _tmp48;
+							((ValaCCodeBaseModule*) self)->requires_array_length = TRUE;
+							_tmp44 = NULL;
+							_tmp45 = NULL;
+							len_call = (_tmp45 = vala_ccode_function_call_new ((ValaCCodeExpression*) (_tmp44 = vala_ccode_identifier_new ("_vala_array_length"))), (_tmp44 == NULL) ? NULL : (_tmp44 = (vala_ccode_node_unref (_tmp44), NULL)), _tmp45);
+							_tmp47 = NULL;
+							_tmp46 = NULL;
+							vala_ccode_function_call_add_argument (len_call, (ValaCCodeExpression*) (_tmp47 = vala_ccode_identifier_new (vala_symbol_get_name ((ValaSymbol*) (_tmp46 = (ValaFormalParameter*) gee_list_get (d_params, i))))));
+							(_tmp47 == NULL) ? NULL : (_tmp47 = (vala_ccode_node_unref (_tmp47), NULL));
+							(_tmp46 == NULL) ? NULL : (_tmp46 = (vala_code_node_unref (_tmp46), NULL));
+							_tmp49 = NULL;
+							_tmp48 = NULL;
+							clength = (_tmp49 = (_tmp48 = (ValaCCodeExpression*) len_call, (_tmp48 == NULL) ? NULL : vala_ccode_node_ref (_tmp48)), (clength == NULL) ? NULL : (clength = (vala_ccode_node_unref (clength), NULL)), _tmp49);
+							(len_call == NULL) ? NULL : (len_call = (vala_ccode_node_unref (len_call), NULL));
 						} else {
-							ValaCCodeExpression* _tmp43;
-							char* _tmp42;
-							ValaFormalParameter* _tmp41;
-							_tmp43 = NULL;
-							_tmp42 = NULL;
-							_tmp41 = NULL;
-							clength = (_tmp43 = (ValaCCodeExpression*) vala_ccode_identifier_new (_tmp42 = vala_ccode_module_get_array_length_cname (vala_ccode_module_get_head ((ValaCCodeModule*) self), vala_symbol_get_name ((ValaSymbol*) (_tmp41 = (ValaFormalParameter*) gee_list_get (d_params, i))), dim)), (clength == NULL) ? NULL : (clength = (vala_ccode_node_unref (clength), NULL)), _tmp43);
-							_tmp42 = (g_free (_tmp42), NULL);
-							(_tmp41 == NULL) ? NULL : (_tmp41 = (vala_code_node_unref (_tmp41), NULL));
+							ValaFormalParameter* _tmp50;
+							gboolean _tmp51;
+							_tmp50 = NULL;
+							if ((_tmp51 = vala_formal_parameter_get_no_array_length (_tmp50 = (ValaFormalParameter*) gee_list_get (d_params, i)), (_tmp50 == NULL) ? NULL : (_tmp50 = (vala_code_node_unref (_tmp50), NULL)), _tmp51)) {
+								ValaCCodeExpression* _tmp52;
+								_tmp52 = NULL;
+								clength = (_tmp52 = (ValaCCodeExpression*) vala_ccode_constant_new ("-1"), (clength == NULL) ? NULL : (clength = (vala_ccode_node_unref (clength), NULL)), _tmp52);
+							} else {
+								ValaCCodeExpression* _tmp55;
+								char* _tmp54;
+								ValaFormalParameter* _tmp53;
+								_tmp55 = NULL;
+								_tmp54 = NULL;
+								_tmp53 = NULL;
+								clength = (_tmp55 = (ValaCCodeExpression*) vala_ccode_identifier_new (_tmp54 = vala_ccode_module_get_array_length_cname (vala_ccode_module_get_head ((ValaCCodeModule*) self), vala_symbol_get_name ((ValaSymbol*) (_tmp53 = (ValaFormalParameter*) gee_list_get (d_params, i))), dim)), (clength == NULL) ? NULL : (clength = (vala_ccode_node_unref (clength), NULL)), _tmp55);
+								_tmp54 = (g_free (_tmp54), NULL);
+								(_tmp53 == NULL) ? NULL : (_tmp53 = (vala_code_node_unref (_tmp53), NULL));
+							}
 						}
 						gee_map_set ((GeeMap*) carg_map, GINT_TO_POINTER (vala_ccode_base_module_get_param_pos ((ValaCCodeBaseModule*) self, vala_formal_parameter_get_carray_length_parameter_position (param) + (0.01 * dim), FALSE)), clength);
 						(clength == NULL) ? NULL : (clength = (vala_ccode_node_unref (clength), NULL));
@@ -754,47 +839,82 @@ static char* vala_ccode_delegate_module_generate_delegate_wrapper (ValaCCodeDele
 		}
 		(_param_it == NULL) ? NULL : (_param_it = (gee_collection_object_unref (_param_it), NULL));
 	}
-	_tmp44 = NULL;
-	if ((_tmp45 = gee_collection_get_size ((GeeCollection*) (_tmp44 = vala_code_node_get_error_types ((ValaCodeNode*) m))) > 0, (_tmp44 == NULL) ? NULL : (_tmp44 = (gee_collection_object_unref (_tmp44), NULL)), _tmp45)) {
-		ValaCCodeIdentifier* _tmp46;
-		_tmp46 = NULL;
-		gee_map_set ((GeeMap*) carg_map, GINT_TO_POINTER (vala_ccode_base_module_get_param_pos ((ValaCCodeBaseModule*) self, (double) (-1), FALSE)), (ValaCCodeExpression*) (_tmp46 = vala_ccode_identifier_new ("error")));
-		(_tmp46 == NULL) ? NULL : (_tmp46 = (vala_ccode_node_unref (_tmp46), NULL));
+	_tmp56 = FALSE;
+	if (!vala_method_get_no_array_length (m)) {
+		_tmp56 = VALA_IS_ARRAY_TYPE (vala_method_get_return_type (m));
+	} else {
+		_tmp56 = FALSE;
 	}
-	_tmp48 = NULL;
-	_tmp47 = NULL;
-	_tmp49 = NULL;
-	ccall = (_tmp49 = vala_ccode_function_call_new ((ValaCCodeExpression*) (_tmp48 = vala_ccode_identifier_new (_tmp47 = vala_method_get_cname (m)))), (_tmp48 == NULL) ? NULL : (_tmp48 = (vala_ccode_node_unref (_tmp48), NULL)), _tmp47 = (g_free (_tmp47), NULL), _tmp49);
+	if (_tmp56) {
+		ValaArrayType* _tmp57;
+		ValaArrayType* array_type;
+		_tmp57 = NULL;
+		array_type = (_tmp57 = VALA_ARRAY_TYPE (vala_method_get_return_type (m)), (_tmp57 == NULL) ? NULL : vala_code_node_ref (_tmp57));
+		{
+			gint dim;
+			dim = 1;
+			for (; dim <= vala_array_type_get_rank (array_type); dim++) {
+				ValaCCodeExpression* clength;
+				clength = NULL;
+				if (vala_delegate_get_no_array_length (d)) {
+					ValaCCodeExpression* _tmp58;
+					_tmp58 = NULL;
+					clength = (_tmp58 = (ValaCCodeExpression*) vala_ccode_constant_new ("NULL"), (clength == NULL) ? NULL : (clength = (vala_ccode_node_unref (clength), NULL)), _tmp58);
+				} else {
+					ValaCCodeExpression* _tmp60;
+					char* _tmp59;
+					_tmp60 = NULL;
+					_tmp59 = NULL;
+					clength = (_tmp60 = (ValaCCodeExpression*) vala_ccode_identifier_new (_tmp59 = vala_ccode_module_get_array_length_cname (vala_ccode_module_get_head ((ValaCCodeModule*) self), "result", dim)), (clength == NULL) ? NULL : (clength = (vala_ccode_node_unref (clength), NULL)), _tmp60);
+					_tmp59 = (g_free (_tmp59), NULL);
+				}
+				gee_map_set ((GeeMap*) carg_map, GINT_TO_POINTER (vala_ccode_base_module_get_param_pos ((ValaCCodeBaseModule*) self, vala_method_get_carray_length_parameter_position (m) + (0.01 * dim), FALSE)), clength);
+				(clength == NULL) ? NULL : (clength = (vala_ccode_node_unref (clength), NULL));
+			}
+		}
+		(array_type == NULL) ? NULL : (array_type = (vala_code_node_unref (array_type), NULL));
+	}
+	_tmp61 = NULL;
+	if ((_tmp62 = gee_collection_get_size ((GeeCollection*) (_tmp61 = vala_code_node_get_error_types ((ValaCodeNode*) m))) > 0, (_tmp61 == NULL) ? NULL : (_tmp61 = (gee_collection_object_unref (_tmp61), NULL)), _tmp62)) {
+		ValaCCodeIdentifier* _tmp63;
+		_tmp63 = NULL;
+		gee_map_set ((GeeMap*) carg_map, GINT_TO_POINTER (vala_ccode_base_module_get_param_pos ((ValaCCodeBaseModule*) self, (double) (-1), FALSE)), (ValaCCodeExpression*) (_tmp63 = vala_ccode_identifier_new ("error")));
+		(_tmp63 == NULL) ? NULL : (_tmp63 = (vala_ccode_node_unref (_tmp63), NULL));
+	}
+	_tmp65 = NULL;
+	_tmp64 = NULL;
+	_tmp66 = NULL;
+	ccall = (_tmp66 = vala_ccode_function_call_new ((ValaCCodeExpression*) (_tmp65 = vala_ccode_identifier_new (_tmp64 = vala_method_get_cname (m)))), (_tmp65 == NULL) ? NULL : (_tmp65 = (vala_ccode_node_unref (_tmp65), NULL)), _tmp64 = (g_free (_tmp64), NULL), _tmp66);
 	/* append C arguments in the right order*/
 	last_pos = -1;
 	while (TRUE) {
-		ValaCCodeExpression* _tmp54;
+		ValaCCodeExpression* _tmp71;
 		min_pos = -1;
 		{
-			GeeSet* _tmp50;
-			GeeIterator* _tmp51;
+			GeeSet* _tmp67;
+			GeeIterator* _tmp68;
 			GeeIterator* _pos_it;
-			_tmp50 = NULL;
-			_tmp51 = NULL;
-			_pos_it = (_tmp51 = gee_iterable_iterator ((GeeIterable*) (_tmp50 = gee_map_get_keys ((GeeMap*) carg_map))), (_tmp50 == NULL) ? NULL : (_tmp50 = (gee_collection_object_unref (_tmp50), NULL)), _tmp51);
+			_tmp67 = NULL;
+			_tmp68 = NULL;
+			_pos_it = (_tmp68 = gee_iterable_iterator ((GeeIterable*) (_tmp67 = gee_map_get_keys ((GeeMap*) carg_map))), (_tmp67 == NULL) ? NULL : (_tmp67 = (gee_collection_object_unref (_tmp67), NULL)), _tmp68);
 			while (gee_iterator_next (_pos_it)) {
 				gint pos;
-				gboolean _tmp52;
+				gboolean _tmp69;
 				pos = GPOINTER_TO_INT (gee_iterator_get (_pos_it));
-				_tmp52 = FALSE;
+				_tmp69 = FALSE;
 				if (pos > last_pos) {
-					gboolean _tmp53;
-					_tmp53 = FALSE;
+					gboolean _tmp70;
+					_tmp70 = FALSE;
 					if (min_pos == (-1)) {
-						_tmp53 = TRUE;
+						_tmp70 = TRUE;
 					} else {
-						_tmp53 = pos < min_pos;
+						_tmp70 = pos < min_pos;
 					}
-					_tmp52 = (_tmp53);
+					_tmp69 = (_tmp70);
 				} else {
-					_tmp52 = FALSE;
+					_tmp69 = FALSE;
 				}
-				if (_tmp52) {
+				if (_tmp69) {
 					min_pos = pos;
 				}
 			}
@@ -803,31 +923,31 @@ static char* vala_ccode_delegate_module_generate_delegate_wrapper (ValaCCodeDele
 		if (min_pos == (-1)) {
 			break;
 		}
-		_tmp54 = NULL;
-		vala_ccode_function_call_add_argument (ccall, _tmp54 = (ValaCCodeExpression*) gee_map_get ((GeeMap*) carg_map, GINT_TO_POINTER (min_pos)));
-		(_tmp54 == NULL) ? NULL : (_tmp54 = (vala_ccode_node_unref (_tmp54), NULL));
+		_tmp71 = NULL;
+		vala_ccode_function_call_add_argument (ccall, _tmp71 = (ValaCCodeExpression*) gee_map_get ((GeeMap*) carg_map, GINT_TO_POINTER (min_pos)));
+		(_tmp71 == NULL) ? NULL : (_tmp71 = (vala_ccode_node_unref (_tmp71), NULL));
 		last_pos = min_pos;
 	}
 	block = vala_ccode_block_new ();
 	if (VALA_IS_VOID_TYPE (vala_method_get_return_type (m))) {
-		ValaCCodeExpressionStatement* _tmp55;
-		_tmp55 = NULL;
-		vala_ccode_block_add_statement (block, (ValaCCodeNode*) (_tmp55 = vala_ccode_expression_statement_new ((ValaCCodeExpression*) ccall)));
-		(_tmp55 == NULL) ? NULL : (_tmp55 = (vala_ccode_node_unref (_tmp55), NULL));
+		ValaCCodeExpressionStatement* _tmp72;
+		_tmp72 = NULL;
+		vala_ccode_block_add_statement (block, (ValaCCodeNode*) (_tmp72 = vala_ccode_expression_statement_new ((ValaCCodeExpression*) ccall)));
+		(_tmp72 == NULL) ? NULL : (_tmp72 = (vala_ccode_node_unref (_tmp72), NULL));
 	} else {
-		ValaCCodeReturnStatement* _tmp56;
-		_tmp56 = NULL;
-		vala_ccode_block_add_statement (block, (ValaCCodeNode*) (_tmp56 = vala_ccode_return_statement_new ((ValaCCodeExpression*) ccall)));
-		(_tmp56 == NULL) ? NULL : (_tmp56 = (vala_ccode_node_unref (_tmp56), NULL));
+		ValaCCodeReturnStatement* _tmp73;
+		_tmp73 = NULL;
+		vala_ccode_block_add_statement (block, (ValaCCodeNode*) (_tmp73 = vala_ccode_return_statement_new ((ValaCCodeExpression*) ccall)));
+		(_tmp73 == NULL) ? NULL : (_tmp73 = (vala_ccode_node_unref (_tmp73), NULL));
 	}
 	/* append to file*/
-	_tmp57 = NULL;
-	vala_ccode_fragment_append (((ValaCCodeBaseModule*) self)->source_type_member_declaration, (ValaCCodeNode*) (_tmp57 = vala_ccode_function_copy (function)));
-	(_tmp57 == NULL) ? NULL : (_tmp57 = (vala_ccode_node_unref (_tmp57), NULL));
+	_tmp74 = NULL;
+	vala_ccode_fragment_append (((ValaCCodeBaseModule*) self)->source_type_member_declaration, (ValaCCodeNode*) (_tmp74 = vala_ccode_function_copy (function)));
+	(_tmp74 == NULL) ? NULL : (_tmp74 = (vala_ccode_node_unref (_tmp74), NULL));
 	vala_ccode_function_set_block (function, block);
 	vala_ccode_fragment_append (((ValaCCodeBaseModule*) self)->source_type_member_definition, (ValaCCodeNode*) function);
-	_tmp58 = NULL;
-	return (_tmp58 = wrapper_name, delegate_name = (g_free (delegate_name), NULL), (sig == NULL) ? NULL : (sig = (vala_code_node_unref (sig), NULL)), (dynamic_sig == NULL) ? NULL : (dynamic_sig = (vala_code_node_unref (dynamic_sig), NULL)), (function == NULL) ? NULL : (function = (vala_ccode_node_unref (function), NULL)), (cparam_map == NULL) ? NULL : (cparam_map = (gee_collection_object_unref (cparam_map), NULL)), (d_params == NULL) ? NULL : (d_params = (gee_collection_object_unref (d_params), NULL)), (carg_map == NULL) ? NULL : (carg_map = (gee_collection_object_unref (carg_map), NULL)), (ccall == NULL) ? NULL : (ccall = (vala_ccode_node_unref (ccall), NULL)), (block == NULL) ? NULL : (block = (vala_ccode_node_unref (block), NULL)), _tmp58);
+	_tmp75 = NULL;
+	return (_tmp75 = wrapper_name, delegate_name = (g_free (delegate_name), NULL), (sig == NULL) ? NULL : (sig = (vala_code_node_unref (sig), NULL)), (dynamic_sig == NULL) ? NULL : (dynamic_sig = (vala_code_node_unref (dynamic_sig), NULL)), (function == NULL) ? NULL : (function = (vala_ccode_node_unref (function), NULL)), (cparam_map == NULL) ? NULL : (cparam_map = (gee_collection_object_unref (cparam_map), NULL)), (d_params == NULL) ? NULL : (d_params = (gee_collection_object_unref (d_params), NULL)), (carg_map == NULL) ? NULL : (carg_map = (gee_collection_object_unref (carg_map), NULL)), (ccall == NULL) ? NULL : (ccall = (vala_ccode_node_unref (ccall), NULL)), (block == NULL) ? NULL : (block = (vala_ccode_node_unref (block), NULL)), _tmp75);
 }
 
 
