@@ -1,6 +1,6 @@
 /* valaccodemodule.vala
  *
- * Copyright (C) 2008  Jürg Billeter
+ * Copyright (C) 2008-2009  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -229,6 +229,8 @@ struct _ValaCCodeModuleClass {
 	char* (*get_marshaller_function) (ValaCCodeModule* self, GeeList* params, ValaDataType* return_type, const char* prefix, gboolean dbus);
 	char* (*get_array_length_cname) (ValaCCodeModule* self, const char* array_cname, gint dim);
 	ValaCCodeExpression* (*get_array_length_cexpression) (ValaCCodeModule* self, ValaExpression* array_expr, gint dim);
+	char* (*get_array_size_cname) (ValaCCodeModule* self, const char* array_cname);
+	ValaCCodeExpression* (*get_array_size_cexpression) (ValaCCodeModule* self, ValaExpression* array_expr);
 	void (*add_simple_check) (ValaCCodeModule* self, ValaCodeNode* node, ValaCCodeFragment* cfrag);
 };
 
@@ -328,6 +330,8 @@ void vala_ccode_module_generate_marshaller (ValaCCodeModule* self, GeeList* para
 char* vala_ccode_module_get_marshaller_function (ValaCCodeModule* self, GeeList* params, ValaDataType* return_type, const char* prefix, gboolean dbus);
 char* vala_ccode_module_get_array_length_cname (ValaCCodeModule* self, const char* array_cname, gint dim);
 ValaCCodeExpression* vala_ccode_module_get_array_length_cexpression (ValaCCodeModule* self, ValaExpression* array_expr, gint dim);
+char* vala_ccode_module_get_array_size_cname (ValaCCodeModule* self, const char* array_cname);
+ValaCCodeExpression* vala_ccode_module_get_array_size_cexpression (ValaCCodeModule* self, ValaExpression* array_expr);
 void vala_ccode_module_add_simple_check (ValaCCodeModule* self, ValaCodeNode* node, ValaCCodeFragment* cfrag);
 ValaCCodeGenerator* vala_ccode_module_get_codegen (ValaCCodeModule* self);
 ValaCCodeModule* vala_ccode_module_get_head (ValaCCodeModule* self);
