@@ -33,6 +33,7 @@
 #include <vala/valasourcefile.h>
 #include <ccode/valaccodetypedefinition.h>
 #include <ccode/valaccodevariabledeclarator.h>
+#include <ccode/valaccodeexpression.h>
 #include <ccode/valaccodedeclarator.h>
 #include <ccode/valaccodenode.h>
 #include <ccode/valaccodecomment.h>
@@ -47,7 +48,6 @@
 #include <vala/valamember.h>
 #include <ccode/valaccodememberaccess.h>
 #include <ccode/valaccodeidentifier.h>
-#include <ccode/valaccodeexpression.h>
 #include <vala/valadatatype.h>
 #include <vala/valamemberaccess.h>
 #include <vala/valaexpression.h>
@@ -105,12 +105,13 @@ static void vala_ccode_struct_module_real_visit_struct (ValaCCodeModule* base, V
 	ValaCCodeFragment* _tmp8;
 	ValaCCodeFragment* decl_frag;
 	ValaCCodeFragment* def_frag;
+	gboolean _tmp17;
+	ValaTypeSymbol* _tmp25;
 	ValaTypeSymbol* _tmp24;
-	ValaTypeSymbol* _tmp23;
+	ValaCCodeStruct* _tmp27;
 	ValaCCodeStruct* _tmp26;
-	ValaCCodeStruct* _tmp25;
+	ValaCCodeFragment* _tmp29;
 	ValaCCodeFragment* _tmp28;
-	ValaCCodeFragment* _tmp27;
 	self = (ValaCCodeStructModule*) base;
 	g_return_if_fail (st != NULL);
 	_tmp0 = NULL;
@@ -155,29 +156,36 @@ static void vala_ccode_struct_module_real_visit_struct (ValaCCodeModule* base, V
 		_tmp15 = NULL;
 		def_frag = (_tmp16 = (_tmp15 = ((ValaCCodeBaseModule*) self)->source_type_definition, (_tmp15 == NULL) ? NULL : vala_ccode_node_ref (_tmp15)), (def_frag == NULL) ? NULL : (def_frag = (vala_ccode_node_unref (def_frag), NULL)), _tmp16);
 	}
-	if (vala_source_file_get_cycle (vala_source_reference_get_file (vala_code_node_get_source_reference ((ValaCodeNode*) st))) == NULL) {
-		ValaCCodeTypeDefinition* _tmp21;
-		ValaCCodeVariableDeclarator* _tmp20;
+	_tmp17 = FALSE;
+	if (vala_symbol_get_access ((ValaSymbol*) st) == VALA_SYMBOL_ACCESSIBILITY_PRIVATE) {
+		_tmp17 = TRUE;
+	} else {
+		_tmp17 = vala_source_file_get_cycle (vala_source_reference_get_file (vala_code_node_get_source_reference ((ValaCodeNode*) st))) == NULL;
+	}
+	if (_tmp17) {
+		ValaCCodeTypeDefinition* _tmp22;
+		ValaCCodeVariableDeclarator* _tmp21;
+		char* _tmp20;
 		char* _tmp19;
 		char* _tmp18;
-		char* _tmp17;
+		/* no file dependency cycle for private symbols*/
+		_tmp22 = NULL;
 		_tmp21 = NULL;
 		_tmp20 = NULL;
 		_tmp19 = NULL;
 		_tmp18 = NULL;
-		_tmp17 = NULL;
-		vala_ccode_fragment_append (decl_frag, (ValaCCodeNode*) (_tmp21 = vala_ccode_type_definition_new (_tmp18 = g_strdup_printf ("struct _%s", _tmp17 = vala_typesymbol_get_cname ((ValaTypeSymbol*) st, FALSE)), (ValaCCodeDeclarator*) (_tmp20 = vala_ccode_variable_declarator_new (_tmp19 = vala_typesymbol_get_cname ((ValaTypeSymbol*) st, FALSE))))));
+		vala_ccode_fragment_append (decl_frag, (ValaCCodeNode*) (_tmp22 = vala_ccode_type_definition_new (_tmp19 = g_strdup_printf ("struct _%s", _tmp18 = vala_typesymbol_get_cname ((ValaTypeSymbol*) st, FALSE)), (ValaCCodeDeclarator*) (_tmp21 = vala_ccode_variable_declarator_new (_tmp20 = vala_typesymbol_get_cname ((ValaTypeSymbol*) st, FALSE), NULL)))));
+		(_tmp22 == NULL) ? NULL : (_tmp22 = (vala_ccode_node_unref (_tmp22), NULL));
 		(_tmp21 == NULL) ? NULL : (_tmp21 = (vala_ccode_node_unref (_tmp21), NULL));
-		(_tmp20 == NULL) ? NULL : (_tmp20 = (vala_ccode_node_unref (_tmp20), NULL));
+		_tmp20 = (g_free (_tmp20), NULL);
 		_tmp19 = (g_free (_tmp19), NULL);
 		_tmp18 = (g_free (_tmp18), NULL);
-		_tmp17 = (g_free (_tmp17), NULL);
 	}
 	if (vala_source_reference_get_comment (vala_code_node_get_source_reference ((ValaCodeNode*) st)) != NULL) {
-		ValaCCodeComment* _tmp22;
-		_tmp22 = NULL;
-		vala_ccode_fragment_append (def_frag, (ValaCCodeNode*) (_tmp22 = vala_ccode_comment_new (vala_source_reference_get_comment (vala_code_node_get_source_reference ((ValaCodeNode*) st)))));
-		(_tmp22 == NULL) ? NULL : (_tmp22 = (vala_ccode_node_unref (_tmp22), NULL));
+		ValaCCodeComment* _tmp23;
+		_tmp23 = NULL;
+		vala_ccode_fragment_append (def_frag, (ValaCCodeNode*) (_tmp23 = vala_ccode_comment_new (vala_source_reference_get_comment (vala_code_node_get_source_reference ((ValaCodeNode*) st)))));
+		(_tmp23 == NULL) ? NULL : (_tmp23 = (vala_ccode_node_unref (_tmp23), NULL));
 	}
 	vala_ccode_fragment_append (def_frag, (ValaCCodeNode*) ((ValaCCodeBaseModule*) self)->instance_struct);
 	vala_code_node_accept_children ((ValaCodeNode*) st, (ValaCodeVisitor*) vala_ccode_module_get_codegen ((ValaCCodeModule*) self));
@@ -187,15 +195,15 @@ static void vala_ccode_struct_module_real_visit_struct (ValaCCodeModule* base, V
 	}
 	vala_ccode_struct_module_add_struct_dup_function (self, st);
 	vala_ccode_struct_module_add_struct_free_function (self, st);
-	_tmp24 = NULL;
-	_tmp23 = NULL;
-	((ValaCCodeBaseModule*) self)->current_type_symbol = (_tmp24 = (_tmp23 = old_type_symbol, (_tmp23 == NULL) ? NULL : vala_code_node_ref (_tmp23)), (((ValaCCodeBaseModule*) self)->current_type_symbol == NULL) ? NULL : (((ValaCCodeBaseModule*) self)->current_type_symbol = (vala_code_node_unref (((ValaCCodeBaseModule*) self)->current_type_symbol), NULL)), _tmp24);
-	_tmp26 = NULL;
 	_tmp25 = NULL;
-	((ValaCCodeBaseModule*) self)->instance_struct = (_tmp26 = (_tmp25 = old_instance_struct, (_tmp25 == NULL) ? NULL : vala_ccode_node_ref (_tmp25)), (((ValaCCodeBaseModule*) self)->instance_struct == NULL) ? NULL : (((ValaCCodeBaseModule*) self)->instance_struct = (vala_ccode_node_unref (((ValaCCodeBaseModule*) self)->instance_struct), NULL)), _tmp26);
-	_tmp28 = NULL;
+	_tmp24 = NULL;
+	((ValaCCodeBaseModule*) self)->current_type_symbol = (_tmp25 = (_tmp24 = old_type_symbol, (_tmp24 == NULL) ? NULL : vala_code_node_ref (_tmp24)), (((ValaCCodeBaseModule*) self)->current_type_symbol == NULL) ? NULL : (((ValaCCodeBaseModule*) self)->current_type_symbol = (vala_code_node_unref (((ValaCCodeBaseModule*) self)->current_type_symbol), NULL)), _tmp25);
 	_tmp27 = NULL;
-	((ValaCCodeBaseModule*) self)->instance_finalize_fragment = (_tmp28 = (_tmp27 = old_instance_finalize_fragment, (_tmp27 == NULL) ? NULL : vala_ccode_node_ref (_tmp27)), (((ValaCCodeBaseModule*) self)->instance_finalize_fragment == NULL) ? NULL : (((ValaCCodeBaseModule*) self)->instance_finalize_fragment = (vala_ccode_node_unref (((ValaCCodeBaseModule*) self)->instance_finalize_fragment), NULL)), _tmp28);
+	_tmp26 = NULL;
+	((ValaCCodeBaseModule*) self)->instance_struct = (_tmp27 = (_tmp26 = old_instance_struct, (_tmp26 == NULL) ? NULL : vala_ccode_node_ref (_tmp26)), (((ValaCCodeBaseModule*) self)->instance_struct == NULL) ? NULL : (((ValaCCodeBaseModule*) self)->instance_struct = (vala_ccode_node_unref (((ValaCCodeBaseModule*) self)->instance_struct), NULL)), _tmp27);
+	_tmp29 = NULL;
+	_tmp28 = NULL;
+	((ValaCCodeBaseModule*) self)->instance_finalize_fragment = (_tmp29 = (_tmp28 = old_instance_finalize_fragment, (_tmp28 == NULL) ? NULL : vala_ccode_node_ref (_tmp28)), (((ValaCCodeBaseModule*) self)->instance_finalize_fragment == NULL) ? NULL : (((ValaCCodeBaseModule*) self)->instance_finalize_fragment = (vala_ccode_node_unref (((ValaCCodeBaseModule*) self)->instance_finalize_fragment), NULL)), _tmp29);
 	(old_type_symbol == NULL) ? NULL : (old_type_symbol = (vala_code_node_unref (old_type_symbol), NULL));
 	(old_instance_struct == NULL) ? NULL : (old_instance_struct = (vala_ccode_node_unref (old_instance_struct), NULL));
 	(old_instance_finalize_fragment == NULL) ? NULL : (old_instance_finalize_fragment = (vala_ccode_node_unref (old_instance_finalize_fragment), NULL));
@@ -267,7 +275,7 @@ static void vala_ccode_struct_module_add_struct_dup_function (ValaCCodeStructMod
 	_tmp12 = NULL;
 	cdecl_ = (_tmp12 = vala_ccode_declaration_new (_tmp11 = g_strconcat (_tmp10 = vala_typesymbol_get_cname ((ValaTypeSymbol*) st, FALSE), "*", NULL)), _tmp11 = (g_free (_tmp11), NULL), _tmp10 = (g_free (_tmp10), NULL), _tmp12);
 	_tmp13 = NULL;
-	vala_ccode_declaration_add_declarator (cdecl_, (ValaCCodeDeclarator*) (_tmp13 = vala_ccode_variable_declarator_new ("dup")));
+	vala_ccode_declaration_add_declarator (cdecl_, (ValaCCodeDeclarator*) (_tmp13 = vala_ccode_variable_declarator_new ("dup", NULL)));
 	(_tmp13 == NULL) ? NULL : (_tmp13 = (vala_ccode_node_unref (_tmp13), NULL));
 	vala_ccode_block_add_statement (cblock, (ValaCCodeNode*) cdecl_);
 	_tmp14 = NULL;
