@@ -26,13 +26,13 @@
 #include <glib.h>
 #include <glib-object.h>
 #include <vala/valaclass.h>
+#include <vala/valacodecontext.h>
 #include <vala/valatypesymbol.h>
 #include <stdlib.h>
 #include <string.h>
 #include <vala/valasymbol.h>
 #include <ccode/valaccodefragment.h>
 #include <gobject/valatyperegisterfunction.h>
-#include <gobject/valaccodegenerator.h>
 
 G_BEGIN_DECLS
 
@@ -61,8 +61,8 @@ struct _ValaClassRegisterFunctionClass {
 };
 
 
-ValaClassRegisterFunction* vala_class_register_function_construct (GType object_type, ValaClass* cl, ValaCCodeGenerator* codegen);
-ValaClassRegisterFunction* vala_class_register_function_new (ValaClass* cl, ValaCCodeGenerator* codegen);
+ValaClassRegisterFunction* vala_class_register_function_construct (GType object_type, ValaClass* cl, ValaCodeContext* context);
+ValaClassRegisterFunction* vala_class_register_function_new (ValaClass* cl, ValaCodeContext* context);
 ValaClass* vala_class_register_function_get_class_reference (ValaClassRegisterFunction* self);
 void vala_class_register_function_set_class_reference (ValaClassRegisterFunction* self, ValaClass* value);
 GType vala_class_register_function_get_type (void);
