@@ -36,6 +36,7 @@
 #include <ccode/valaccodenode.h>
 #include <ccode/valaccodetypedefinition.h>
 #include <ccode/valaccodevariabledeclarator.h>
+#include <ccode/valaccodeexpression.h>
 #include <ccode/valaccodedeclarator.h>
 #include <ccode/valaccodefunction.h>
 #include <gee/hashmap.h>
@@ -43,7 +44,6 @@
 #include <ccode/valaccodeblock.h>
 #include <ccode/valaccodefunctioncall.h>
 #include <ccode/valaccodeidentifier.h>
-#include <ccode/valaccodeexpression.h>
 #include <ccode/valaccodedeclaration.h>
 #include <ccode/valaccodeexpressionstatement.h>
 #include <ccode/valaccodeassignment.h>
@@ -221,7 +221,7 @@ static void vala_gasync_module_real_visit_method (ValaCCodeModule* base, ValaMet
 	_tmp15 = NULL;
 	_tmp14 = NULL;
 	_tmp13 = NULL;
-	vala_ccode_fragment_append (((ValaCCodeBaseModule*) self)->source_type_declaration, (ValaCCodeNode*) (_tmp15 = vala_ccode_type_definition_new (_tmp13 = g_strconcat ("struct _", dataname, NULL), (ValaCCodeDeclarator*) (_tmp14 = vala_ccode_variable_declarator_new (dataname)))));
+	vala_ccode_fragment_append (((ValaCCodeBaseModule*) self)->source_type_declaration, (ValaCCodeNode*) (_tmp15 = vala_ccode_type_definition_new (_tmp13 = g_strconcat ("struct _", dataname, NULL), (ValaCCodeDeclarator*) (_tmp14 = vala_ccode_variable_declarator_new (dataname, NULL)))));
 	(_tmp15 == NULL) ? NULL : (_tmp15 = (vala_ccode_node_unref (_tmp15), NULL));
 	(_tmp14 == NULL) ? NULL : (_tmp14 = (vala_ccode_node_unref (_tmp14), NULL));
 	_tmp13 = (g_free (_tmp13), NULL);
@@ -243,7 +243,7 @@ static void vala_gasync_module_real_visit_method (ValaCCodeModule* base, ValaMet
 	_tmp23 = NULL;
 	datadecl = (_tmp23 = vala_ccode_declaration_new (_tmp22 = g_strconcat (dataname, "*", NULL)), _tmp22 = (g_free (_tmp22), NULL), _tmp23);
 	_tmp24 = NULL;
-	vala_ccode_declaration_add_declarator (datadecl, (ValaCCodeDeclarator*) (_tmp24 = vala_ccode_variable_declarator_new ("data")));
+	vala_ccode_declaration_add_declarator (datadecl, (ValaCCodeDeclarator*) (_tmp24 = vala_ccode_variable_declarator_new ("data", NULL)));
 	(_tmp24 == NULL) ? NULL : (_tmp24 = (vala_ccode_node_unref (_tmp24), NULL));
 	vala_ccode_block_add_statement (asyncblock, (ValaCCodeNode*) datadecl);
 	_tmp27 = NULL;
@@ -509,7 +509,7 @@ static void vala_gasync_module_real_visit_method (ValaCCodeModule* base, ValaMet
 		datadecl = (_tmp87 = vala_ccode_declaration_new (_tmp86 = g_strconcat (dataname, "*", NULL)), (datadecl == NULL) ? NULL : (datadecl = (vala_ccode_node_unref (datadecl), NULL)), _tmp87);
 		_tmp86 = (g_free (_tmp86), NULL);
 		_tmp88 = NULL;
-		vala_ccode_declaration_add_declarator (datadecl, (ValaCCodeDeclarator*) (_tmp88 = vala_ccode_variable_declarator_new ("data")));
+		vala_ccode_declaration_add_declarator (datadecl, (ValaCCodeDeclarator*) (_tmp88 = vala_ccode_variable_declarator_new ("data", NULL)));
 		(_tmp88 == NULL) ? NULL : (_tmp88 = (vala_ccode_node_unref (_tmp88), NULL));
 		vala_ccode_block_add_statement (readyblock, (ValaCCodeNode*) datadecl);
 		_tmp92 = NULL;
