@@ -75,6 +75,7 @@ static gboolean vala_gir_writer_check_accessibility (ValaGIRWriter* self, ValaSy
 static gpointer vala_gir_writer_parent_class = NULL;
 static void vala_gir_writer_finalize (ValaCodeVisitor* obj);
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
+static gint _vala_array_length (gpointer array);
 
 
 
@@ -366,7 +367,7 @@ static void vala_gir_writer_real_visit_enum_value (ValaCodeVisitor* base, ValaEn
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	_tmp0 = NULL;
-	fprintf (self->priv->stream, "<member name=\"%s\"/>\n", _tmp3 = g_strjoinv ("-", (_tmp2 = _tmp1 = g_strsplit (_tmp0 = g_utf8_strdown (vala_symbol_get_name ((ValaSymbol*) ev), -1), "_", 0), _tmp2_length1 = g_strv_length (_tmp1), _tmp2)));
+	fprintf (self->priv->stream, "<member name=\"%s\"/>\n", _tmp3 = g_strjoinv ("-", (_tmp2 = _tmp1 = g_strsplit (_tmp0 = g_utf8_strdown (vala_symbol_get_name ((ValaSymbol*) ev), -1), "_", 0), _tmp2_length1 = _vala_array_length (_tmp1), _tmp2)));
 	_tmp3 = (g_free (_tmp3), NULL);
 	_tmp2 = (_vala_array_free (_tmp2, _tmp2_length1, (GDestroyNotify) g_free), NULL);
 	_tmp0 = (g_free (_tmp0), NULL);
@@ -860,5 +861,17 @@ static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify
 }
 
 
+static gint _vala_array_length (gpointer array) {
+	int length;
+	length = 0;
+	if (array) {
+		while (((gpointer*) array)[length]) {
+			length++;
+		}
+	}
+	return length;
+}
+
+
 
 
