@@ -154,7 +154,7 @@ void vala_typeregister_function_init_from_type (ValaTypeRegisterFunction* self,
 		_tmp9 = NULL;
 		_tmp8 = NULL;
 		_tmp7 = NULL;
-		vala_ccode_declaration_add_declarator (cdecl_, (ValaCCodeDeclarator*) (_tmp9 = vala_ccode_variable_declarator_new_with_initializer (_tmp7 = g_strconcat (type_id_name, "__volatile", NULL), (ValaCCodeExpression*) (_tmp8 = vala_ccode_constant_new ("0")))));
+		vala_ccode_declaration_add_declarator (cdecl_, (ValaCCodeDeclarator*) (_tmp9 = vala_ccode_variable_declarator_new (_tmp7 = g_strconcat (type_id_name, "__volatile", NULL), (ValaCCodeExpression*) (_tmp8 = vala_ccode_constant_new ("0")))));
 		(_tmp9 == NULL) ? NULL : (_tmp9 = (vala_ccode_node_unref (_tmp9), NULL));
 		(_tmp8 == NULL) ? NULL : (_tmp8 = (vala_ccode_node_unref (_tmp8), NULL));
 		_tmp7 = (g_free (_tmp7), NULL);
@@ -166,7 +166,7 @@ void vala_typeregister_function_init_from_type (ValaTypeRegisterFunction* self,
 		cdecl_ = (_tmp10 = vala_ccode_declaration_new ("GType"), (cdecl_ == NULL) ? NULL : (cdecl_ = (vala_ccode_node_unref (cdecl_), NULL)), _tmp10);
 		_tmp12 = NULL;
 		_tmp11 = NULL;
-		vala_ccode_declaration_add_declarator (cdecl_, (ValaCCodeDeclarator*) (_tmp12 = vala_ccode_variable_declarator_new_with_initializer (type_id_name, (ValaCCodeExpression*) (_tmp11 = vala_ccode_constant_new ("0")))));
+		vala_ccode_declaration_add_declarator (cdecl_, (ValaCCodeDeclarator*) (_tmp12 = vala_ccode_variable_declarator_new (type_id_name, (ValaCCodeExpression*) (_tmp11 = vala_ccode_constant_new ("0")))));
 		(_tmp12 == NULL) ? NULL : (_tmp12 = (vala_ccode_node_unref (_tmp12), NULL));
 		(_tmp11 == NULL) ? NULL : (_tmp11 = (vala_ccode_node_unref (_tmp11), NULL));
 	}
@@ -270,7 +270,7 @@ void vala_typeregister_function_init_from_type (ValaTypeRegisterFunction* self,
 		_tmp32 = NULL;
 		_tmp31 = NULL;
 		_tmp30 = NULL;
-		vala_ccode_declaration_add_declarator (cgtypetabledecl, (ValaCCodeDeclarator*) (_tmp38 = vala_ccode_variable_declarator_new_with_initializer ("g_define_type_value_table", (ValaCCodeExpression*) (_tmp37 = vala_ccode_constant_new (_tmp36 = g_strdup_printf ("{ %s, %s, %s, %s, \"p\", %s, \"p\", %s }", _tmp30 = vala_typeregister_function_get_gtype_value_table_init_function_name (self), _tmp31 = vala_typeregister_function_get_gtype_value_table_free_function_name (self), _tmp32 = vala_typeregister_function_get_gtype_value_table_copy_function_name (self), _tmp33 = vala_typeregister_function_get_gtype_value_table_peek_pointer_function_name (self), _tmp34 = vala_typeregister_function_get_gtype_value_table_collect_value_function_name (self), _tmp35 = vala_typeregister_function_get_gtype_value_table_lcopy_value_function_name (self)))))));
+		vala_ccode_declaration_add_declarator (cgtypetabledecl, (ValaCCodeDeclarator*) (_tmp38 = vala_ccode_variable_declarator_new ("g_define_type_value_table", (ValaCCodeExpression*) (_tmp37 = vala_ccode_constant_new (_tmp36 = g_strdup_printf ("{ %s, %s, %s, %s, \"p\", %s, \"p\", %s }", _tmp30 = vala_typeregister_function_get_gtype_value_table_init_function_name (self), _tmp31 = vala_typeregister_function_get_gtype_value_table_free_function_name (self), _tmp32 = vala_typeregister_function_get_gtype_value_table_copy_function_name (self), _tmp33 = vala_typeregister_function_get_gtype_value_table_peek_pointer_function_name (self), _tmp34 = vala_typeregister_function_get_gtype_value_table_collect_value_function_name (self), _tmp35 = vala_typeregister_function_get_gtype_value_table_lcopy_value_function_name (self)))))));
 		(_tmp38 == NULL) ? NULL : (_tmp38 = (vala_ccode_node_unref (_tmp38), NULL));
 		(_tmp37 == NULL) ? NULL : (_tmp37 = (vala_ccode_node_unref (_tmp37), NULL));
 		_tmp36 = (g_free (_tmp36), NULL);
@@ -323,7 +323,7 @@ void vala_typeregister_function_init_from_type (ValaTypeRegisterFunction* self,
 		_tmp48 = NULL;
 		_tmp47 = NULL;
 		_tmp46 = NULL;
-		vala_ccode_declaration_add_declarator (ctypedecl, (ValaCCodeDeclarator*) (_tmp54 = vala_ccode_variable_declarator_new_with_initializer ("g_define_type_info", (ValaCCodeExpression*) (_tmp53 = vala_ccode_constant_new (_tmp52 = g_strdup_printf ("{ sizeof (%s), (GBaseInitFunc) %s, (GBaseFinalizeFunc) %s, (GClassInitFunc) %s, (GClassFinalizeFunc) %s, NULL, %s, 0, (GInstanceInitFunc) %s, %s }", _tmp46 = vala_typeregister_function_get_type_struct_name (self), _tmp47 = vala_typeregister_function_get_base_init_func_name (self), _tmp43, _tmp48 = vala_typeregister_function_get_class_init_func_name (self), _tmp49 = vala_typeregister_function_get_class_finalize_func_name (self), _tmp50 = vala_typeregister_function_get_instance_struct_size (self), _tmp51 = vala_typeregister_function_get_instance_init_func_name (self), type_value_table_decl_name))))));
+		vala_ccode_declaration_add_declarator (ctypedecl, (ValaCCodeDeclarator*) (_tmp54 = vala_ccode_variable_declarator_new ("g_define_type_info", (ValaCCodeExpression*) (_tmp53 = vala_ccode_constant_new (_tmp52 = g_strdup_printf ("{ sizeof (%s), (GBaseInitFunc) %s, (GBaseFinalizeFunc) %s, (GClassInitFunc) %s, (GClassFinalizeFunc) %s, NULL, %s, 0, (GInstanceInitFunc) %s, %s }", _tmp46 = vala_typeregister_function_get_type_struct_name (self), _tmp47 = vala_typeregister_function_get_base_init_func_name (self), _tmp43, _tmp48 = vala_typeregister_function_get_class_init_func_name (self), _tmp49 = vala_typeregister_function_get_class_finalize_func_name (self), _tmp50 = vala_typeregister_function_get_instance_struct_size (self), _tmp51 = vala_typeregister_function_get_instance_init_func_name (self), type_value_table_decl_name))))));
 		(_tmp54 == NULL) ? NULL : (_tmp54 = (vala_ccode_node_unref (_tmp54), NULL));
 		(_tmp53 == NULL) ? NULL : (_tmp53 = (vala_ccode_node_unref (_tmp53), NULL));
 		_tmp52 = (g_free (_tmp52), NULL);
@@ -342,7 +342,7 @@ void vala_typeregister_function_init_from_type (ValaTypeRegisterFunction* self,
 			vala_ccode_declaration_set_modifiers (ctypefundamentaldecl, VALA_CCODE_MODIFIERS_STATIC);
 			_tmp56 = NULL;
 			_tmp55 = NULL;
-			vala_ccode_declaration_add_declarator (ctypefundamentaldecl, (ValaCCodeDeclarator*) (_tmp56 = vala_ccode_variable_declarator_new_with_initializer ("g_define_type_fundamental_info", (ValaCCodeExpression*) (_tmp55 = vala_ccode_constant_new ("{ (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) }")))));
+			vala_ccode_declaration_add_declarator (ctypefundamentaldecl, (ValaCCodeDeclarator*) (_tmp56 = vala_ccode_variable_declarator_new ("g_define_type_fundamental_info", (ValaCCodeExpression*) (_tmp55 = vala_ccode_constant_new ("{ (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) }")))));
 			(_tmp56 == NULL) ? NULL : (_tmp56 = (vala_ccode_node_unref (_tmp56), NULL));
 			(_tmp55 == NULL) ? NULL : (_tmp55 = (vala_ccode_node_unref (_tmp55), NULL));
 			vala_ccode_block_add_statement (type_init, (ValaCCodeNode*) ctypefundamentaldecl);
@@ -536,7 +536,7 @@ void vala_typeregister_function_init_from_type (ValaTypeRegisterFunction* self,
 		ValaCCodeVariableDeclarator* _tmp107;
 		temp_decl = vala_ccode_declaration_new ("GType");
 		_tmp107 = NULL;
-		vala_ccode_declaration_add_declarator (temp_decl, (ValaCCodeDeclarator*) (_tmp107 = vala_ccode_variable_declarator_new_with_initializer (type_id_name, (ValaCCodeExpression*) reg_call)));
+		vala_ccode_declaration_add_declarator (temp_decl, (ValaCCodeDeclarator*) (_tmp107 = vala_ccode_variable_declarator_new (type_id_name, (ValaCCodeExpression*) reg_call)));
 		(_tmp107 == NULL) ? NULL : (_tmp107 = (vala_ccode_node_unref (_tmp107), NULL));
 		vala_ccode_block_add_statement (type_init, (ValaCCodeNode*) temp_decl);
 		(temp_decl == NULL) ? NULL : (temp_decl = (vala_ccode_node_unref (temp_decl), NULL));
