@@ -1,6 +1,6 @@
 /* valacharacterliteral.vala
  *
- * Copyright (C) 2006-2008  Jürg Billeter, Raffaele Sandrini
+ * Copyright (C) 2006-2009  Jürg Billeter, Raffaele Sandrini
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -26,10 +26,10 @@
 #include <vala/valacodevisitor.h>
 #include <vala/valaexpression.h>
 #include <vala/valasemanticanalyzer.h>
-#include <vala/valavaluetype.h>
+#include <vala/valaintegertype.h>
 #include <vala/valasymbol.h>
 #include <vala/valascope.h>
-#include <vala/valatypesymbol.h>
+#include <vala/valastruct.h>
 
 
 
@@ -103,8 +103,8 @@ static gboolean vala_character_literal_real_is_pure (ValaExpression* base) {
 
 static gboolean vala_character_literal_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer) {
 	ValaCharacterLiteral * self;
-	ValaValueType* _tmp2;
-	ValaTypeSymbol* _tmp1;
+	ValaIntegerType* _tmp2;
+	ValaStruct* _tmp1;
 	self = (ValaCharacterLiteral*) base;
 	g_return_val_if_fail (analyzer != NULL, FALSE);
 	if (vala_code_node_get_checked ((ValaCodeNode*) self)) {
@@ -113,7 +113,7 @@ static gboolean vala_character_literal_real_check (ValaCodeNode* base, ValaSeman
 	vala_code_node_set_checked ((ValaCodeNode*) self, TRUE);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	vala_expression_set_value_type ((ValaExpression*) self, (ValaDataType*) (_tmp2 = vala_value_type_new (_tmp1 = VALA_TYPESYMBOL (vala_scope_lookup (vala_symbol_get_scope (analyzer->root_symbol), "char")))));
+	vala_expression_set_value_type ((ValaExpression*) self, (ValaDataType*) (_tmp2 = vala_integer_type_new (_tmp1 = VALA_STRUCT (vala_scope_lookup (vala_symbol_get_scope (analyzer->root_symbol), "char")), NULL, NULL)));
 	(_tmp2 == NULL) ? NULL : (_tmp2 = (vala_code_node_unref (_tmp2), NULL));
 	(_tmp1 == NULL) ? NULL : (_tmp1 = (vala_code_node_unref (_tmp1), NULL));
 	return !vala_code_node_get_error ((ValaCodeNode*) self);
