@@ -45,10 +45,12 @@ struct _ValaCodeContextPrivate {
 	gboolean _memory_management;
 	gboolean _assert;
 	gboolean _checking;
-	gboolean _non_null;
+	gboolean _deprecated;
+	gboolean _experimental;
 	gboolean _non_null_experimental;
 	gboolean _dbus_transformation;
 	gboolean _ccode_only;
+	char* _header_filename;
 	gboolean _compile_only;
 	char* _output;
 	char* _basedir;
@@ -76,6 +78,7 @@ static ValaSourceFile* vala_code_context_find_cycle_head (ValaCodeContext* self,
 static void vala_code_context_visit (ValaCodeContext* self, ValaSourceFile* file, GeeList* chain);
 static gpointer vala_code_context_parent_class = NULL;
 static void vala_code_context_finalize (ValaCodeContext* obj);
+static gint _vala_array_length (gpointer array);
 
 
 
@@ -556,8 +559,8 @@ char* vala_code_context_get_package_path (ValaCodeContext* self, const char* pkg
 		int vapidir_it;
 		_tmp5 = NULL;
 		vapidir_collection = _tmp5 = g_get_system_data_dirs ();
-		vapidir_collection_length1 = g_strv_length (_tmp5);
-		for (vapidir_it = 0; vapidir_it < g_strv_length (_tmp5); vapidir_it = vapidir_it + 1) {
+		vapidir_collection_length1 = _vala_array_length (_tmp5);
+		for (vapidir_it = 0; vapidir_it < _vala_array_length (_tmp5); vapidir_it = vapidir_it + 1) {
 			const char* _tmp8;
 			char* vapidir;
 			_tmp8 = NULL;
@@ -632,15 +635,27 @@ void vala_code_context_set_checking (ValaCodeContext* self, gboolean value) {
 }
 
 
-gboolean vala_code_context_get_non_null (ValaCodeContext* self) {
+gboolean vala_code_context_get_deprecated (ValaCodeContext* self) {
 	g_return_val_if_fail (self != NULL, FALSE);
-	return self->priv->_non_null;
+	return self->priv->_deprecated;
 }
 
 
-void vala_code_context_set_non_null (ValaCodeContext* self, gboolean value) {
+void vala_code_context_set_deprecated (ValaCodeContext* self, gboolean value) {
 	g_return_if_fail (self != NULL);
-	self->priv->_non_null = value;
+	self->priv->_deprecated = value;
+}
+
+
+gboolean vala_code_context_get_experimental (ValaCodeContext* self) {
+	g_return_val_if_fail (self != NULL, FALSE);
+	return self->priv->_experimental;
+}
+
+
+void vala_code_context_set_experimental (ValaCodeContext* self, gboolean value) {
+	g_return_if_fail (self != NULL);
+	self->priv->_experimental = value;
 }
 
 
@@ -680,6 +695,22 @@ void vala_code_context_set_ccode_only (ValaCodeContext* self, gboolean value) {
 }
 
 
+const char* vala_code_context_get_header_filename (ValaCodeContext* self) {
+	g_return_val_if_fail (self != NULL, NULL);
+	return self->priv->_header_filename;
+}
+
+
+void vala_code_context_set_header_filename (ValaCodeContext* self, const char* value) {
+	char* _tmp2;
+	const char* _tmp1;
+	g_return_if_fail (self != NULL);
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_header_filename = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : g_strdup (_tmp1)), self->priv->_header_filename = (g_free (self->priv->_header_filename), NULL), _tmp2);
+}
+
+
 gboolean vala_code_context_get_compile_only (ValaCodeContext* self) {
 	g_return_val_if_fail (self != NULL, FALSE);
 	return self->priv->_compile_only;
@@ -985,6 +1016,7 @@ static void vala_code_context_finalize (ValaCodeContext* obj) {
 	ValaCodeContext * self;
 	self = VALA_CODE_CONTEXT (obj);
 	self->priv->_library = (g_free (self->priv->_library), NULL);
+	self->priv->_header_filename = (g_free (self->priv->_header_filename), NULL);
 	self->priv->_output = (g_free (self->priv->_output), NULL);
 	self->priv->_basedir = (g_free (self->priv->_basedir), NULL);
 	self->priv->_directory = (g_free (self->priv->_directory), NULL);
@@ -1028,5 +1060,17 @@ void vala_code_context_unref (gpointer instance) {
 }
 
 
+static gint _vala_array_length (gpointer array) {
+	int length;
+	length = 0;
+	if (array) {
+		while (((gpointer*) array)[length]) {
+			length++;
+		}
+	}
+	return length;
+}
+
+
 
 
