@@ -93,6 +93,8 @@ gboolean vala_code_context_get_dbus_transformation (ValaCodeContext* self);
 void vala_code_context_set_dbus_transformation (ValaCodeContext* self, gboolean value);
 gboolean vala_code_context_get_ccode_only (ValaCodeContext* self);
 void vala_code_context_set_ccode_only (ValaCodeContext* self, gboolean value);
+const char* vala_code_context_get_header_filename (ValaCodeContext* self);
+void vala_code_context_set_header_filename (ValaCodeContext* self, const char* value);
 gboolean vala_code_context_get_compile_only (ValaCodeContext* self);
 void vala_code_context_set_compile_only (ValaCodeContext* self, gboolean value);
 const char* vala_code_context_get_output (ValaCodeContext* self);
