@@ -1,6 +1,7 @@
 /* valacreationmethod.vala
  *
- * Copyright (C) 2007-2008  Raffaele Sandrini, Jürg Billeter
+ * Copyright (C) 2007-2009  Jürg Billeter
+ * Copyright (C) 2007-2008  Raffaele Sandrini
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -252,7 +253,7 @@ static gboolean vala_creation_method_real_check (ValaCodeNode* base, ValaSemanti
 	vala_method_process_attributes ((ValaMethod*) self);
 	_tmp1 = FALSE;
 	if (self->priv->_type_name != NULL) {
-		_tmp1 = _vala_strcmp0 (self->priv->_type_name, vala_symbol_get_name (vala_semantic_analyzer_get_current_symbol (analyzer))) != 0;
+		_tmp1 = _vala_strcmp0 (self->priv->_type_name, vala_symbol_get_name (vala_symbol_get_parent_symbol ((ValaSymbol*) self))) != 0;
 	} else {
 		_tmp1 = FALSE;
 	}
