@@ -34,13 +34,13 @@
 #include <vala/valasourcereference.h>
 #include <vala/valascope.h>
 #include <vala/valasymbol.h>
+#include <vala/valagenerictype.h>
+#include <vala/valasemanticanalyzer.h>
+#include <vala/valastruct.h>
 #include <vala/valadelegatetype.h>
 #include <vala/valapointertype.h>
 #include <vala/valaarraytype.h>
 #include <vala/valaenum.h>
-#include <vala/valastruct.h>
-#include <vala/valagenerictype.h>
-#include <vala/valasemanticanalyzer.h>
 
 
 
@@ -59,7 +59,7 @@ struct _ValaDataTypePrivate {
 enum  {
 	VALA_DATA_TYPE_DUMMY_PROPERTY
 };
-static GeeList* vala_data_type__empty_type_list;
+static GeeList* vala_data_type__empty_type_list = NULL;
 static void vala_data_type_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static char* vala_data_type_real_get_cname (ValaDataType* self);
 static char* vala_data_type_real_get_lower_case_cname (ValaDataType* self, const char* infix);
@@ -520,8 +520,8 @@ static void vala_data_type_real_replace_type (ValaCodeNode* base, ValaDataType*
 				ValaDataType* _tmp0;
 				gboolean _tmp1;
 				_tmp0 = NULL;
-				if ((_tmp1 = (_tmp0 = (ValaDataType*) gee_list_get ((GeeList*) self->priv->type_argument_list, i)) == old_type, (_tmp0 == NULL) ? NULL : (_tmp0 = (vala_code_node_unref (_tmp0), NULL)), _tmp1)) {
-					gee_list_set ((GeeList*) self->priv->type_argument_list, i, new_type);
+				if ((_tmp1 = (_tmp0 = (ValaDataType*) gee_list_get (self->priv->type_argument_list, i)) == old_type, (_tmp0 == NULL) ? NULL : (_tmp0 = (vala_code_node_unref (_tmp0), NULL)), _tmp1)) {
+					gee_list_set (self->priv->type_argument_list, i, new_type);
 					return;
 				}
 			}
@@ -870,13 +870,26 @@ static char* vala_data_type_real_get_type_signature (ValaDataType* self) {
 	if (self->priv->_data_type != NULL) {
 		char* sig;
 		GeeList* type_args;
-		char* _tmp2;
+		gboolean _tmp0;
+		gboolean _tmp1;
+		char* _tmp4;
 		sig = vala_typesymbol_get_type_signature (self->priv->_data_type);
 		type_args = vala_data_type_get_type_arguments (self);
-		if (gee_collection_get_size ((GeeCollection*) type_args) > 0) {
+		_tmp0 = FALSE;
+		_tmp1 = FALSE;
+		if (sig != NULL) {
+			_tmp1 = strstr (sig, "%s") != NULL;
+		} else {
+			_tmp1 = FALSE;
+		}
+		if (_tmp1) {
+			_tmp0 = gee_collection_get_size ((GeeCollection*) type_args) > 0;
+		} else {
+			_tmp0 = FALSE;
+		}
+		if (_tmp0) {
 			char* element_sig;
-			char* _tmp1;
-			g_assert (strstr (sig, "%s") != NULL);
+			char* _tmp3;
 			element_sig = g_strdup ("");
 			{
 				GeeIterator* _type_arg_it;
@@ -887,21 +900,21 @@ static char* vala_data_type_real_get_type_signature (ValaDataType* self) {
 					type_arg = (ValaDataType*) gee_iterator_get (_type_arg_it);
 					s = vala_data_type_get_type_signature (type_arg);
 					if (s != NULL) {
-						char* _tmp0;
-						_tmp0 = NULL;
-						element_sig = (_tmp0 = g_strconcat (element_sig, (s), NULL), element_sig = (g_free (element_sig), NULL), _tmp0);
+						char* _tmp2;
+						_tmp2 = NULL;
+						element_sig = (_tmp2 = g_strconcat (element_sig, (s), NULL), element_sig = (g_free (element_sig), NULL), _tmp2);
 					}
 					(type_arg == NULL) ? NULL : (type_arg = (vala_code_node_unref (type_arg), NULL));
 					s = (g_free (s), NULL);
 				}
 				(_type_arg_it == NULL) ? NULL : (_type_arg_it = (gee_collection_object_unref (_type_arg_it), NULL));
 			}
-			_tmp1 = NULL;
-			sig = (_tmp1 = g_strdup_printf (sig, element_sig), sig = (g_free (sig), NULL), _tmp1);
+			_tmp3 = NULL;
+			sig = (_tmp3 = g_strdup_printf (sig, element_sig), sig = (g_free (sig), NULL), _tmp3);
 			element_sig = (g_free (element_sig), NULL);
 		}
-		_tmp2 = NULL;
-		return (_tmp2 = sig, (type_args == NULL) ? NULL : (type_args = (gee_collection_object_unref (type_args), NULL)), _tmp2);
+		_tmp4 = NULL;
+		return (_tmp4 = sig, (type_args == NULL) ? NULL : (type_args = (gee_collection_object_unref (type_args), NULL)), _tmp4);
 	} else {
 		return NULL;
 	}
@@ -965,7 +978,7 @@ ValaDataType* vala_data_type_get_actual_type (ValaDataType* self, ValaDataType*
 					ValaDataType* _tmp5;
 					_tmp6 = NULL;
 					_tmp5 = NULL;
-					gee_list_set ((GeeList*) result->priv->type_argument_list, i, _tmp6 = vala_data_type_get_actual_type (_tmp5 = (ValaDataType*) gee_list_get ((GeeList*) result->priv->type_argument_list, i), derived_instance_type, node_reference));
+					gee_list_set (result->priv->type_argument_list, i, _tmp6 = vala_data_type_get_actual_type (_tmp5 = (ValaDataType*) gee_list_get (result->priv->type_argument_list, i), derived_instance_type, node_reference));
 					(_tmp6 == NULL) ? NULL : (_tmp6 = (vala_code_node_unref (_tmp6), NULL));
 					(_tmp5 == NULL) ? NULL : (_tmp5 = (vala_code_node_unref (_tmp5), NULL));
 				}
