@@ -76,6 +76,7 @@ static gboolean vala_delegate_real_check (ValaCodeNode* base, ValaSemanticAnalyz
 static gpointer vala_delegate_parent_class = NULL;
 static void vala_delegate_finalize (ValaCodeNode* obj);
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
+static gint _vala_array_length (gpointer array);
 static int _vala_strcmp0 (const char * str1, const char * str2);
 
 
@@ -259,6 +260,21 @@ static void vala_delegate_real_accept_children (ValaCodeNode* base, ValaCodeVisi
 		}
 		(_param_it == NULL) ? NULL : (_param_it = (gee_collection_object_unref (_param_it), NULL));
 	}
+	{
+		GeeList* _tmp0;
+		GeeIterator* _tmp1;
+		GeeIterator* _error_type_it;
+		_tmp0 = NULL;
+		_tmp1 = NULL;
+		_error_type_it = (_tmp1 = gee_iterable_iterator ((GeeIterable*) (_tmp0 = vala_code_node_get_error_types ((ValaCodeNode*) self))), (_tmp0 == NULL) ? NULL : (_tmp0 = (gee_collection_object_unref (_tmp0), NULL)), _tmp1);
+		while (gee_iterator_next (_error_type_it)) {
+			ValaDataType* error_type;
+			error_type = (ValaDataType*) gee_iterator_get (_error_type_it);
+			vala_code_node_accept ((ValaCodeNode*) error_type, visitor);
+			(error_type == NULL) ? NULL : (error_type = (vala_code_node_unref (error_type), NULL));
+		}
+		(_error_type_it == NULL) ? NULL : (_error_type_it = (gee_collection_object_unref (_error_type_it), NULL));
+	}
 }
 
 
@@ -329,8 +345,8 @@ static void vala_delegate_process_ccode_attribute (ValaDelegate* self, ValaAttri
 			int filename_it;
 			_tmp1 = NULL;
 			filename_collection = _tmp1 = g_strsplit (val, ",", 0);
-			filename_collection_length1 = g_strv_length (_tmp1);
-			for (filename_it = 0; filename_it < g_strv_length (_tmp1); filename_it = filename_it + 1) {
+			filename_collection_length1 = _vala_array_length (_tmp1);
+			for (filename_it = 0; filename_it < _vala_array_length (_tmp1); filename_it = filename_it + 1) {
 				const char* _tmp2;
 				char* filename;
 				_tmp2 = NULL;
@@ -425,8 +441,8 @@ static void vala_delegate_real_replace_type (ValaCodeNode* base, ValaDataType* o
 			ValaDataType* _tmp0;
 			gboolean _tmp1;
 			_tmp0 = NULL;
-			if ((_tmp1 = (_tmp0 = (ValaDataType*) gee_list_get ((GeeList*) error_types, i)) == old_type, (_tmp0 == NULL) ? NULL : (_tmp0 = (vala_code_node_unref (_tmp0), NULL)), _tmp1)) {
-				gee_list_set ((GeeList*) error_types, i, new_type);
+			if ((_tmp1 = (_tmp0 = (ValaDataType*) gee_list_get (error_types, i)) == old_type, (_tmp0 == NULL) ? NULL : (_tmp0 = (vala_code_node_unref (_tmp0), NULL)), _tmp1)) {
+				gee_list_set (error_types, i, new_type);
 				(error_types == NULL) ? NULL : (error_types = (gee_collection_object_unref (error_types), NULL));
 				return;
 			}
@@ -754,6 +770,18 @@ static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify
 }
 
 
+static gint _vala_array_length (gpointer array) {
+	int length;
+	length = 0;
+	if (array) {
+		while (((gpointer*) array)[length]) {
+			length++;
+		}
+	}
+	return length;
+}
+
+
 static int _vala_strcmp0 (const char * str1, const char * str2) {
 	if (str1 == NULL) {
 		return -(str1 != str2);
