@@ -26,6 +26,7 @@
 #include <glib.h>
 #include <glib-object.h>
 #include <vala/valasymbol.h>
+#include <vala/valamember.h>
 #include <vala/valacodenode.h>
 
 G_BEGIN_DECLS
@@ -47,17 +48,20 @@ struct _ValaDestructor {
 	ValaSymbol parent_instance;
 	ValaDestructorPrivate * priv;
 };
+
 struct _ValaDestructorClass {
 	ValaSymbolClass parent_class;
 };
 
+
+ValaDestructor* vala_destructor_construct (GType object_type, ValaSourceReference* source_reference);
 ValaDestructor* vala_destructor_new (ValaSourceReference* source_reference);
 ValaBlock* vala_destructor_get_body (ValaDestructor* self);
 void vala_destructor_set_body (ValaDestructor* self, ValaBlock* value);
 ValaFormalParameter* vala_destructor_get_this_parameter (ValaDestructor* self);
 void vala_destructor_set_this_parameter (ValaDestructor* self, ValaFormalParameter* value);
-gboolean vala_destructor_get_instance (ValaDestructor* self);
-void vala_destructor_set_instance (ValaDestructor* self, gboolean value);
+MemberBinding vala_destructor_get_binding (ValaDestructor* self);
+void vala_destructor_set_binding (ValaDestructor* self, MemberBinding value);
 GType vala_destructor_get_type (void);
 
 
