@@ -21,20 +21,20 @@
  */
 
 #include <vala/valaenum.h>
-#include <gee/arraylist.h>
-#include <gee/collection.h>
 #include <gee/iterable.h>
 #include <gee/iterator.h>
+#include <gee/arraylist.h>
+#include <gee/collection.h>
 #include <gee/readonlylist.h>
 #include <vala/valasymbol.h>
-#include <vala/valaenumvalue.h>
-#include <vala/valamethod.h>
-#include <vala/valasourcereference.h>
-#include <vala/valascope.h>
 #include <vala/valacodevisitor.h>
 #include <vala/valasemanticanalyzer.h>
 #include <vala/valaattribute.h>
 #include <vala/valasourcefile.h>
+#include <vala/valasourcereference.h>
+#include <vala/valaenumvalue.h>
+#include <vala/valamethod.h>
+#include <vala/valascope.h>
 #include <vala/valacreationmethod.h>
 #include <vala/valareport.h>
 #include <vala/valamember.h>
@@ -80,6 +80,7 @@ static gboolean vala_enum_real_check (ValaCodeNode* base, ValaSemanticAnalyzer*
 static gpointer vala_enum_parent_class = NULL;
 static void vala_enum_finalize (ValaCodeNode* obj);
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
+static gint _vala_array_length (gpointer array);
 static int _vala_strcmp0 (const char * str1, const char * str2);
 
 
@@ -357,8 +358,8 @@ static void vala_enum_process_ccode_attribute (ValaEnum* self, ValaAttribute* a)
 			int filename_it;
 			_tmp2 = NULL;
 			filename_collection = _tmp2 = g_strsplit (val, ",", 0);
-			filename_collection_length1 = g_strv_length (_tmp2);
-			for (filename_it = 0; filename_it < g_strv_length (_tmp2); filename_it = filename_it + 1) {
+			filename_collection_length1 = _vala_array_length (_tmp2);
+			for (filename_it = 0; filename_it < _vala_array_length (_tmp2); filename_it = filename_it + 1) {
 				const char* _tmp3;
 				char* filename;
 				_tmp3 = NULL;
@@ -660,6 +661,18 @@ static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify
 }
 
 
+static gint _vala_array_length (gpointer array) {
+	int length;
+	length = 0;
+	if (array) {
+		while (((gpointer*) array)[length]) {
+			length++;
+		}
+	}
+	return length;
+}
+
+
 static int _vala_strcmp0 (const char * str1, const char * str2) {
 	if (str1 == NULL) {
 		return -(str1 != str2);
