@@ -27,7 +27,7 @@
 #include <glib-object.h>
 #include <stdlib.h>
 #include <string.h>
-#include <vala/valasymbol.h>
+#include <vala/valatypesymbol.h>
 #include <vala/valacodenode.h>
 
 G_BEGIN_DECLS
@@ -46,12 +46,12 @@ typedef struct _ValaErrorCodePrivate ValaErrorCodePrivate;
  * Represents an enum member in the source code.
  */
 struct _ValaErrorCode {
-	ValaSymbol parent_instance;
+	ValaTypeSymbol parent_instance;
 	ValaErrorCodePrivate * priv;
 };
 
 struct _ValaErrorCodeClass {
-	ValaSymbolClass parent_class;
+	ValaTypeSymbolClass parent_class;
 };
 
 
@@ -59,7 +59,6 @@ ValaErrorCode* vala_error_code_construct (GType object_type, const char* name, V
 ValaErrorCode* vala_error_code_new (const char* name, ValaSourceReference* source_reference);
 ValaErrorCode* vala_error_code_construct_with_value (GType object_type, const char* name, ValaExpression* value, ValaSourceReference* source_reference);
 ValaErrorCode* vala_error_code_new_with_value (const char* name, ValaExpression* value, ValaSourceReference* source_reference);
-char* vala_error_code_get_cname (ValaErrorCode* self);
 ValaExpression* vala_error_code_get_value (ValaErrorCode* self);
 void vala_error_code_set_value (ValaErrorCode* self, ValaExpression* value);
 GType vala_error_code_get_type (void);
