@@ -33,7 +33,6 @@
 #include <vala/valainterface.h>
 #include <vala/valaclass.h>
 #include <vala/valavaluetype.h>
-#include <vala/valanamespace.h>
 #include <vala/valastringliteral.h>
 
 
@@ -45,6 +44,7 @@ struct _ValaFieldPrivate {
 	gboolean _no_array_length;
 	gboolean _array_null_terminated;
 	char* array_length_cname;
+	char* array_length_cexpr;
 	char* cname;
 	gboolean lock_used;
 	ValaExpression* _initializer;
@@ -201,6 +201,35 @@ void vala_field_set_array_length_cname (ValaField* self, const char* array_lengt
 }
 
 
+/**
+ * Returns the array length expression as it is used in C code
+ *
+ * @return the array length expression to be used in C code
+ */
+char* vala_field_get_array_length_cexpr (ValaField* self) {
+	const char* _tmp0;
+	g_return_val_if_fail (self != NULL, NULL);
+	_tmp0 = NULL;
+	return (_tmp0 = self->priv->array_length_cexpr, (_tmp0 == NULL) ? NULL : g_strdup (_tmp0));
+}
+
+
+/**
+ * Sets the array length expression as it is used in C code
+ *
+ * @param array_length_cexpr the array length expression to be used in C
+ * code
+ */
+void vala_field_set_array_length_cexpr (ValaField* self, const char* array_length_cexpr) {
+	char* _tmp1;
+	const char* _tmp0;
+	g_return_if_fail (self != NULL);
+	_tmp1 = NULL;
+	_tmp0 = NULL;
+	self->priv->array_length_cexpr = (_tmp1 = (_tmp0 = array_length_cexpr, (_tmp0 == NULL) ? NULL : g_strdup (_tmp0)), self->priv->array_length_cexpr = (g_free (self->priv->array_length_cexpr), NULL), _tmp1);
+}
+
+
 static void vala_field_process_ccode_attribute (ValaField* self, ValaAttribute* a) {
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (a != NULL);
@@ -247,6 +276,12 @@ static void vala_field_process_ccode_attribute (ValaField* self, ValaAttribute*
 		vala_field_set_array_length_cname (self, _tmp3 = vala_attribute_get_string (a, "array_length_cname"));
 		_tmp3 = (g_free (_tmp3), NULL);
 	}
+	if (vala_attribute_has_argument (a, "array_length_cexpr")) {
+		char* _tmp4;
+		_tmp4 = NULL;
+		vala_field_set_array_length_cexpr (self, _tmp4 = vala_attribute_get_string (a, "array_length_cexpr"));
+		_tmp4 = (g_free (_tmp4), NULL);
+	}
 }
 
 
@@ -354,7 +389,9 @@ static gboolean vala_field_real_check (ValaCodeNode* base, ValaSemanticAnalyzer*
 	ValaField * self;
 	ValaSourceFile* _tmp1;
 	ValaSourceFile* old_source_file;
-	gboolean _tmp6;
+	ValaSymbol* _tmp2;
+	ValaSymbol* old_symbol;
+	gboolean _tmp7;
 	gboolean field_in_header;
 	gboolean _tmp11;
 	self = (ValaField*) base;
@@ -365,57 +402,60 @@ static gboolean vala_field_real_check (ValaCodeNode* base, ValaSemanticAnalyzer*
 	vala_code_node_set_checked ((ValaCodeNode*) self, TRUE);
 	_tmp1 = NULL;
 	old_source_file = (_tmp1 = vala_semantic_analyzer_get_current_source_file (analyzer), (_tmp1 == NULL) ? NULL : vala_source_file_ref (_tmp1));
+	_tmp2 = NULL;
+	old_symbol = (_tmp2 = vala_semantic_analyzer_get_current_symbol (analyzer), (_tmp2 == NULL) ? NULL : vala_code_node_ref (_tmp2));
 	if (vala_code_node_get_source_reference ((ValaCodeNode*) self) != NULL) {
 		vala_semantic_analyzer_set_current_source_file (analyzer, vala_source_reference_get_file (vala_code_node_get_source_reference ((ValaCodeNode*) self)));
 	}
+	vala_semantic_analyzer_set_current_symbol (analyzer, (ValaSymbol*) self);
 	vala_code_node_check ((ValaCodeNode*) vala_field_get_field_type (self), analyzer);
 	/* check whether field type is at least as accessible as the field*/
 	if (!vala_semantic_analyzer_is_type_accessible (analyzer, (ValaSymbol*) self, vala_field_get_field_type (self))) {
+		char* _tmp5;
 		char* _tmp4;
 		char* _tmp3;
-		char* _tmp2;
-		gboolean _tmp5;
+		gboolean _tmp6;
 		vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
+		_tmp5 = NULL;
 		_tmp4 = NULL;
 		_tmp3 = NULL;
-		_tmp2 = NULL;
-		vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), _tmp4 = g_strdup_printf ("field type `%s` is less accessible than field `%s`", _tmp2 = vala_code_node_to_string ((ValaCodeNode*) vala_field_get_field_type (self)), _tmp3 = vala_symbol_get_full_name ((ValaSymbol*) self)));
+		vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), _tmp5 = g_strdup_printf ("field type `%s` is less accessible than field `%s`", _tmp3 = vala_code_node_to_string ((ValaCodeNode*) vala_field_get_field_type (self)), _tmp4 = vala_symbol_get_full_name ((ValaSymbol*) self)));
+		_tmp5 = (g_free (_tmp5), NULL);
 		_tmp4 = (g_free (_tmp4), NULL);
 		_tmp3 = (g_free (_tmp3), NULL);
-		_tmp2 = (g_free (_tmp2), NULL);
-		return (_tmp5 = FALSE, (old_source_file == NULL) ? NULL : (old_source_file = (vala_source_file_unref (old_source_file), NULL)), _tmp5);
+		return (_tmp6 = FALSE, (old_source_file == NULL) ? NULL : (old_source_file = (vala_source_file_unref (old_source_file), NULL)), (old_symbol == NULL) ? NULL : (old_symbol = (vala_code_node_unref (old_symbol), NULL)), _tmp6);
 	}
 	vala_field_process_attributes (self);
 	if (vala_field_get_initializer (self) != NULL) {
 		vala_expression_set_target_type (vala_field_get_initializer (self), vala_field_get_field_type (self));
 		vala_code_node_check ((ValaCodeNode*) vala_field_get_initializer (self), analyzer);
 	}
-	_tmp6 = FALSE;
+	_tmp7 = FALSE;
 	if (self->priv->_binding == MEMBER_BINDING_INSTANCE) {
-		_tmp6 = VALA_IS_INTERFACE (vala_symbol_get_parent_symbol ((ValaSymbol*) self));
+		_tmp7 = VALA_IS_INTERFACE (vala_symbol_get_parent_symbol ((ValaSymbol*) self));
 	} else {
-		_tmp6 = FALSE;
+		_tmp7 = FALSE;
 	}
-	if (_tmp6) {
-		gboolean _tmp7;
+	if (_tmp7) {
+		gboolean _tmp8;
 		vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
 		vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), "Interfaces may not have instance fields");
-		return (_tmp7 = FALSE, (old_source_file == NULL) ? NULL : (old_source_file = (vala_source_file_unref (old_source_file), NULL)), _tmp7);
+		return (_tmp8 = FALSE, (old_source_file == NULL) ? NULL : (old_source_file = (vala_source_file_unref (old_source_file), NULL)), (old_symbol == NULL) ? NULL : (old_symbol = (vala_code_node_unref (old_symbol), NULL)), _tmp8);
 	}
 	field_in_header = !vala_symbol_is_internal_symbol ((ValaSymbol*) self);
 	if (VALA_IS_CLASS (vala_symbol_get_parent_symbol ((ValaSymbol*) self))) {
-		ValaClass* _tmp8;
+		ValaClass* _tmp9;
 		ValaClass* cl;
-		gboolean _tmp9;
-		_tmp8 = NULL;
-		cl = (_tmp8 = VALA_CLASS (vala_symbol_get_parent_symbol ((ValaSymbol*) self)), (_tmp8 == NULL) ? NULL : vala_code_node_ref (_tmp8));
-		_tmp9 = FALSE;
+		gboolean _tmp10;
+		_tmp9 = NULL;
+		cl = (_tmp9 = VALA_CLASS (vala_symbol_get_parent_symbol ((ValaSymbol*) self)), (_tmp9 == NULL) ? NULL : vala_code_node_ref (_tmp9));
+		_tmp10 = FALSE;
 		if (vala_class_get_is_compact (cl)) {
-			_tmp9 = !vala_symbol_is_internal_symbol ((ValaSymbol*) cl);
+			_tmp10 = !vala_symbol_is_internal_symbol ((ValaSymbol*) cl);
 		} else {
-			_tmp9 = FALSE;
+			_tmp10 = FALSE;
 		}
-		if (_tmp9) {
+		if (_tmp10) {
 			/* compact classes don't have priv structs*/
 			field_in_header = TRUE;
 		}
@@ -428,16 +468,11 @@ static gboolean vala_field_real_check (ValaCodeNode* base, ValaSemanticAnalyzer*
 			vala_source_file_add_type_dependency (vala_semantic_analyzer_get_current_source_file (analyzer), vala_field_get_field_type (self), VALA_SOURCE_FILE_DEPENDENCY_TYPE_HEADER_SHALLOW);
 		}
 	} else {
-		if (VALA_IS_NAMESPACE (vala_symbol_get_parent_symbol ((ValaSymbol*) self))) {
-			gboolean _tmp10;
-			vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
-			vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), "Namespaces may not have private members");
-			return (_tmp10 = FALSE, (old_source_file == NULL) ? NULL : (old_source_file = (vala_source_file_unref (old_source_file), NULL)), _tmp10);
-		}
 		vala_source_file_add_type_dependency (vala_semantic_analyzer_get_current_source_file (analyzer), vala_field_get_field_type (self), VALA_SOURCE_FILE_DEPENDENCY_TYPE_SOURCE);
 	}
 	vala_semantic_analyzer_set_current_source_file (analyzer, old_source_file);
-	return (_tmp11 = !vala_code_node_get_error ((ValaCodeNode*) self), (old_source_file == NULL) ? NULL : (old_source_file = (vala_source_file_unref (old_source_file), NULL)), _tmp11);
+	vala_semantic_analyzer_set_current_symbol (analyzer, old_symbol);
+	return (_tmp11 = !vala_code_node_get_error ((ValaCodeNode*) self), (old_source_file == NULL) ? NULL : (old_source_file = (vala_source_file_unref (old_source_file), NULL)), (old_symbol == NULL) ? NULL : (old_symbol = (vala_code_node_unref (old_symbol), NULL)), _tmp11);
 }
 
 
@@ -531,6 +566,12 @@ gboolean vala_field_get_has_array_length_cname (ValaField* self) {
 }
 
 
+gboolean vala_field_get_has_array_length_cexpr (ValaField* self) {
+	g_return_val_if_fail (self != NULL, FALSE);
+	return (self->priv->array_length_cexpr != NULL);
+}
+
+
 static void vala_field_class_init (ValaFieldClass * klass) {
 	vala_field_parent_class = g_type_class_peek_parent (klass);
 	VALA_CODE_NODE_CLASS (klass)->finalize = vala_field_finalize;
@@ -561,6 +602,7 @@ static void vala_field_finalize (ValaCodeNode* obj) {
 	ValaField * self;
 	self = VALA_FIELD (obj);
 	self->priv->array_length_cname = (g_free (self->priv->array_length_cname), NULL);
+	self->priv->array_length_cexpr = (g_free (self->priv->array_length_cexpr), NULL);
 	self->priv->cname = (g_free (self->priv->cname), NULL);
 	(self->priv->_initializer == NULL) ? NULL : (self->priv->_initializer = (vala_code_node_unref (self->priv->_initializer), NULL));
 	(self->priv->_data_type == NULL) ? NULL : (self->priv->_data_type = (vala_code_node_unref (self->priv->_data_type), NULL));
