@@ -32,7 +32,6 @@
 #include <vala/valasourcefile.h>
 #include <vala/valaarraytype.h>
 #include <vala/valareport.h>
-#include <vala/valacodecontext.h>
 #include <vala/valanullliteral.h>
 #include <vala/valavaluetype.h>
 
@@ -210,8 +209,7 @@ static gboolean vala_formal_parameter_real_check (ValaCodeNode* base, ValaSemant
 	ValaSourceFile* old_source_file;
 	ValaSymbol* _tmp2;
 	ValaSymbol* old_symbol;
-	gboolean _tmp5;
-	gboolean _tmp14;
+	gboolean _tmp13;
 	self = (ValaFormalParameter*) base;
 	g_return_val_if_fail (analyzer != NULL, FALSE);
 	if (vala_code_node_get_checked ((ValaCodeNode*) self)) {
@@ -249,47 +247,41 @@ static gboolean vala_formal_parameter_real_check (ValaCodeNode* base, ValaSemant
 			vala_code_node_check ((ValaCodeNode*) self->priv->_default_expression, analyzer);
 		}
 	}
-	_tmp5 = FALSE;
-	if (vala_code_context_get_non_null (vala_semantic_analyzer_get_context (analyzer))) {
-		_tmp5 = self->priv->_default_expression != NULL;
-	} else {
-		_tmp5 = FALSE;
-	}
-	if (_tmp5) {
+	if (self->priv->_default_expression != NULL) {
+		gboolean _tmp5;
 		gboolean _tmp6;
-		gboolean _tmp7;
+		_tmp5 = FALSE;
 		_tmp6 = FALSE;
-		_tmp7 = FALSE;
 		if (VALA_IS_NULL_LITERAL (self->priv->_default_expression)) {
-			_tmp7 = !vala_data_type_get_nullable (vala_formal_parameter_get_parameter_type (self));
-		} else {
-			_tmp7 = FALSE;
-		}
-		if (_tmp7) {
-			_tmp6 = self->priv->_direction != VALA_PARAMETER_DIRECTION_OUT;
+			_tmp6 = !vala_data_type_get_nullable (vala_formal_parameter_get_parameter_type (self));
 		} else {
 			_tmp6 = FALSE;
 		}
 		if (_tmp6) {
-			char* _tmp9;
+			_tmp5 = self->priv->_direction != VALA_PARAMETER_DIRECTION_OUT;
+		} else {
+			_tmp5 = FALSE;
+		}
+		if (_tmp5) {
 			char* _tmp8;
-			_tmp9 = NULL;
+			char* _tmp7;
 			_tmp8 = NULL;
-			vala_report_warning (vala_code_node_get_source_reference ((ValaCodeNode*) self), _tmp9 = g_strdup_printf ("`null' incompatible with parameter type `%s`", _tmp8 = vala_code_node_to_string ((ValaCodeNode*) vala_formal_parameter_get_parameter_type (self))));
-			_tmp9 = (g_free (_tmp9), NULL);
+			_tmp7 = NULL;
+			vala_report_warning (vala_code_node_get_source_reference ((ValaCodeNode*) self), _tmp8 = g_strdup_printf ("`null' incompatible with parameter type `%s`", _tmp7 = vala_code_node_to_string ((ValaCodeNode*) vala_formal_parameter_get_parameter_type (self))));
 			_tmp8 = (g_free (_tmp8), NULL);
+			_tmp7 = (g_free (_tmp7), NULL);
 		}
 	}
 	if (!self->priv->_ellipsis) {
 		if (!vala_symbol_is_internal_symbol ((ValaSymbol*) self)) {
-			gboolean _tmp10;
-			_tmp10 = FALSE;
+			gboolean _tmp9;
+			_tmp9 = FALSE;
 			if (VALA_IS_VALUE_TYPE (vala_formal_parameter_get_parameter_type (self))) {
-				_tmp10 = !vala_data_type_is_real_struct_type (vala_formal_parameter_get_parameter_type (self));
+				_tmp9 = !vala_data_type_is_real_struct_type (vala_formal_parameter_get_parameter_type (self));
 			} else {
-				_tmp10 = FALSE;
+				_tmp9 = FALSE;
 			}
-			if (_tmp10) {
+			if (_tmp9) {
 				vala_source_file_add_type_dependency (vala_semantic_analyzer_get_current_source_file (analyzer), vala_formal_parameter_get_parameter_type (self), VALA_SOURCE_FILE_DEPENDENCY_TYPE_HEADER_FULL);
 			} else {
 				vala_source_file_add_type_dependency (vala_semantic_analyzer_get_current_source_file (analyzer), vala_formal_parameter_get_parameter_type (self), VALA_SOURCE_FILE_DEPENDENCY_TYPE_HEADER_SHALLOW);
@@ -298,22 +290,22 @@ static gboolean vala_formal_parameter_real_check (ValaCodeNode* base, ValaSemant
 		vala_source_file_add_type_dependency (vala_semantic_analyzer_get_current_source_file (analyzer), vala_formal_parameter_get_parameter_type (self), VALA_SOURCE_FILE_DEPENDENCY_TYPE_SOURCE);
 		/* check whether parameter type is at least as accessible as the method*/
 		if (!vala_semantic_analyzer_is_type_accessible (analyzer, (ValaSymbol*) self, vala_formal_parameter_get_parameter_type (self))) {
-			char* _tmp13;
 			char* _tmp12;
 			char* _tmp11;
+			char* _tmp10;
 			vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
-			_tmp13 = NULL;
 			_tmp12 = NULL;
 			_tmp11 = NULL;
-			vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), _tmp13 = g_strdup_printf ("parameter type `%s` is less accessible than method `%s`", _tmp11 = vala_code_node_to_string ((ValaCodeNode*) vala_formal_parameter_get_parameter_type (self)), _tmp12 = vala_symbol_get_full_name (vala_symbol_get_parent_symbol ((ValaSymbol*) self))));
-			_tmp13 = (g_free (_tmp13), NULL);
+			_tmp10 = NULL;
+			vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), _tmp12 = g_strdup_printf ("parameter type `%s` is less accessible than method `%s`", _tmp10 = vala_code_node_to_string ((ValaCodeNode*) vala_formal_parameter_get_parameter_type (self)), _tmp11 = vala_symbol_get_full_name (vala_symbol_get_parent_symbol ((ValaSymbol*) self))));
 			_tmp12 = (g_free (_tmp12), NULL);
 			_tmp11 = (g_free (_tmp11), NULL);
+			_tmp10 = (g_free (_tmp10), NULL);
 		}
 	}
 	vala_semantic_analyzer_set_current_source_file (analyzer, old_source_file);
 	vala_semantic_analyzer_set_current_symbol (analyzer, old_symbol);
-	return (_tmp14 = !vala_code_node_get_error ((ValaCodeNode*) self), (old_source_file == NULL) ? NULL : (old_source_file = (vala_source_file_unref (old_source_file), NULL)), (old_symbol == NULL) ? NULL : (old_symbol = (vala_code_node_unref (old_symbol), NULL)), _tmp14);
+	return (_tmp13 = !vala_code_node_get_error ((ValaCodeNode*) self), (old_source_file == NULL) ? NULL : (old_source_file = (vala_source_file_unref (old_source_file), NULL)), (old_symbol == NULL) ? NULL : (old_symbol = (vala_code_node_unref (old_symbol), NULL)), _tmp13);
 }
 
 
