@@ -1871,7 +1871,7 @@ static gboolean vala_genie_scanner_comment (ValaGenieScanner* self) {
 			self->priv->current++;
 		}
 		_tmp5 = NULL;
-		vala_genie_scanner_push_comment (self, _tmp5 = g_strndup (((const char*) begin), (gulong) ((glong) (self->priv->current - begin))), self->priv->line == 1);
+		vala_genie_scanner_push_comment (self, _tmp5 = g_strndup (((const char*) begin), (gsize) ((glong) (self->priv->current - begin))), self->priv->line == 1);
 		_tmp5 = (g_free (_tmp5), NULL);
 		if (self->priv->current[0] == '\n') {
 			self->priv->current++;
@@ -1920,7 +1920,7 @@ static gboolean vala_genie_scanner_comment (ValaGenieScanner* self) {
 			return TRUE;
 		}
 		_tmp10 = NULL;
-		vala_genie_scanner_push_comment (self, _tmp10 = g_strndup (((const char*) begin), (gulong) ((glong) (self->priv->current - begin))), begin_line == 1);
+		vala_genie_scanner_push_comment (self, _tmp10 = g_strndup (((const char*) begin), (gsize) ((glong) (self->priv->current - begin))), begin_line == 1);
 		_tmp10 = (g_free (_tmp10), NULL);
 		self->priv->current = self->priv->current + (2);
 		self->priv->column = self->priv->column + (2);
@@ -2022,7 +2022,7 @@ static void vala_genie_scanner_push_comment (ValaGenieScanner* self, const char*
  * @return saved comment
  */
 char* vala_genie_scanner_pop_comment (ValaGenieScanner* self) {
-	GString* result;
+	GString* result_builder;
 	char* _tmp1;
 	const char* index;
 	const char* _tmp2;
@@ -2031,16 +2031,16 @@ char* vala_genie_scanner_pop_comment (ValaGenieScanner* self) {
 	if (self->priv->_comment == NULL) {
 		return NULL;
 	}
-	result = g_string_new (self->priv->_comment);
+	result_builder = g_string_new (self->priv->_comment);
 	_tmp1 = NULL;
 	self->priv->_comment = (_tmp1 = NULL, self->priv->_comment = (g_free (self->priv->_comment), NULL), _tmp1);
 	index = NULL;
-	while ((index = g_utf8_strchr (result->str, (glong) (-1), (gunichar) '\t')) != NULL) {
-		g_string_erase (result, g_utf8_pointer_to_offset (result->str, index), (glong) 1);
+	while ((index = g_utf8_strchr (result_builder->str, (glong) (-1), (gunichar) '\t')) != NULL) {
+		g_string_erase (result_builder, g_utf8_pointer_to_offset (result_builder->str, index), (glong) 1);
 	}
 	_tmp2 = NULL;
 	_tmp3 = NULL;
-	return (_tmp3 = (_tmp2 = result->str, (_tmp2 == NULL) ? NULL : g_strdup (_tmp2)), (result == NULL) ? NULL : (result = (g_string_free (result, TRUE), NULL)), _tmp3);
+	return (_tmp3 = (_tmp2 = result_builder->str, (_tmp2 == NULL) ? NULL : g_strdup (_tmp2)), (result_builder == NULL) ? NULL : (result_builder = (g_string_free (result_builder, TRUE), NULL)), _tmp3);
 }
 
 
