@@ -21,10 +21,16 @@
  */
 
 #include <vala/valaifstatement.h>
-#include <vala/valaexpression.h>
+#include <stdlib.h>
+#include <string.h>
+#include <gee/list.h>
 #include <vala/valablock.h>
+#include <vala/valaexpression.h>
 #include <vala/valasourcereference.h>
 #include <vala/valacodevisitor.h>
+#include <vala/valasemanticanalyzer.h>
+#include <vala/valadatatype.h>
+#include <vala/valareport.h>
 
 
 
@@ -42,6 +48,7 @@ enum  {
 static void vala_if_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_if_statement_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_if_statement_real_replace_expression (ValaCodeNode* base, ValaExpression* old_node, ValaExpression* new_node);
+static gboolean vala_if_statement_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer);
 static gpointer vala_if_statement_parent_class = NULL;
 static ValaStatementIface* vala_if_statement_vala_statement_parent_iface = NULL;
 static void vala_if_statement_finalize (ValaCodeNode* obj);
@@ -60,11 +67,11 @@ ValaIfStatement* vala_if_statement_construct (GType object_type, ValaExpression*
 	ValaIfStatement* self;
 	g_return_val_if_fail (cond != NULL, NULL);
 	g_return_val_if_fail (true_stmt != NULL, NULL);
-	self = ((ValaIfStatement*) (g_type_create_instance (object_type)));
+	self = (ValaIfStatement*) g_type_create_instance (object_type);
 	vala_if_statement_set_condition (self, cond);
 	vala_if_statement_set_true_statement (self, true_stmt);
 	vala_if_statement_set_false_statement (self, false_stmt);
-	vala_code_node_set_source_reference (((ValaCodeNode*) (self)), source);
+	vala_code_node_set_source_reference ((ValaCodeNode*) self, source);
 	return self;
 }
 
@@ -76,7 +83,7 @@ ValaIfStatement* vala_if_statement_new (ValaExpression* cond, ValaBlock* true_st
 
 static void vala_if_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaIfStatement * self;
-	self = ((ValaIfStatement*) (base));
+	self = (ValaIfStatement*) base;
 	g_return_if_fail (visitor != NULL);
 	vala_code_visitor_visit_if_statement (visitor, self);
 }
@@ -84,20 +91,20 @@ static void vala_if_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor*
 
 static void vala_if_statement_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaIfStatement * self;
-	self = ((ValaIfStatement*) (base));
+	self = (ValaIfStatement*) base;
 	g_return_if_fail (visitor != NULL);
-	vala_code_node_accept (((ValaCodeNode*) (vala_if_statement_get_condition (self))), visitor);
+	vala_code_node_accept ((ValaCodeNode*) vala_if_statement_get_condition (self), visitor);
 	vala_code_visitor_visit_end_full_expression (visitor, vala_if_statement_get_condition (self));
-	vala_code_node_accept (((ValaCodeNode*) (self->priv->_true_statement)), visitor);
+	vala_code_node_accept ((ValaCodeNode*) self->priv->_true_statement, visitor);
 	if (self->priv->_false_statement != NULL) {
-		vala_code_node_accept (((ValaCodeNode*) (self->priv->_false_statement)), visitor);
+		vala_code_node_accept ((ValaCodeNode*) self->priv->_false_statement, visitor);
 	}
 }
 
 
 static void vala_if_statement_real_replace_expression (ValaCodeNode* base, ValaExpression* old_node, ValaExpression* new_node) {
 	ValaIfStatement * self;
-	self = ((ValaIfStatement*) (base));
+	self = (ValaIfStatement*) base;
 	g_return_if_fail (old_node != NULL);
 	g_return_if_fail (new_node != NULL);
 	if (vala_if_statement_get_condition (self) == old_node) {
@@ -106,6 +113,47 @@ static void vala_if_statement_real_replace_expression (ValaCodeNode* base, ValaE
 }
 
 
+static gboolean vala_if_statement_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer) {
+	ValaIfStatement * self;
+	GeeList* _tmp3;
+	GeeList* _tmp4;
+	self = (ValaIfStatement*) base;
+	g_return_val_if_fail (analyzer != NULL, FALSE);
+	if (vala_code_node_get_checked ((ValaCodeNode*) self)) {
+		return !vala_code_node_get_error ((ValaCodeNode*) self);
+	}
+	vala_code_node_set_checked ((ValaCodeNode*) self, TRUE);
+	vala_code_node_check ((ValaCodeNode*) vala_if_statement_get_condition (self), analyzer);
+	vala_code_node_check ((ValaCodeNode*) self->priv->_true_statement, analyzer);
+	if (self->priv->_false_statement != NULL) {
+		vala_code_node_check ((ValaCodeNode*) self->priv->_false_statement, analyzer);
+	}
+	if (vala_code_node_get_error ((ValaCodeNode*) vala_if_statement_get_condition (self))) {
+		/* if there was an error in the condition, skip this check */
+		vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
+		return FALSE;
+	}
+	if (!vala_data_type_compatible (vala_expression_get_value_type (vala_if_statement_get_condition (self)), analyzer->bool_type)) {
+		vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
+		vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) vala_if_statement_get_condition (self)), "Condition must be boolean");
+		return FALSE;
+	}
+	_tmp3 = NULL;
+	vala_code_node_add_error_types ((ValaCodeNode*) self, _tmp3 = vala_code_node_get_error_types ((ValaCodeNode*) vala_if_statement_get_condition (self)));
+	(_tmp3 == NULL) ? NULL : (_tmp3 = (gee_collection_object_unref (_tmp3), NULL));
+	_tmp4 = NULL;
+	vala_code_node_add_error_types ((ValaCodeNode*) self, _tmp4 = vala_code_node_get_error_types ((ValaCodeNode*) self->priv->_true_statement));
+	(_tmp4 == NULL) ? NULL : (_tmp4 = (gee_collection_object_unref (_tmp4), NULL));
+	if (self->priv->_false_statement != NULL) {
+		GeeList* _tmp5;
+		_tmp5 = NULL;
+		vala_code_node_add_error_types ((ValaCodeNode*) self, _tmp5 = vala_code_node_get_error_types ((ValaCodeNode*) self->priv->_false_statement));
+		(_tmp5 == NULL) ? NULL : (_tmp5 = (gee_collection_object_unref (_tmp5), NULL));
+	}
+	return !vala_code_node_get_error ((ValaCodeNode*) self);
+}
+
+
 ValaExpression* vala_if_statement_get_condition (ValaIfStatement* self) {
 	g_return_val_if_fail (self != NULL, NULL);
 	return self->priv->_condition;
@@ -118,8 +166,8 @@ void vala_if_statement_set_condition (ValaIfStatement* self, ValaExpression* val
 	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_condition = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1))), (self->priv->_condition == NULL ? NULL : (self->priv->_condition = (vala_code_node_unref (self->priv->_condition), NULL))), _tmp2);
-	vala_code_node_set_parent_node (((ValaCodeNode*) (self->priv->_condition)), ((ValaCodeNode*) (self)));
+	self->priv->_condition = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : vala_code_node_ref (_tmp1)), (self->priv->_condition == NULL) ? NULL : (self->priv->_condition = (vala_code_node_unref (self->priv->_condition), NULL)), _tmp2);
+	vala_code_node_set_parent_node ((ValaCodeNode*) self->priv->_condition, (ValaCodeNode*) self);
 }
 
 
@@ -135,7 +183,7 @@ void vala_if_statement_set_true_statement (ValaIfStatement* self, ValaBlock* val
 	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_true_statement = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1))), (self->priv->_true_statement == NULL ? NULL : (self->priv->_true_statement = (vala_code_node_unref (self->priv->_true_statement), NULL))), _tmp2);
+	self->priv->_true_statement = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : vala_code_node_ref (_tmp1)), (self->priv->_true_statement == NULL) ? NULL : (self->priv->_true_statement = (vala_code_node_unref (self->priv->_true_statement), NULL)), _tmp2);
 }
 
 
@@ -151,7 +199,7 @@ void vala_if_statement_set_false_statement (ValaIfStatement* self, ValaBlock* va
 	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_false_statement = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1))), (self->priv->_false_statement == NULL ? NULL : (self->priv->_false_statement = (vala_code_node_unref (self->priv->_false_statement), NULL))), _tmp2);
+	self->priv->_false_statement = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : vala_code_node_ref (_tmp1)), (self->priv->_false_statement == NULL) ? NULL : (self->priv->_false_statement = (vala_code_node_unref (self->priv->_false_statement), NULL)), _tmp2);
 }
 
 
@@ -162,6 +210,7 @@ static void vala_if_statement_class_init (ValaIfStatementClass * klass) {
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_if_statement_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_if_statement_real_accept_children;
 	VALA_CODE_NODE_CLASS (klass)->replace_expression = vala_if_statement_real_replace_expression;
+	VALA_CODE_NODE_CLASS (klass)->check = vala_if_statement_real_check;
 }
 
 
@@ -178,9 +227,9 @@ static void vala_if_statement_instance_init (ValaIfStatement * self) {
 static void vala_if_statement_finalize (ValaCodeNode* obj) {
 	ValaIfStatement * self;
 	self = VALA_IF_STATEMENT (obj);
-	(self->priv->_true_statement == NULL ? NULL : (self->priv->_true_statement = (vala_code_node_unref (self->priv->_true_statement), NULL)));
-	(self->priv->_false_statement == NULL ? NULL : (self->priv->_false_statement = (vala_code_node_unref (self->priv->_false_statement), NULL)));
-	(self->priv->_condition == NULL ? NULL : (self->priv->_condition = (vala_code_node_unref (self->priv->_condition), NULL)));
+	(self->priv->_true_statement == NULL) ? NULL : (self->priv->_true_statement = (vala_code_node_unref (self->priv->_true_statement), NULL));
+	(self->priv->_false_statement == NULL) ? NULL : (self->priv->_false_statement = (vala_code_node_unref (self->priv->_false_statement), NULL));
+	(self->priv->_condition == NULL) ? NULL : (self->priv->_condition = (vala_code_node_unref (self->priv->_condition), NULL));
 	VALA_CODE_NODE_CLASS (vala_if_statement_parent_class)->finalize (obj);
 }
 
