@@ -167,8 +167,8 @@ static void vala_initializer_list_real_replace_expression (ValaCodeNode* base, V
 			ValaExpression* _tmp0;
 			gboolean _tmp1;
 			_tmp0 = NULL;
-			if ((_tmp1 = (_tmp0 = (ValaExpression*) gee_list_get ((GeeList*) self->priv->initializers, i)) == old_node, (_tmp0 == NULL) ? NULL : (_tmp0 = (vala_code_node_unref (_tmp0), NULL)), _tmp1)) {
-				gee_list_set ((GeeList*) self->priv->initializers, i, new_node);
+			if ((_tmp1 = (_tmp0 = (ValaExpression*) gee_list_get (self->priv->initializers, i)) == old_node, (_tmp0 == NULL) ? NULL : (_tmp0 = (vala_code_node_unref (_tmp0), NULL)), _tmp1)) {
+				gee_list_set (self->priv->initializers, i, new_node);
 			}
 		}
 	}
