@@ -102,6 +102,7 @@ static gboolean vala_interface_real_check (ValaCodeNode* base, ValaSemanticAnaly
 static gpointer vala_interface_parent_class = NULL;
 static void vala_interface_finalize (ValaCodeNode* obj);
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
+static gint _vala_array_length (gpointer array);
 static int _vala_strcmp0 (const char * str1, const char * str2);
 
 
@@ -796,8 +797,8 @@ static void vala_interface_process_ccode_attribute (ValaInterface* self, ValaAtt
 			int filename_it;
 			_tmp1 = NULL;
 			filename_collection = _tmp1 = g_strsplit (val, ",", 0);
-			filename_collection_length1 = g_strv_length (_tmp1);
-			for (filename_it = 0; filename_it < g_strv_length (_tmp1); filename_it = filename_it + 1) {
+			filename_collection_length1 = _vala_array_length (_tmp1);
+			for (filename_it = 0; filename_it < _vala_array_length (_tmp1); filename_it = filename_it + 1) {
 				const char* _tmp2;
 				char* filename;
 				_tmp2 = NULL;
@@ -928,8 +929,8 @@ static void vala_interface_real_replace_type (ValaCodeNode* base, ValaDataType*
 			ValaDataType* _tmp0;
 			gboolean _tmp1;
 			_tmp0 = NULL;
-			if ((_tmp1 = (_tmp0 = (ValaDataType*) gee_list_get ((GeeList*) self->priv->prerequisites, i)) == old_type, (_tmp0 == NULL) ? NULL : (_tmp0 = (vala_code_node_unref (_tmp0), NULL)), _tmp1)) {
-				gee_list_set ((GeeList*) self->priv->prerequisites, i, new_type);
+			if ((_tmp1 = (_tmp0 = (ValaDataType*) gee_list_get (self->priv->prerequisites, i)) == old_type, (_tmp0 == NULL) ? NULL : (_tmp0 = (vala_code_node_unref (_tmp0), NULL)), _tmp1)) {
+				gee_list_set (self->priv->prerequisites, i, new_type);
 				return;
 			}
 		}
@@ -1318,6 +1319,18 @@ static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify
 }
 
 
+static gint _vala_array_length (gpointer array) {
+	int length;
+	length = 0;
+	if (array) {
+		while (((gpointer*) array)[length]) {
+			length++;
+		}
+	}
+	return length;
+}
+
+
 static int _vala_strcmp0 (const char * str1, const char * str2) {
 	if (str1 == NULL) {
 		return -(str1 != str2);
