@@ -1,6 +1,6 @@
 /* valalambdaexpression.vala
  *
- * Copyright (C) 2006-2008  Jürg Billeter
+ * Copyright (C) 2006-2009  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -33,9 +33,9 @@
 #include <vala/valasemanticanalyzer.h>
 #include <vala/valadelegatetype.h>
 #include <vala/valareport.h>
-#include <vala/valamember.h>
 #include <vala/valadelegate.h>
 #include <vala/valadatatype.h>
+#include <vala/valamember.h>
 #include <vala/valasymbol.h>
 #include <vala/valaformalparameter.h>
 #include <vala/valascope.h>
@@ -184,8 +184,6 @@ static char* vala_lambda_expression_get_lambda_name (ValaLambdaExpression* self,
 
 static gboolean vala_lambda_expression_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer) {
 	ValaLambdaExpression * self;
-	gboolean in_instance_method;
-	ValaMethod* current_method;
 	ValaDelegate* _tmp2;
 	ValaDelegate* cb;
 	ValaMethod* _tmp4;
@@ -193,8 +191,8 @@ static gboolean vala_lambda_expression_real_check (ValaCodeNode* base, ValaSeman
 	gboolean _tmp5;
 	GeeList* lambda_params;
 	GeeIterator* lambda_param_it;
-	ValaMethodType* _tmp11;
-	gboolean _tmp12;
+	ValaMethodType* _tmp14;
+	gboolean _tmp15;
 	self = (ValaLambdaExpression*) base;
 	g_return_val_if_fail (analyzer != NULL, FALSE);
 	if (vala_code_node_get_checked ((ValaCodeNode*) self)) {
@@ -206,13 +204,6 @@ static gboolean vala_lambda_expression_real_check (ValaCodeNode* base, ValaSeman
 		vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), "lambda expression not allowed in this context");
 		return FALSE;
 	}
-	in_instance_method = FALSE;
-	current_method = vala_semantic_analyzer_find_current_method (analyzer);
-	if (current_method != NULL) {
-		in_instance_method = (vala_method_get_binding (current_method) == MEMBER_BINDING_INSTANCE);
-	} else {
-		in_instance_method = vala_semantic_analyzer_is_in_constructor (analyzer);
-	}
 	_tmp2 = NULL;
 	cb = (_tmp2 = VALA_DELEGATE (vala_delegate_type_get_delegate_symbol ((VALA_DELEGATE_TYPE (vala_expression_get_target_type ((ValaExpression*) self))))), (_tmp2 == NULL) ? NULL : vala_code_node_ref (_tmp2));
 	_tmp4 = NULL;
@@ -224,7 +215,7 @@ static gboolean vala_lambda_expression_real_check (ValaCodeNode* base, ValaSeman
 	if (!vala_delegate_get_has_target (cb)) {
 		_tmp5 = TRUE;
 	} else {
-		_tmp5 = !in_instance_method;
+		_tmp5 = !vala_semantic_analyzer_is_in_instance_method (analyzer);
 	}
 	if (_tmp5) {
 		vala_method_set_binding (self->priv->_method, MEMBER_BINDING_STATIC);
@@ -263,22 +254,40 @@ static gboolean vala_lambda_expression_real_check (ValaCodeNode* base, ValaSeman
 		/* lambda expressions may not expect more parameters */
 		vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
 		vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), "lambda expression: too many parameters");
-		return (_tmp8 = FALSE, (current_method == NULL) ? NULL : (current_method = (vala_code_node_unref (current_method), NULL)), (cb == NULL) ? NULL : (cb = (vala_code_node_unref (cb), NULL)), (lambda_params == NULL) ? NULL : (lambda_params = (gee_collection_object_unref (lambda_params), NULL)), (lambda_param_it == NULL) ? NULL : (lambda_param_it = (gee_collection_object_unref (lambda_param_it), NULL)), _tmp8);
+		return (_tmp8 = FALSE, (cb == NULL) ? NULL : (cb = (vala_code_node_unref (cb), NULL)), (lambda_params == NULL) ? NULL : (lambda_params = (gee_collection_object_unref (lambda_params), NULL)), (lambda_param_it == NULL) ? NULL : (lambda_param_it = (gee_collection_object_unref (lambda_param_it), NULL)), _tmp8);
+	}
+	{
+		GeeList* _tmp9;
+		GeeIterator* _tmp10;
+		GeeIterator* _error_type_it;
+		_tmp9 = NULL;
+		_tmp10 = NULL;
+		_error_type_it = (_tmp10 = gee_iterable_iterator ((GeeIterable*) (_tmp9 = vala_code_node_get_error_types ((ValaCodeNode*) cb))), (_tmp9 == NULL) ? NULL : (_tmp9 = (gee_collection_object_unref (_tmp9), NULL)), _tmp10);
+		while (gee_iterator_next (_error_type_it)) {
+			ValaDataType* error_type;
+			ValaDataType* _tmp11;
+			error_type = (ValaDataType*) gee_iterator_get (_error_type_it);
+			_tmp11 = NULL;
+			vala_code_node_add_error_type ((ValaCodeNode*) self->priv->_method, _tmp11 = vala_data_type_copy (error_type));
+			(_tmp11 == NULL) ? NULL : (_tmp11 = (vala_code_node_unref (_tmp11), NULL));
+			(error_type == NULL) ? NULL : (error_type = (vala_code_node_unref (error_type), NULL));
+		}
+		(_error_type_it == NULL) ? NULL : (_error_type_it = (gee_collection_object_unref (_error_type_it), NULL));
 	}
 	if (self->priv->_expression_body != NULL) {
 		ValaBlock* block;
 		block = vala_block_new (vala_code_node_get_source_reference ((ValaCodeNode*) self));
 		vala_scope_set_parent_scope (vala_symbol_get_scope ((ValaSymbol*) block), vala_symbol_get_scope ((ValaSymbol*) self->priv->_method));
 		if (vala_data_type_get_data_type (vala_method_get_return_type (self->priv->_method)) != NULL) {
-			ValaReturnStatement* _tmp9;
-			_tmp9 = NULL;
-			vala_block_add_statement (block, (ValaStatement*) (_tmp9 = vala_return_statement_new (self->priv->_expression_body, vala_code_node_get_source_reference ((ValaCodeNode*) self))));
-			(_tmp9 == NULL) ? NULL : (_tmp9 = (vala_code_node_unref (_tmp9), NULL));
+			ValaReturnStatement* _tmp12;
+			_tmp12 = NULL;
+			vala_block_add_statement (block, (ValaStatement*) (_tmp12 = vala_return_statement_new (self->priv->_expression_body, vala_code_node_get_source_reference ((ValaCodeNode*) self))));
+			(_tmp12 == NULL) ? NULL : (_tmp12 = (vala_code_node_unref (_tmp12), NULL));
 		} else {
-			ValaExpressionStatement* _tmp10;
-			_tmp10 = NULL;
-			vala_block_add_statement (block, (ValaStatement*) (_tmp10 = vala_expression_statement_new (self->priv->_expression_body, vala_code_node_get_source_reference ((ValaCodeNode*) self))));
-			(_tmp10 == NULL) ? NULL : (_tmp10 = (vala_code_node_unref (_tmp10), NULL));
+			ValaExpressionStatement* _tmp13;
+			_tmp13 = NULL;
+			vala_block_add_statement (block, (ValaStatement*) (_tmp13 = vala_expression_statement_new (self->priv->_expression_body, vala_code_node_get_source_reference ((ValaCodeNode*) self))));
+			(_tmp13 == NULL) ? NULL : (_tmp13 = (vala_code_node_unref (_tmp13), NULL));
 		}
 		vala_method_set_body (self->priv->_method, block);
 		(block == NULL) ? NULL : (block = (vala_code_node_unref (block), NULL));
@@ -299,10 +308,10 @@ static gboolean vala_lambda_expression_real_check (ValaCodeNode* base, ValaSeman
 	} else {
 		vala_code_node_check ((ValaCodeNode*) self->priv->_method, analyzer);
 	}
-	_tmp11 = NULL;
-	vala_expression_set_value_type ((ValaExpression*) self, (ValaDataType*) (_tmp11 = vala_method_type_new (self->priv->_method)));
-	(_tmp11 == NULL) ? NULL : (_tmp11 = (vala_code_node_unref (_tmp11), NULL));
-	return (_tmp12 = !vala_code_node_get_error ((ValaCodeNode*) self), (current_method == NULL) ? NULL : (current_method = (vala_code_node_unref (current_method), NULL)), (cb == NULL) ? NULL : (cb = (vala_code_node_unref (cb), NULL)), (lambda_params == NULL) ? NULL : (lambda_params = (gee_collection_object_unref (lambda_params), NULL)), (lambda_param_it == NULL) ? NULL : (lambda_param_it = (gee_collection_object_unref (lambda_param_it), NULL)), _tmp12);
+	_tmp14 = NULL;
+	vala_expression_set_value_type ((ValaExpression*) self, (ValaDataType*) (_tmp14 = vala_method_type_new (self->priv->_method)));
+	(_tmp14 == NULL) ? NULL : (_tmp14 = (vala_code_node_unref (_tmp14), NULL));
+	return (_tmp15 = !vala_code_node_get_error ((ValaCodeNode*) self), (cb == NULL) ? NULL : (cb = (vala_code_node_unref (cb), NULL)), (lambda_params == NULL) ? NULL : (lambda_params = (gee_collection_object_unref (lambda_params), NULL)), (lambda_param_it == NULL) ? NULL : (lambda_param_it = (gee_collection_object_unref (lambda_param_it), NULL)), _tmp15);
 }
 
 
