@@ -57,6 +57,7 @@ static void vala_local_variable_real_replace_type (ValaCodeNode* base, ValaDataT
 static gboolean vala_local_variable_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer);
 static gpointer vala_local_variable_parent_class = NULL;
 static void vala_local_variable_finalize (ValaCodeNode* obj);
+static int _vala_strcmp0 (const char * str1, const char * str2);
 
 
 
@@ -129,9 +130,10 @@ static void vala_local_variable_real_replace_type (ValaCodeNode* base, ValaDataT
 
 static gboolean vala_local_variable_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer) {
 	ValaLocalVariable * self;
-	ValaBlock* _tmp21;
+	ValaBlock* _tmp23;
+	ValaSymbol* _tmp22;
 	ValaBlock* block;
-	gboolean _tmp22;
+	gboolean _tmp24;
 	self = (ValaLocalVariable*) base;
 	g_return_val_if_fail (analyzer != NULL, FALSE);
 	if (vala_code_node_get_checked ((ValaCodeNode*) self)) {
@@ -165,55 +167,70 @@ static gboolean vala_local_variable_real_check (ValaCodeNode* base, ValaSemantic
 		vala_data_type_set_floating_reference (vala_local_variable_get_variable_type (self), FALSE);
 		vala_expression_set_target_type (vala_local_variable_get_initializer (self), vala_local_variable_get_variable_type (self));
 	}
+	if (_vala_strcmp0 (vala_symbol_get_name ((ValaSymbol*) self), "result") == 0) {
+		gboolean _tmp4;
+		_tmp4 = FALSE;
+		if (analyzer->current_return_type == NULL) {
+			_tmp4 = TRUE;
+		} else {
+			_tmp4 = !vala_data_type_compatible (vala_local_variable_get_variable_type (self), analyzer->current_return_type);
+		}
+		/* warn if type of `result' variable is incompatible with return type
+		 as an implicit `result' variable might be introduced to be used
+		 by Vala postconditions and implicit checks generated by the code generated*/
+		if (_tmp4) {
+			vala_report_warning (vala_code_node_get_source_reference ((ValaCodeNode*) self), "result variable type incompatible with return type");
+		}
+	}
 	if (vala_local_variable_get_initializer (self) != NULL) {
 		if (vala_expression_get_value_type (vala_local_variable_get_initializer (self)) == NULL) {
-			gboolean _tmp4;
-			gboolean _tmp6;
-			_tmp4 = FALSE;
+			gboolean _tmp5;
+			gboolean _tmp7;
+			_tmp5 = FALSE;
 			if (!(VALA_IS_MEMBER_ACCESS (vala_local_variable_get_initializer (self)))) {
-				_tmp4 = !(VALA_IS_LAMBDA_EXPRESSION (vala_local_variable_get_initializer (self)));
+				_tmp5 = !(VALA_IS_LAMBDA_EXPRESSION (vala_local_variable_get_initializer (self)));
 			} else {
-				_tmp4 = FALSE;
+				_tmp5 = FALSE;
 			}
-			if (_tmp4) {
+			if (_tmp5) {
 				vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
 				vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), "expression type not allowed as initializer");
 				return FALSE;
 			}
-			_tmp6 = FALSE;
+			_tmp7 = FALSE;
 			if (VALA_IS_METHOD (vala_expression_get_symbol_reference (vala_local_variable_get_initializer (self)))) {
-				_tmp6 = VALA_IS_DELEGATE_TYPE (vala_local_variable_get_variable_type (self));
+				_tmp7 = VALA_IS_DELEGATE_TYPE (vala_local_variable_get_variable_type (self));
 			} else {
-				_tmp6 = FALSE;
+				_tmp7 = FALSE;
 			}
-			if (_tmp6) {
-				ValaMethod* _tmp7;
+			if (_tmp7) {
+				ValaMethod* _tmp8;
 				ValaMethod* m;
-				ValaDelegateType* _tmp8;
+				ValaDelegateType* _tmp9;
 				ValaDelegateType* dt;
-				ValaDelegate* _tmp9;
+				ValaDelegate* _tmp10;
 				ValaDelegate* cb;
-				_tmp7 = NULL;
-				m = (_tmp7 = VALA_METHOD (vala_expression_get_symbol_reference (vala_local_variable_get_initializer (self))), (_tmp7 == NULL) ? NULL : vala_code_node_ref (_tmp7));
 				_tmp8 = NULL;
-				dt = (_tmp8 = VALA_DELEGATE_TYPE (vala_local_variable_get_variable_type (self)), (_tmp8 == NULL) ? NULL : vala_code_node_ref (_tmp8));
+				m = (_tmp8 = VALA_METHOD (vala_expression_get_symbol_reference (vala_local_variable_get_initializer (self))), (_tmp8 == NULL) ? NULL : vala_code_node_ref (_tmp8));
 				_tmp9 = NULL;
-				cb = (_tmp9 = vala_delegate_type_get_delegate_symbol (dt), (_tmp9 == NULL) ? NULL : vala_code_node_ref (_tmp9));
+				dt = (_tmp9 = VALA_DELEGATE_TYPE (vala_local_variable_get_variable_type (self)), (_tmp9 == NULL) ? NULL : vala_code_node_ref (_tmp9));
+				_tmp10 = NULL;
+				cb = (_tmp10 = vala_delegate_type_get_delegate_symbol (dt), (_tmp10 == NULL) ? NULL : vala_code_node_ref (_tmp10));
 				/* check whether method matches callback type */
 				if (!vala_delegate_matches_method (cb, m)) {
+					char* _tmp13;
 					char* _tmp12;
 					char* _tmp11;
-					char* _tmp10;
-					gboolean _tmp13;
+					gboolean _tmp14;
 					vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
+					_tmp13 = NULL;
 					_tmp12 = NULL;
 					_tmp11 = NULL;
-					_tmp10 = NULL;
-					vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), _tmp12 = g_strdup_printf ("declaration of method `%s' doesn't match declaration of callback `%s'", _tmp10 = vala_symbol_get_full_name ((ValaSymbol*) m), _tmp11 = vala_symbol_get_full_name ((ValaSymbol*) cb)));
+					vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), _tmp13 = g_strdup_printf ("declaration of method `%s' doesn't match declaration of callback `%s'", _tmp11 = vala_symbol_get_full_name ((ValaSymbol*) m), _tmp12 = vala_symbol_get_full_name ((ValaSymbol*) cb)));
+					_tmp13 = (g_free (_tmp13), NULL);
 					_tmp12 = (g_free (_tmp12), NULL);
 					_tmp11 = (g_free (_tmp11), NULL);
-					_tmp10 = (g_free (_tmp10), NULL);
-					return (_tmp13 = FALSE, (m == NULL) ? NULL : (m = (vala_code_node_unref (m), NULL)), (dt == NULL) ? NULL : (dt = (vala_code_node_unref (dt), NULL)), (cb == NULL) ? NULL : (cb = (vala_code_node_unref (cb), NULL)), _tmp13);
+					return (_tmp14 = FALSE, (m == NULL) ? NULL : (m = (vala_code_node_unref (m), NULL)), (dt == NULL) ? NULL : (dt = (vala_code_node_unref (dt), NULL)), (cb == NULL) ? NULL : (cb = (vala_code_node_unref (cb), NULL)), _tmp14);
 				}
 				vala_expression_set_value_type (vala_local_variable_get_initializer (self), vala_local_variable_get_variable_type (self));
 				(m == NULL) ? NULL : (m = (vala_code_node_unref (m), NULL));
@@ -226,29 +243,29 @@ static gboolean vala_local_variable_real_check (ValaCodeNode* base, ValaSemantic
 			}
 		}
 		if (!vala_data_type_compatible (vala_expression_get_value_type (vala_local_variable_get_initializer (self)), vala_local_variable_get_variable_type (self))) {
+			char* _tmp18;
 			char* _tmp17;
 			char* _tmp16;
-			char* _tmp15;
 			vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
+			_tmp18 = NULL;
 			_tmp17 = NULL;
 			_tmp16 = NULL;
-			_tmp15 = NULL;
-			vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), _tmp17 = g_strdup_printf ("Assignment: Cannot convert from `%s' to `%s'", _tmp15 = vala_code_node_to_string ((ValaCodeNode*) vala_expression_get_value_type (vala_local_variable_get_initializer (self))), _tmp16 = vala_code_node_to_string ((ValaCodeNode*) vala_local_variable_get_variable_type (self))));
+			vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), _tmp18 = g_strdup_printf ("Assignment: Cannot convert from `%s' to `%s'", _tmp16 = vala_code_node_to_string ((ValaCodeNode*) vala_expression_get_value_type (vala_local_variable_get_initializer (self))), _tmp17 = vala_code_node_to_string ((ValaCodeNode*) vala_local_variable_get_variable_type (self))));
+			_tmp18 = (g_free (_tmp18), NULL);
 			_tmp17 = (g_free (_tmp17), NULL);
 			_tmp16 = (g_free (_tmp16), NULL);
-			_tmp15 = (g_free (_tmp15), NULL);
 			return FALSE;
 		}
 		if (vala_data_type_is_disposable (vala_expression_get_value_type (vala_local_variable_get_initializer (self)))) {
-			gboolean _tmp19;
-			_tmp19 = FALSE;
+			gboolean _tmp20;
+			_tmp20 = FALSE;
 			if (!(VALA_IS_POINTER_TYPE (vala_local_variable_get_variable_type (self)))) {
-				_tmp19 = !vala_data_type_get_value_owned (vala_local_variable_get_variable_type (self));
+				_tmp20 = !vala_data_type_get_value_owned (vala_local_variable_get_variable_type (self));
 			} else {
-				_tmp19 = FALSE;
+				_tmp20 = FALSE;
 			}
 			/* rhs transfers ownership of the expression */
-			if (_tmp19) {
+			if (_tmp20) {
 				/* lhs doesn't own the value */
 				vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
 				vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), "Invalid assignment from owned expression to unowned variable");
@@ -258,11 +275,16 @@ static gboolean vala_local_variable_real_check (ValaCodeNode* base, ValaSemantic
 	}
 	vala_source_file_add_type_dependency (vala_semantic_analyzer_get_current_source_file (analyzer), vala_local_variable_get_variable_type (self), VALA_SOURCE_FILE_DEPENDENCY_TYPE_SOURCE);
 	vala_scope_add (vala_symbol_get_scope (vala_semantic_analyzer_get_current_symbol (analyzer)), vala_symbol_get_name ((ValaSymbol*) self), (ValaSymbol*) self);
-	_tmp21 = NULL;
-	block = (_tmp21 = VALA_BLOCK (vala_semantic_analyzer_get_current_symbol (analyzer)), (_tmp21 == NULL) ? NULL : vala_code_node_ref (_tmp21));
-	vala_block_add_local_variable (block, self);
+	/* current_symbol is a Method if this is the `result'
+	 variable used for postconditions*/
+	_tmp23 = NULL;
+	_tmp22 = NULL;
+	block = (_tmp23 = (_tmp22 = vala_semantic_analyzer_get_current_symbol (analyzer), VALA_IS_BLOCK (_tmp22) ? ((ValaBlock*) _tmp22) : NULL), (_tmp23 == NULL) ? NULL : vala_code_node_ref (_tmp23));
+	if (block != NULL) {
+		vala_block_add_local_variable (block, self);
+	}
 	vala_symbol_set_active ((ValaSymbol*) self, TRUE);
-	return (_tmp22 = !vala_code_node_get_error ((ValaCodeNode*) self), (block == NULL) ? NULL : (block = (vala_code_node_unref (block), NULL)), _tmp22);
+	return (_tmp24 = !vala_code_node_get_error ((ValaCodeNode*) self), (block == NULL) ? NULL : (block = (vala_code_node_unref (block), NULL)), _tmp24);
 }
 
 
@@ -352,5 +374,16 @@ GType vala_local_variable_get_type (void) {
 }
 
 
+static int _vala_strcmp0 (const char * str1, const char * str2) {
+	if (str1 == NULL) {
+		return -(str1 != str2);
+	}
+	if (str2 == NULL) {
+		return str1 != str2;
+	}
+	return strcmp (str1, str2);
+}
+
+
 
 
