@@ -22,9 +22,10 @@
 
 #include <vala/valamemberinitializer.h>
 #include <vala/valaexpression.h>
-#include <vala/valasourcereference.h>
 #include <vala/valasymbol.h>
+#include <vala/valasourcereference.h>
 #include <vala/valacodevisitor.h>
+#include <vala/valasemanticanalyzer.h>
 
 
 
@@ -40,6 +41,7 @@ enum  {
 	VALA_MEMBER_INITIALIZER_DUMMY_PROPERTY
 };
 static void vala_member_initializer_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
+static gboolean vala_member_initializer_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer);
 static gpointer vala_member_initializer_parent_class = NULL;
 static void vala_member_initializer_finalize (ValaCodeNode* obj);
 
@@ -57,9 +59,9 @@ ValaMemberInitializer* vala_member_initializer_construct (GType object_type, con
 	ValaMemberInitializer* self;
 	g_return_val_if_fail (name != NULL, NULL);
 	g_return_val_if_fail (initializer != NULL, NULL);
-	self = ((ValaMemberInitializer*) (g_type_create_instance (object_type)));
+	self = (ValaMemberInitializer*) g_type_create_instance (object_type);
 	vala_member_initializer_set_initializer (self, initializer);
-	vala_code_node_set_source_reference (((ValaCodeNode*) (self)), source_reference);
+	vala_code_node_set_source_reference ((ValaCodeNode*) self, source_reference);
 	vala_member_initializer_set_name (self, name);
 	return self;
 }
@@ -72,9 +74,17 @@ ValaMemberInitializer* vala_member_initializer_new (const char* name, ValaExpres
 
 static void vala_member_initializer_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaMemberInitializer * self;
-	self = ((ValaMemberInitializer*) (base));
+	self = (ValaMemberInitializer*) base;
 	g_return_if_fail (visitor != NULL);
-	vala_code_node_accept (((ValaCodeNode*) (self->priv->_initializer)), visitor);
+	vala_code_node_accept ((ValaCodeNode*) self->priv->_initializer, visitor);
+}
+
+
+static gboolean vala_member_initializer_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer) {
+	ValaMemberInitializer * self;
+	self = (ValaMemberInitializer*) base;
+	g_return_val_if_fail (analyzer != NULL, FALSE);
+	return vala_code_node_check ((ValaCodeNode*) self->priv->_initializer, analyzer);
 }
 
 
@@ -90,7 +100,7 @@ void vala_member_initializer_set_name (ValaMemberInitializer* self, const char*
 	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_name = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_name = (g_free (self->priv->_name), NULL)), _tmp2);
+	self->priv->_name = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : g_strdup (_tmp1)), self->priv->_name = (g_free (self->priv->_name), NULL), _tmp2);
 }
 
 
@@ -106,7 +116,7 @@ void vala_member_initializer_set_initializer (ValaMemberInitializer* self, ValaE
 	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_initializer = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1))), (self->priv->_initializer == NULL ? NULL : (self->priv->_initializer = (vala_code_node_unref (self->priv->_initializer), NULL))), _tmp2);
+	self->priv->_initializer = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : vala_code_node_ref (_tmp1)), (self->priv->_initializer == NULL) ? NULL : (self->priv->_initializer = (vala_code_node_unref (self->priv->_initializer), NULL)), _tmp2);
 }
 
 
@@ -127,6 +137,7 @@ static void vala_member_initializer_class_init (ValaMemberInitializerClass * kla
 	VALA_CODE_NODE_CLASS (klass)->finalize = vala_member_initializer_finalize;
 	g_type_class_add_private (klass, sizeof (ValaMemberInitializerPrivate));
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_member_initializer_real_accept;
+	VALA_CODE_NODE_CLASS (klass)->check = vala_member_initializer_real_check;
 }
 
 
@@ -139,7 +150,7 @@ static void vala_member_initializer_finalize (ValaCodeNode* obj) {
 	ValaMemberInitializer * self;
 	self = VALA_MEMBER_INITIALIZER (obj);
 	self->priv->_name = (g_free (self->priv->_name), NULL);
-	(self->priv->_initializer == NULL ? NULL : (self->priv->_initializer = (vala_code_node_unref (self->priv->_initializer), NULL)));
+	(self->priv->_initializer == NULL) ? NULL : (self->priv->_initializer = (vala_code_node_unref (self->priv->_initializer), NULL));
 	VALA_CODE_NODE_CLASS (vala_member_initializer_parent_class)->finalize (obj);
 }
 
