@@ -193,7 +193,7 @@ static void vala_method_call_real_replace_expression (ValaCodeNode* base, ValaEx
 		_tmp0 = FALSE;
 	}
 	if (_tmp0) {
-		gee_list_set ((GeeList*) self->priv->argument_list, index, new_node);
+		gee_list_set (self->priv->argument_list, index, new_node);
 		vala_code_node_set_parent_node ((ValaCodeNode*) new_node, (ValaCodeNode*) self);
 	}
 }
