@@ -758,7 +758,7 @@ static char* vala_namespace_real_get_cprefix (ValaSymbol* base) {
 	ValaNamespace * self;
 	self = (ValaNamespace*) base;
 	if (gee_collection_get_size ((GeeCollection*) self->priv->cprefixes) > 0) {
-		return (char*) gee_list_get ((GeeList*) self->priv->cprefixes, 0);
+		return (char*) gee_list_get (self->priv->cprefixes, 0);
 	} else {
 		if (NULL != vala_symbol_get_name ((ValaSymbol*) self)) {
 			char* parent_prefix;
