@@ -44,8 +44,8 @@ static gpointer vala_null_type_parent_class = NULL;
 ValaNullType* vala_null_type_construct (GType object_type, ValaSourceReference* source_reference) {
 	ValaNullType* self;
 	g_return_val_if_fail (source_reference != NULL, NULL);
-	self = ((ValaNullType*) (g_type_create_instance (object_type)));
-	vala_code_node_set_source_reference (((ValaCodeNode*) (self)), source_reference);
+	self = (ValaNullType*) g_type_create_instance (object_type);
+	vala_code_node_set_source_reference ((ValaCodeNode*) self, source_reference);
 	return self;
 }
 
@@ -57,19 +57,75 @@ ValaNullType* vala_null_type_new (ValaSourceReference* source_reference) {
 
 static gboolean vala_null_type_real_compatible (ValaDataType* base, ValaDataType* target_type) {
 	ValaNullType * self;
-	ValaAttribute* _tmp1;
-	gboolean _tmp2;
-	self = ((ValaNullType*) (base));
+	gboolean _tmp0;
+	gboolean _tmp4;
+	gboolean _tmp5;
+	gboolean _tmp6;
+	gboolean _tmp9;
+	gboolean _tmp10;
+	self = (ValaNullType*) base;
 	g_return_val_if_fail (target_type != NULL, FALSE);
-	if (!(VALA_IS_POINTER_TYPE (target_type)) && (VALA_IS_NULL_TYPE (target_type) || (vala_data_type_get_data_type (target_type) == NULL && vala_data_type_get_type_parameter (target_type) == NULL))) {
+	_tmp0 = FALSE;
+	if (!(VALA_IS_POINTER_TYPE (target_type))) {
+		gboolean _tmp1;
+		_tmp1 = FALSE;
+		if (VALA_IS_NULL_TYPE (target_type)) {
+			_tmp1 = TRUE;
+		} else {
+			gboolean _tmp2;
+			_tmp2 = FALSE;
+			if (vala_data_type_get_data_type (target_type) == NULL) {
+				_tmp2 = vala_data_type_get_type_parameter (target_type) == NULL;
+			} else {
+				_tmp2 = FALSE;
+			}
+			_tmp1 = (_tmp2);
+		}
+		_tmp0 = (_tmp1);
+	} else {
+		_tmp0 = FALSE;
+	}
+	if (_tmp0) {
 		return TRUE;
 	}
+	_tmp4 = FALSE;
+	_tmp5 = FALSE;
+	_tmp6 = FALSE;
+	if (vala_data_type_get_type_parameter (target_type) != NULL) {
+		_tmp6 = TRUE;
+	} else {
+		_tmp6 = VALA_IS_POINTER_TYPE (target_type);
+	}
+	if (_tmp6) {
+		_tmp5 = TRUE;
+	} else {
+		_tmp5 = vala_data_type_get_nullable (target_type);
+	}
+	if (_tmp5) {
+		_tmp4 = TRUE;
+	} else {
+		ValaAttribute* _tmp7;
+		_tmp7 = NULL;
+		_tmp4 = (_tmp7 = vala_code_node_get_attribute ((ValaCodeNode*) vala_data_type_get_data_type (target_type), "PointerType")) != NULL;
+		(_tmp7 == NULL) ? NULL : (_tmp7 = (vala_code_node_unref (_tmp7), NULL));
+	}
 	/* null can be cast to any reference or array type or pointer type */
-	_tmp1 = NULL;
-	if ((_tmp2 = vala_data_type_get_type_parameter (target_type) != NULL || VALA_IS_POINTER_TYPE (target_type) || vala_data_type_get_nullable (target_type) || (_tmp1 = vala_code_node_get_attribute (((ValaCodeNode*) (vala_data_type_get_data_type (target_type))), "PointerType")) != NULL, (_tmp1 == NULL ? NULL : (_tmp1 = (vala_code_node_unref (_tmp1), NULL))), _tmp2)) {
+	if (_tmp4) {
 		return TRUE;
 	}
-	if (vala_typesymbol_is_reference_type (vala_data_type_get_data_type (target_type)) || VALA_IS_ARRAY_TYPE (target_type) || VALA_IS_DELEGATE_TYPE (target_type)) {
+	_tmp9 = FALSE;
+	_tmp10 = FALSE;
+	if (vala_typesymbol_is_reference_type (vala_data_type_get_data_type (target_type))) {
+		_tmp10 = TRUE;
+	} else {
+		_tmp10 = VALA_IS_ARRAY_TYPE (target_type);
+	}
+	if (_tmp10) {
+		_tmp9 = TRUE;
+	} else {
+		_tmp9 = VALA_IS_DELEGATE_TYPE (target_type);
+	}
+	if (_tmp9) {
 		return TRUE;
 	}
 	/* null is not compatible with any other type (i.e. value types) */
@@ -79,21 +135,21 @@ static gboolean vala_null_type_real_compatible (ValaDataType* base, ValaDataType
 
 static ValaDataType* vala_null_type_real_copy (ValaDataType* base) {
 	ValaNullType * self;
-	self = ((ValaNullType*) (base));
-	return ((ValaDataType*) (vala_null_type_new (vala_code_node_get_source_reference (((ValaCodeNode*) (self))))));
+	self = (ValaNullType*) base;
+	return (ValaDataType*) vala_null_type_new (vala_code_node_get_source_reference ((ValaCodeNode*) self));
 }
 
 
 static char* vala_null_type_real_get_cname (ValaDataType* base) {
 	ValaNullType * self;
-	self = ((ValaNullType*) (base));
+	self = (ValaNullType*) base;
 	return g_strdup ("gpointer");
 }
 
 
 static gboolean vala_null_type_real_is_disposable (ValaDataType* base) {
 	ValaNullType * self;
-	self = ((ValaNullType*) (base));
+	self = (ValaNullType*) base;
 	return FALSE;
 }
 
