@@ -210,7 +210,7 @@ static void vala_object_creation_expression_real_replace_expression (ValaCodeNod
 		_tmp0 = FALSE;
 	}
 	if (_tmp0) {
-		gee_list_set ((GeeList*) self->priv->argument_list, index, new_node);
+		gee_list_set (self->priv->argument_list, index, new_node);
 		vala_code_node_set_parent_node ((ValaCodeNode*) new_node, (ValaCodeNode*) self);
 	}
 }
@@ -243,7 +243,7 @@ static gboolean vala_object_creation_expression_real_check (ValaCodeNode* base,
 	gint given_num_type_args;
 	gint expected_num_type_args;
 	gboolean _tmp42;
-	gboolean _tmp61;
+	gboolean _tmp62;
 	self = (ValaObjectCreationExpression*) base;
 	g_return_val_if_fail (analyzer != NULL, FALSE);
 	if (vala_code_node_get_checked ((ValaCodeNode*) self)) {
@@ -416,6 +416,10 @@ static gboolean vala_object_creation_expression_real_check (ValaCodeNode* base,
 		}
 		if (vala_expression_get_symbol_reference ((ValaExpression*) self) == NULL) {
 			vala_expression_set_symbol_reference ((ValaExpression*) self, (ValaSymbol*) vala_class_get_default_construction_method (cl));
+			if (vala_expression_get_symbol_reference ((ValaExpression*) self) != NULL) {
+				/* track usage for flow analyzer*/
+				vala_symbol_set_used (vala_expression_get_symbol_reference ((ValaExpression*) self), TRUE);
+			}
 		}
 		while (cl != NULL) {
 			ValaClass* _tmp36;
@@ -495,8 +499,8 @@ static gboolean vala_object_creation_expression_real_check (ValaCodeNode* base,
 		ValaMethod* m;
 		GeeList* args;
 		GeeIterator* arg_it;
-		GeeList* _tmp51;
-		ValaMethodType* _tmp50;
+		GeeList* _tmp52;
+		ValaMethodType* _tmp51;
 		_tmp47 = NULL;
 		m = (_tmp47 = VALA_METHOD (vala_expression_get_symbol_reference ((ValaExpression*) self)), (_tmp47 == NULL) ? NULL : vala_code_node_ref (_tmp47));
 		args = vala_object_creation_expression_get_argument_list (self);
@@ -517,9 +521,13 @@ static gboolean vala_object_creation_expression_real_check (ValaCodeNode* base,
 				}
 				if (gee_iterator_next (arg_it)) {
 					ValaExpression* arg;
+					ValaDataType* _tmp50;
 					arg = (ValaExpression*) gee_iterator_get (arg_it);
 					/* store expected type for callback parameters */
-					vala_expression_set_target_type (arg, vala_formal_parameter_get_parameter_type (param));
+					vala_expression_set_formal_target_type (arg, vala_formal_parameter_get_parameter_type (param));
+					_tmp50 = NULL;
+					vala_expression_set_target_type (arg, _tmp50 = vala_data_type_get_actual_type (vala_expression_get_formal_target_type (arg), vala_expression_get_value_type ((ValaExpression*) self), (ValaCodeNode*) self));
+					(_tmp50 == NULL) ? NULL : (_tmp50 = (vala_code_node_unref (_tmp50), NULL));
 					(arg == NULL) ? NULL : (arg = (vala_code_node_unref (arg), NULL));
 				}
 				(param == NULL) ? NULL : (param = (vala_code_node_unref (param), NULL));
@@ -537,18 +545,18 @@ static gboolean vala_object_creation_expression_real_check (ValaCodeNode* base,
 			}
 			(_arg_it == NULL) ? NULL : (_arg_it = (gee_collection_object_unref (_arg_it), NULL));
 		}
+		_tmp52 = NULL;
 		_tmp51 = NULL;
-		_tmp50 = NULL;
-		vala_semantic_analyzer_check_arguments (analyzer, (ValaExpression*) self, (ValaDataType*) (_tmp50 = vala_method_type_new (m)), _tmp51 = vala_method_get_parameters (m), args);
-		(_tmp51 == NULL) ? NULL : (_tmp51 = (gee_collection_object_unref (_tmp51), NULL));
-		(_tmp50 == NULL) ? NULL : (_tmp50 = (vala_code_node_unref (_tmp50), NULL));
+		vala_semantic_analyzer_check_arguments (analyzer, (ValaExpression*) self, (ValaDataType*) (_tmp51 = vala_method_type_new (m)), _tmp52 = vala_method_get_parameters (m), args);
+		(_tmp52 == NULL) ? NULL : (_tmp52 = (gee_collection_object_unref (_tmp52), NULL));
+		(_tmp51 == NULL) ? NULL : (_tmp51 = (vala_code_node_unref (_tmp51), NULL));
 		{
-			GeeList* _tmp52;
-			GeeIterator* _tmp53;
+			GeeList* _tmp53;
+			GeeIterator* _tmp54;
 			GeeIterator* _error_type_it;
-			_tmp52 = NULL;
 			_tmp53 = NULL;
-			_error_type_it = (_tmp53 = gee_iterable_iterator ((GeeIterable*) (_tmp52 = vala_code_node_get_error_types ((ValaCodeNode*) m))), (_tmp52 == NULL) ? NULL : (_tmp52 = (gee_collection_object_unref (_tmp52), NULL)), _tmp53);
+			_tmp54 = NULL;
+			_error_type_it = (_tmp54 = gee_iterable_iterator ((GeeIterable*) (_tmp53 = vala_code_node_get_error_types ((ValaCodeNode*) m))), (_tmp53 == NULL) ? NULL : (_tmp53 = (gee_collection_object_unref (_tmp53), NULL)), _tmp54);
 			while (gee_iterator_next (_error_type_it)) {
 				ValaDataType* error_type;
 				ValaDataType* call_error_type;
@@ -567,8 +575,8 @@ static gboolean vala_object_creation_expression_real_check (ValaCodeNode* base,
 		(arg_it == NULL) ? NULL : (arg_it = (gee_collection_object_unref (arg_it), NULL));
 	} else {
 		if (VALA_IS_ERROR_TYPE (vala_object_creation_expression_get_type_reference (self))) {
-			GeeList* _tmp54;
-			gboolean _tmp55;
+			GeeList* _tmp55;
+			gboolean _tmp56;
 			if (vala_object_creation_expression_get_type_reference (self) != NULL) {
 				vala_code_node_check ((ValaCodeNode*) vala_object_creation_expression_get_type_reference (self), analyzer);
 			}
@@ -597,28 +605,28 @@ static gboolean vala_object_creation_expression_real_check (ValaCodeNode* base,
 				}
 				(_init_it == NULL) ? NULL : (_init_it = (gee_collection_object_unref (_init_it), NULL));
 			}
-			_tmp54 = NULL;
-			if ((_tmp55 = gee_collection_get_size ((GeeCollection*) (_tmp54 = vala_object_creation_expression_get_argument_list (self))) == 0, (_tmp54 == NULL) ? NULL : (_tmp54 = (gee_collection_object_unref (_tmp54), NULL)), _tmp55)) {
+			_tmp55 = NULL;
+			if ((_tmp56 = gee_collection_get_size ((GeeCollection*) (_tmp55 = vala_object_creation_expression_get_argument_list (self))) == 0, (_tmp55 == NULL) ? NULL : (_tmp55 = (gee_collection_object_unref (_tmp55), NULL)), _tmp56)) {
 				vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
 				vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), "Too few arguments, errors need at least 1 argument");
 			} else {
-				GeeList* _tmp56;
-				GeeIterator* _tmp57;
+				GeeList* _tmp57;
+				GeeIterator* _tmp58;
 				GeeIterator* arg_it;
 				ValaExpression* ex;
-				gboolean _tmp58;
-				_tmp56 = NULL;
+				gboolean _tmp59;
 				_tmp57 = NULL;
-				arg_it = (_tmp57 = gee_iterable_iterator ((GeeIterable*) (_tmp56 = vala_object_creation_expression_get_argument_list (self))), (_tmp56 == NULL) ? NULL : (_tmp56 = (gee_collection_object_unref (_tmp56), NULL)), _tmp57);
+				_tmp58 = NULL;
+				arg_it = (_tmp58 = gee_iterable_iterator ((GeeIterable*) (_tmp57 = vala_object_creation_expression_get_argument_list (self))), (_tmp57 == NULL) ? NULL : (_tmp57 = (gee_collection_object_unref (_tmp57), NULL)), _tmp58);
 				gee_iterator_next (arg_it);
 				ex = (ValaExpression*) gee_iterator_get (arg_it);
-				_tmp58 = FALSE;
+				_tmp59 = FALSE;
 				if (vala_expression_get_value_type (ex) == NULL) {
-					_tmp58 = TRUE;
+					_tmp59 = TRUE;
 				} else {
-					_tmp58 = !vala_data_type_compatible (vala_expression_get_value_type (ex), analyzer->string_type);
+					_tmp59 = !vala_data_type_compatible (vala_expression_get_value_type (ex), analyzer->string_type);
 				}
-				if (_tmp58) {
+				if (_tmp59) {
 					vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
 					vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), "Invalid type for argument 1");
 				}
@@ -628,12 +636,12 @@ static gboolean vala_object_creation_expression_real_check (ValaCodeNode* base,
 		}
 	}
 	{
-		GeeList* _tmp59;
-		GeeIterator* _tmp60;
+		GeeList* _tmp60;
+		GeeIterator* _tmp61;
 		GeeIterator* _init_it;
-		_tmp59 = NULL;
 		_tmp60 = NULL;
-		_init_it = (_tmp60 = gee_iterable_iterator ((GeeIterable*) (_tmp59 = vala_object_creation_expression_get_object_initializer (self))), (_tmp59 == NULL) ? NULL : (_tmp59 = (gee_collection_object_unref (_tmp59), NULL)), _tmp60);
+		_tmp61 = NULL;
+		_init_it = (_tmp61 = gee_iterable_iterator ((GeeIterable*) (_tmp60 = vala_object_creation_expression_get_object_initializer (self))), (_tmp60 == NULL) ? NULL : (_tmp60 = (gee_collection_object_unref (_tmp60), NULL)), _tmp61);
 		while (gee_iterator_next (_init_it)) {
 			ValaMemberInitializer* init;
 			init = (ValaMemberInitializer*) gee_iterator_get (_init_it);
@@ -642,7 +650,7 @@ static gboolean vala_object_creation_expression_real_check (ValaCodeNode* base,
 		}
 		(_init_it == NULL) ? NULL : (_init_it = (gee_collection_object_unref (_init_it), NULL));
 	}
-	return (_tmp61 = !vala_code_node_get_error ((ValaCodeNode*) self), (type == NULL) ? NULL : (type = (vala_code_node_unref (type), NULL)), _tmp61);
+	return (_tmp62 = !vala_code_node_get_error ((ValaCodeNode*) self), (type == NULL) ? NULL : (type = (vala_code_node_unref (type), NULL)), _tmp62);
 }
 
 
