@@ -21,8 +21,16 @@
  */
 
 #include <vala/valareferencetransferexpression.h>
+#include <stdlib.h>
+#include <string.h>
 #include <vala/valasourcereference.h>
 #include <vala/valacodevisitor.h>
+#include <vala/valasemanticanalyzer.h>
+#include <vala/valamemberaccess.h>
+#include <vala/valaelementaccess.h>
+#include <vala/valareport.h>
+#include <vala/valadatatype.h>
+#include <vala/valapointertype.h>
 
 
 
@@ -39,6 +47,9 @@ static void vala_reference_transfer_expression_real_accept (ValaCodeNode* base,
 static void vala_reference_transfer_expression_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_reference_transfer_expression_real_replace_expression (ValaCodeNode* base, ValaExpression* old_node, ValaExpression* new_node);
 static gboolean vala_reference_transfer_expression_real_is_pure (ValaExpression* base);
+static gboolean vala_reference_transfer_expression_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer);
+static void vala_reference_transfer_expression_real_get_defined_variables (ValaCodeNode* base, GeeCollection* collection);
+static void vala_reference_transfer_expression_real_get_used_variables (ValaCodeNode* base, GeeCollection* collection);
 static gpointer vala_reference_transfer_expression_parent_class = NULL;
 static void vala_reference_transfer_expression_finalize (ValaCodeNode* obj);
 
@@ -53,9 +64,9 @@ static void vala_reference_transfer_expression_finalize (ValaCodeNode* obj);
 ValaReferenceTransferExpression* vala_reference_transfer_expression_construct (GType object_type, ValaExpression* inner, ValaSourceReference* source_reference) {
 	ValaReferenceTransferExpression* self;
 	g_return_val_if_fail (inner != NULL, NULL);
-	self = ((ValaReferenceTransferExpression*) (g_type_create_instance (object_type)));
+	self = (ValaReferenceTransferExpression*) g_type_create_instance (object_type);
 	vala_reference_transfer_expression_set_inner (self, inner);
-	vala_code_node_set_source_reference (((ValaCodeNode*) (self)), source_reference);
+	vala_code_node_set_source_reference ((ValaCodeNode*) self, source_reference);
 	return self;
 }
 
@@ -67,24 +78,24 @@ ValaReferenceTransferExpression* vala_reference_transfer_expression_new (ValaExp
 
 static void vala_reference_transfer_expression_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaReferenceTransferExpression * self;
-	self = ((ValaReferenceTransferExpression*) (base));
+	self = (ValaReferenceTransferExpression*) base;
 	g_return_if_fail (visitor != NULL);
 	vala_code_visitor_visit_reference_transfer_expression (visitor, self);
-	vala_code_visitor_visit_expression (visitor, ((ValaExpression*) (self)));
+	vala_code_visitor_visit_expression (visitor, (ValaExpression*) self);
 }
 
 
 static void vala_reference_transfer_expression_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaReferenceTransferExpression * self;
-	self = ((ValaReferenceTransferExpression*) (base));
+	self = (ValaReferenceTransferExpression*) base;
 	g_return_if_fail (visitor != NULL);
-	vala_code_node_accept (((ValaCodeNode*) (vala_reference_transfer_expression_get_inner (self))), visitor);
+	vala_code_node_accept ((ValaCodeNode*) vala_reference_transfer_expression_get_inner (self), visitor);
 }
 
 
 static void vala_reference_transfer_expression_real_replace_expression (ValaCodeNode* base, ValaExpression* old_node, ValaExpression* new_node) {
 	ValaReferenceTransferExpression * self;
-	self = ((ValaReferenceTransferExpression*) (base));
+	self = (ValaReferenceTransferExpression*) base;
 	g_return_if_fail (old_node != NULL);
 	g_return_if_fail (new_node != NULL);
 	if (vala_reference_transfer_expression_get_inner (self) == old_node) {
@@ -95,11 +106,75 @@ static void vala_reference_transfer_expression_real_replace_expression (ValaCode
 
 static gboolean vala_reference_transfer_expression_real_is_pure (ValaExpression* base) {
 	ValaReferenceTransferExpression * self;
-	self = ((ValaReferenceTransferExpression*) (base));
+	self = (ValaReferenceTransferExpression*) base;
 	return FALSE;
 }
 
 
+static gboolean vala_reference_transfer_expression_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer) {
+	ValaReferenceTransferExpression * self;
+	gboolean _tmp2;
+	gboolean _tmp4;
+	ValaDataType* _tmp6;
+	self = (ValaReferenceTransferExpression*) base;
+	g_return_val_if_fail (analyzer != NULL, FALSE);
+	if (vala_code_node_get_checked ((ValaCodeNode*) self)) {
+		return !vala_code_node_get_error ((ValaCodeNode*) self);
+	}
+	vala_code_node_set_checked ((ValaCodeNode*) self, TRUE);
+	vala_expression_set_lvalue (vala_reference_transfer_expression_get_inner (self), TRUE);
+	vala_code_node_check ((ValaCodeNode*) vala_reference_transfer_expression_get_inner (self), analyzer);
+	if (vala_code_node_get_error ((ValaCodeNode*) vala_reference_transfer_expression_get_inner (self))) {
+		/* if there was an error in the inner expression, skip type check */
+		vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
+		return FALSE;
+	}
+	_tmp2 = FALSE;
+	if (VALA_IS_MEMBER_ACCESS (vala_reference_transfer_expression_get_inner (self))) {
+		_tmp2 = TRUE;
+	} else {
+		_tmp2 = VALA_IS_ELEMENT_ACCESS (vala_reference_transfer_expression_get_inner (self));
+	}
+	if (!(_tmp2)) {
+		vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
+		vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), "Reference transfer not supported for this expression");
+		return FALSE;
+	}
+	_tmp4 = FALSE;
+	if (!vala_data_type_is_disposable (vala_expression_get_value_type (vala_reference_transfer_expression_get_inner (self)))) {
+		_tmp4 = !(VALA_IS_POINTER_TYPE (vala_expression_get_value_type (vala_reference_transfer_expression_get_inner (self))));
+	} else {
+		_tmp4 = FALSE;
+	}
+	if (_tmp4) {
+		vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
+		vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), "No reference to be transferred");
+		return FALSE;
+	}
+	_tmp6 = NULL;
+	vala_expression_set_value_type ((ValaExpression*) self, _tmp6 = vala_data_type_copy (vala_expression_get_value_type (vala_reference_transfer_expression_get_inner (self))));
+	(_tmp6 == NULL) ? NULL : (_tmp6 = (vala_code_node_unref (_tmp6), NULL));
+	vala_data_type_set_value_owned (vala_expression_get_value_type ((ValaExpression*) self), TRUE);
+	return !vala_code_node_get_error ((ValaCodeNode*) self);
+}
+
+
+static void vala_reference_transfer_expression_real_get_defined_variables (ValaCodeNode* base, GeeCollection* collection) {
+	ValaReferenceTransferExpression * self;
+	self = (ValaReferenceTransferExpression*) base;
+	g_return_if_fail (collection != NULL);
+	vala_code_node_get_defined_variables ((ValaCodeNode*) vala_reference_transfer_expression_get_inner (self), collection);
+}
+
+
+static void vala_reference_transfer_expression_real_get_used_variables (ValaCodeNode* base, GeeCollection* collection) {
+	ValaReferenceTransferExpression * self;
+	self = (ValaReferenceTransferExpression*) base;
+	g_return_if_fail (collection != NULL);
+	vala_code_node_get_used_variables ((ValaCodeNode*) vala_reference_transfer_expression_get_inner (self), collection);
+}
+
+
 ValaExpression* vala_reference_transfer_expression_get_inner (ValaReferenceTransferExpression* self) {
 	g_return_val_if_fail (self != NULL, NULL);
 	return self->priv->_inner;
@@ -112,8 +187,8 @@ void vala_reference_transfer_expression_set_inner (ValaReferenceTransferExpressi
 	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_inner = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1))), (self->priv->_inner == NULL ? NULL : (self->priv->_inner = (vala_code_node_unref (self->priv->_inner), NULL))), _tmp2);
-	vala_code_node_set_parent_node (((ValaCodeNode*) (self->priv->_inner)), ((ValaCodeNode*) (self)));
+	self->priv->_inner = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : vala_code_node_ref (_tmp1)), (self->priv->_inner == NULL) ? NULL : (self->priv->_inner = (vala_code_node_unref (self->priv->_inner), NULL)), _tmp2);
+	vala_code_node_set_parent_node ((ValaCodeNode*) self->priv->_inner, (ValaCodeNode*) self);
 }
 
 
@@ -125,6 +200,9 @@ static void vala_reference_transfer_expression_class_init (ValaReferenceTransfer
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_reference_transfer_expression_real_accept_children;
 	VALA_CODE_NODE_CLASS (klass)->replace_expression = vala_reference_transfer_expression_real_replace_expression;
 	VALA_EXPRESSION_CLASS (klass)->is_pure = vala_reference_transfer_expression_real_is_pure;
+	VALA_CODE_NODE_CLASS (klass)->check = vala_reference_transfer_expression_real_check;
+	VALA_CODE_NODE_CLASS (klass)->get_defined_variables = vala_reference_transfer_expression_real_get_defined_variables;
+	VALA_CODE_NODE_CLASS (klass)->get_used_variables = vala_reference_transfer_expression_real_get_used_variables;
 }
 
 
@@ -136,7 +214,7 @@ static void vala_reference_transfer_expression_instance_init (ValaReferenceTrans
 static void vala_reference_transfer_expression_finalize (ValaCodeNode* obj) {
 	ValaReferenceTransferExpression * self;
 	self = VALA_REFERENCE_TRANSFER_EXPRESSION (obj);
-	(self->priv->_inner == NULL ? NULL : (self->priv->_inner = (vala_code_node_unref (self->priv->_inner), NULL)));
+	(self->priv->_inner == NULL) ? NULL : (self->priv->_inner = (vala_code_node_unref (self->priv->_inner), NULL));
 	VALA_CODE_NODE_CLASS (vala_reference_transfer_expression_parent_class)->finalize (obj);
 }
 
