@@ -32,29 +32,19 @@ static gpointer vala_reference_type_parent_class = NULL;
 
 
 
-/**
- * A reference type, i.e. a class, interface, or array type.
- */
-ValaReferenceType* vala_reference_type_new (void) {
-	ValaReferenceType * self;
-	self = g_object_newv (VALA_TYPE_REFERENCE_TYPE, 0, NULL);
-	return self;
-}
-
-
 static void vala_reference_type_class_init (ValaReferenceTypeClass * klass) {
 	vala_reference_type_parent_class = g_type_class_peek_parent (klass);
 }
 
 
-static void vala_reference_type_init (ValaReferenceType * self) {
+static void vala_reference_type_instance_init (ValaReferenceType * self) {
 }
 
 
 GType vala_reference_type_get_type (void) {
 	static GType vala_reference_type_type_id = 0;
-	if (G_UNLIKELY (vala_reference_type_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaReferenceTypeClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_reference_type_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaReferenceType), 0, (GInstanceInitFunc) vala_reference_type_init };
+	if (vala_reference_type_type_id == 0) {
+		static const GTypeInfo g_define_type_info = { sizeof (ValaReferenceTypeClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_reference_type_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaReferenceType), 0, (GInstanceInitFunc) vala_reference_type_instance_init, NULL };
 		vala_reference_type_type_id = g_type_register_static (VALA_TYPE_DATA_TYPE, "ValaReferenceType", &g_define_type_info, G_TYPE_FLAG_ABSTRACT);
 	}
 	return vala_reference_type_type_id;
