@@ -33,9 +33,13 @@ G_BEGIN_DECLS
 
 
 
+extern gint vala_report_warnings;
+extern gint vala_report_errors;
+extern gboolean vala_report_verbose_errors;
 void vala_report_set_verbose_errors (gboolean verbose);
 gint vala_report_get_warnings (void);
 gint vala_report_get_errors (void);
+void vala_report_report_source (ValaSourceReference* source);
 void vala_report_warning (ValaSourceReference* source, const char* message);
 void vala_report_error (ValaSourceReference* source, const char* message);
 
