@@ -99,7 +99,7 @@ void vala_scope_add (ValaScope* self, const char* name, ValaSymbol* sym) {
 				return;
 			}
 		}
-		gee_map_set ((GeeMap*) self->priv->symbol_table, (const char*) name, sym);
+		gee_map_set (self->priv->symbol_table, (const char*) name, sym);
 	} else {
 		if (self->priv->anonymous_members == NULL) {
 			GeeList* _tmp5;
@@ -134,7 +134,7 @@ ValaSymbol* vala_scope_lookup (ValaScope* self, const char* name) {
 	if (self->priv->symbol_table == NULL) {
 		return NULL;
 	}
-	sym = (ValaSymbol*) gee_map_get ((GeeMap*) self->priv->symbol_table, name);
+	sym = (ValaSymbol*) gee_map_get (self->priv->symbol_table, name);
 	_tmp1 = FALSE;
 	if (sym != NULL) {
 		_tmp1 = !vala_symbol_get_active (sym);
