@@ -1,6 +1,6 @@
 /* valasourcefile.vala
  *
- * Copyright (C) 2006-2008  Jürg Billeter
+ * Copyright (C) 2006-2009  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -24,17 +24,17 @@
 #include <gee/arraylist.h>
 #include <gee/collection.h>
 #include <glib/gstdio.h>
-#include <gee/readonlylist.h>
 #include <gee/iterable.h>
 #include <gee/iterator.h>
 #include <gee/hashset.h>
+#include <gee/readonlylist.h>
 #include <gee/readonlyset.h>
 #include <vala/valasourcefilecycle.h>
 #include <vala/valacodecontext.h>
-#include <vala/valausingdirective.h>
 #include <vala/valadatatype.h>
 #include <vala/valasymbol.h>
 #include <vala/valaerrorcode.h>
+#include <vala/valaenumvalue.h>
 #include <vala/valatypesymbol.h>
 #include <vala/valamethod.h>
 #include <vala/valafield.h>
@@ -42,6 +42,7 @@
 #include <vala/valaconstant.h>
 #include <vala/valaformalparameter.h>
 #include <vala/valasourcereference.h>
+#include <vala/valausingdirective.h>
 #include <vala/valacodevisitor.h>
 #include <vala/valasemanticanalyzer.h>
 #include <vala/valaunresolvedsymbol.h>
@@ -440,63 +441,70 @@ char* vala_source_file_get_cinclude_filename (ValaSourceFile* self) {
  */
 void vala_source_file_add_symbol_dependency (ValaSourceFile* self, ValaSymbol* sym, ValaSourceFileDependencyType dep_type) {
 	ValaSymbol* s;
+	gboolean _tmp0;
 	g_return_if_fail (self != NULL);
 	if (self->priv->_external_package) {
 		return;
 	}
 	s = NULL;
+	_tmp0 = FALSE;
 	if (VALA_IS_ERROR_CODE (sym)) {
+		_tmp0 = TRUE;
+	} else {
+		_tmp0 = VALA_IS_ENUM_VALUE (sym);
+	}
+	if (_tmp0) {
+		ValaSymbol* _tmp2;
 		ValaSymbol* _tmp1;
-		ValaSymbol* _tmp0;
+		_tmp2 = NULL;
 		_tmp1 = NULL;
-		_tmp0 = NULL;
-		s = (_tmp1 = (_tmp0 = vala_symbol_get_parent_symbol (sym), (_tmp0 == NULL) ? NULL : vala_code_node_ref (_tmp0)), (s == NULL) ? NULL : (s = (vala_code_node_unref (s), NULL)), _tmp1);
+		s = (_tmp2 = (_tmp1 = vala_symbol_get_parent_symbol (sym), (_tmp1 == NULL) ? NULL : vala_code_node_ref (_tmp1)), (s == NULL) ? NULL : (s = (vala_code_node_unref (s), NULL)), _tmp2);
 	} else {
-		gboolean _tmp2;
 		gboolean _tmp3;
 		gboolean _tmp4;
 		gboolean _tmp5;
-		_tmp2 = FALSE;
+		gboolean _tmp6;
 		_tmp3 = FALSE;
 		_tmp4 = FALSE;
 		_tmp5 = FALSE;
+		_tmp6 = FALSE;
 		if (VALA_IS_TYPESYMBOL (sym)) {
+			_tmp6 = TRUE;
+		} else {
+			_tmp6 = VALA_IS_METHOD (sym);
+		}
+		if (_tmp6) {
 			_tmp5 = TRUE;
 		} else {
-			_tmp5 = VALA_IS_METHOD (sym);
+			_tmp5 = VALA_IS_FIELD (sym);
 		}
 		if (_tmp5) {
 			_tmp4 = TRUE;
 		} else {
-			_tmp4 = VALA_IS_FIELD (sym);
+			_tmp4 = VALA_IS_PROPERTY (sym);
 		}
 		if (_tmp4) {
 			_tmp3 = TRUE;
 		} else {
-			_tmp3 = VALA_IS_PROPERTY (sym);
+			_tmp3 = VALA_IS_CONSTANT (sym);
 		}
 		if (_tmp3) {
-			_tmp2 = TRUE;
-		} else {
-			_tmp2 = VALA_IS_CONSTANT (sym);
-		}
-		if (_tmp2) {
+			ValaSymbol* _tmp8;
 			ValaSymbol* _tmp7;
-			ValaSymbol* _tmp6;
+			_tmp8 = NULL;
 			_tmp7 = NULL;
-			_tmp6 = NULL;
-			s = (_tmp7 = (_tmp6 = sym, (_tmp6 == NULL) ? NULL : vala_code_node_ref (_tmp6)), (s == NULL) ? NULL : (s = (vala_code_node_unref (s), NULL)), _tmp7);
+			s = (_tmp8 = (_tmp7 = sym, (_tmp7 == NULL) ? NULL : vala_code_node_ref (_tmp7)), (s == NULL) ? NULL : (s = (vala_code_node_unref (s), NULL)), _tmp8);
 		} else {
 			if (VALA_IS_FORMAL_PARAMETER (sym)) {
-				ValaFormalParameter* _tmp8;
+				ValaFormalParameter* _tmp9;
 				ValaFormalParameter* fp;
+				ValaSymbol* _tmp11;
 				ValaSymbol* _tmp10;
-				ValaSymbol* _tmp9;
-				_tmp8 = NULL;
-				fp = (_tmp8 = VALA_FORMAL_PARAMETER (sym), (_tmp8 == NULL) ? NULL : vala_code_node_ref (_tmp8));
-				_tmp10 = NULL;
 				_tmp9 = NULL;
-				s = (_tmp10 = (_tmp9 = (ValaSymbol*) vala_data_type_get_data_type (vala_formal_parameter_get_parameter_type (fp)), (_tmp9 == NULL) ? NULL : vala_code_node_ref (_tmp9)), (s == NULL) ? NULL : (s = (vala_code_node_unref (s), NULL)), _tmp10);
+				fp = (_tmp9 = VALA_FORMAL_PARAMETER (sym), (_tmp9 == NULL) ? NULL : vala_code_node_ref (_tmp9));
+				_tmp11 = NULL;
+				_tmp10 = NULL;
+				s = (_tmp11 = (_tmp10 = (ValaSymbol*) vala_data_type_get_data_type (vala_formal_parameter_get_parameter_type (fp)), (_tmp10 == NULL) ? NULL : vala_code_node_ref (_tmp10)), (s == NULL) ? NULL : (s = (vala_code_node_unref (s), NULL)), _tmp11);
 				if (s == NULL) {
 					/* generic type parameter */
 					(fp == NULL) ? NULL : (fp = (vala_code_node_unref (fp), NULL));
@@ -514,12 +522,12 @@ void vala_source_file_add_symbol_dependency (ValaSourceFile* self, ValaSymbol* s
 		gee_collection_add ((GeeCollection*) self->priv->source_symbol_dependencies, s);
 		if (vala_symbol_get_external_package (s)) {
 			{
-				GeeList* _tmp11;
-				GeeIterator* _tmp12;
+				GeeList* _tmp12;
+				GeeIterator* _tmp13;
 				GeeIterator* _fn_it;
-				_tmp11 = NULL;
 				_tmp12 = NULL;
-				_fn_it = (_tmp12 = gee_iterable_iterator ((GeeIterable*) (_tmp11 = vala_symbol_get_cheader_filenames (s))), (_tmp11 == NULL) ? NULL : (_tmp11 = (gee_collection_object_unref (_tmp11), NULL)), _tmp12);
+				_tmp13 = NULL;
+				_fn_it = (_tmp13 = gee_iterable_iterator ((GeeIterable*) (_tmp12 = vala_symbol_get_cheader_filenames (s))), (_tmp12 == NULL) ? NULL : (_tmp12 = (gee_collection_object_unref (_tmp12), NULL)), _tmp13);
 				while (gee_iterator_next (_fn_it)) {
 					char* fn;
 					fn = (char*) gee_iterator_get (_fn_it);
@@ -530,12 +538,12 @@ void vala_source_file_add_symbol_dependency (ValaSourceFile* self, ValaSymbol* s
 			}
 		} else {
 			{
-				GeeList* _tmp13;
-				GeeIterator* _tmp14;
+				GeeList* _tmp14;
+				GeeIterator* _tmp15;
 				GeeIterator* _fn_it;
-				_tmp13 = NULL;
 				_tmp14 = NULL;
-				_fn_it = (_tmp14 = gee_iterable_iterator ((GeeIterable*) (_tmp13 = vala_symbol_get_cheader_filenames (s))), (_tmp13 == NULL) ? NULL : (_tmp13 = (gee_collection_object_unref (_tmp13), NULL)), _tmp14);
+				_tmp15 = NULL;
+				_fn_it = (_tmp15 = gee_iterable_iterator ((GeeIterable*) (_tmp14 = vala_symbol_get_cheader_filenames (s))), (_tmp14 == NULL) ? NULL : (_tmp14 = (gee_collection_object_unref (_tmp14), NULL)), _tmp15);
 				while (gee_iterator_next (_fn_it)) {
 					char* fn;
 					fn = (char*) gee_iterator_get (_fn_it);
@@ -551,13 +559,13 @@ void vala_source_file_add_symbol_dependency (ValaSourceFile* self, ValaSymbol* s
 	if (vala_symbol_get_external_package (s)) {
 		/* external package */
 		{
-			GeeList* _tmp15;
-			GeeIterator* _tmp16;
+			GeeList* _tmp16;
+			GeeIterator* _tmp17;
 			GeeIterator* _fn_it;
 			/* external package */
-			_tmp15 = NULL;
 			_tmp16 = NULL;
-			_fn_it = (_tmp16 = gee_iterable_iterator ((GeeIterable*) (_tmp15 = vala_symbol_get_cheader_filenames (s))), (_tmp15 == NULL) ? NULL : (_tmp15 = (gee_collection_object_unref (_tmp15), NULL)), _tmp16);
+			_tmp17 = NULL;
+			_fn_it = (_tmp17 = gee_iterable_iterator ((GeeIterable*) (_tmp16 = vala_symbol_get_cheader_filenames (s))), (_tmp16 == NULL) ? NULL : (_tmp16 = (gee_collection_object_unref (_tmp16), NULL)), _tmp17);
 			/* external package */
 			while (gee_iterator_next (_fn_it)) {
 				char* fn;
@@ -573,12 +581,12 @@ void vala_source_file_add_symbol_dependency (ValaSourceFile* self, ValaSymbol* s
 	}
 	if (dep_type == VALA_SOURCE_FILE_DEPENDENCY_TYPE_HEADER_FULL) {
 		{
-			GeeList* _tmp17;
-			GeeIterator* _tmp18;
+			GeeList* _tmp18;
+			GeeIterator* _tmp19;
 			GeeIterator* _fn_it;
-			_tmp17 = NULL;
 			_tmp18 = NULL;
-			_fn_it = (_tmp18 = gee_iterable_iterator ((GeeIterable*) (_tmp17 = vala_symbol_get_cheader_filenames (s))), (_tmp17 == NULL) ? NULL : (_tmp17 = (gee_collection_object_unref (_tmp17), NULL)), _tmp18);
+			_tmp19 = NULL;
+			_fn_it = (_tmp19 = gee_iterable_iterator ((GeeIterable*) (_tmp18 = vala_symbol_get_cheader_filenames (s))), (_tmp18 == NULL) ? NULL : (_tmp18 = (gee_collection_object_unref (_tmp18), NULL)), _tmp19);
 			while (gee_iterator_next (_fn_it)) {
 				char* fn;
 				fn = (char*) gee_iterator_get (_fn_it);
