@@ -22,25 +22,25 @@
 
 #include <vala/valastruct.h>
 #include <gee/arraylist.h>
+#include <gee/collection.h>
+#include <gee/readonlylist.h>
 #include <gee/iterable.h>
 #include <gee/iterator.h>
-#include <gee/readonlylist.h>
-#include <gee/collection.h>
 #include <vala/valatypeparameter.h>
+#include <vala/valaconstant.h>
 #include <vala/valafield.h>
-#include <vala/valamember.h>
-#include <vala/valadatatype.h>
 #include <vala/valamethod.h>
+#include <vala/valadatatype.h>
+#include <vala/valasourcereference.h>
+#include <vala/valasymbol.h>
+#include <vala/valascope.h>
+#include <vala/valamember.h>
 #include <vala/valacodevisitor.h>
 #include <vala/valasemanticanalyzer.h>
 #include <vala/valaattribute.h>
 #include <vala/valasourcefile.h>
-#include <vala/valasymbol.h>
-#include <vala/valasourcereference.h>
 #include <vala/valastructvaluetype.h>
 #include <vala/valareport.h>
-#include <vala/valaconstant.h>
-#include <vala/valascope.h>
 #include <vala/valacreationmethod.h>
 #include <vala/valaformalparameter.h>
 #include <vala/valavoidtype.h>
@@ -55,7 +55,7 @@ struct _ValaStructPrivate {
 	GeeList* constants;
 	GeeList* fields;
 	GeeList* methods;
-	GeeList* base_types;
+	ValaDataType* _base_type;
 	char* cname;
 	char* const_cname;
 	char* type_id;
@@ -316,16 +316,8 @@ static void vala_struct_real_accept_children (ValaCodeNode* base, ValaCodeVisito
 	ValaStruct * self;
 	self = (ValaStruct*) base;
 	g_return_if_fail (visitor != NULL);
-	{
-		GeeIterator* _type_it;
-		_type_it = gee_iterable_iterator ((GeeIterable*) self->priv->base_types);
-		while (gee_iterator_next (_type_it)) {
-			ValaDataType* type;
-			type = (ValaDataType*) gee_iterator_get (_type_it);
-			vala_code_node_accept ((ValaCodeNode*) type, visitor);
-			(type == NULL) ? NULL : (type = (vala_code_node_unref (type), NULL));
-		}
-		(_type_it == NULL) ? NULL : (_type_it = (gee_collection_object_unref (_type_it), NULL));
+	if (vala_struct_get_base_type (self) != NULL) {
+		vala_code_node_accept ((ValaCodeNode*) vala_struct_get_base_type (self), visitor);
 	}
 	{
 		GeeIterator* _p_it;
@@ -536,33 +528,25 @@ static char* vala_struct_real_get_type_signature (ValaTypeSymbol* base) {
  */
 gboolean vala_struct_is_boolean_type (ValaStruct* self) {
 	g_return_val_if_fail (self != NULL, FALSE);
-	{
-		GeeIterator* _type_it;
-		_type_it = gee_iterable_iterator ((GeeIterable*) self->priv->base_types);
-		while (gee_iterator_next (_type_it)) {
-			ValaDataType* type;
-			ValaStruct* _tmp1;
-			ValaTypeSymbol* _tmp0;
-			ValaStruct* st;
-			gboolean _tmp2;
-			type = (ValaDataType*) gee_iterator_get (_type_it);
-			_tmp1 = NULL;
-			_tmp0 = NULL;
-			st = (_tmp1 = (_tmp0 = vala_data_type_get_data_type (type), VALA_IS_STRUCT (_tmp0) ? ((ValaStruct*) _tmp0) : NULL), (_tmp1 == NULL) ? NULL : vala_code_node_ref (_tmp1));
+	if (vala_struct_get_base_type (self) != NULL) {
+		ValaStruct* _tmp1;
+		ValaTypeSymbol* _tmp0;
+		ValaStruct* st;
+		gboolean _tmp2;
+		_tmp1 = NULL;
+		_tmp0 = NULL;
+		st = (_tmp1 = (_tmp0 = vala_data_type_get_data_type (vala_struct_get_base_type (self)), VALA_IS_STRUCT (_tmp0) ? ((ValaStruct*) _tmp0) : NULL), (_tmp1 == NULL) ? NULL : vala_code_node_ref (_tmp1));
+		_tmp2 = FALSE;
+		if (st != NULL) {
+			_tmp2 = vala_struct_is_boolean_type (st);
+		} else {
 			_tmp2 = FALSE;
-			if (st != NULL) {
-				_tmp2 = vala_struct_is_boolean_type (st);
-			} else {
-				_tmp2 = FALSE;
-			}
-			if (_tmp2) {
-				gboolean _tmp3;
-				return (_tmp3 = TRUE, (type == NULL) ? NULL : (type = (vala_code_node_unref (type), NULL)), (st == NULL) ? NULL : (st = (vala_code_node_unref (st), NULL)), (_type_it == NULL) ? NULL : (_type_it = (gee_collection_object_unref (_type_it), NULL)), _tmp3);
-			}
-			(type == NULL) ? NULL : (type = (vala_code_node_unref (type), NULL));
-			(st == NULL) ? NULL : (st = (vala_code_node_unref (st), NULL));
 		}
-		(_type_it == NULL) ? NULL : (_type_it = (gee_collection_object_unref (_type_it), NULL));
+		if (_tmp2) {
+			gboolean _tmp3;
+			return (_tmp3 = TRUE, (st == NULL) ? NULL : (st = (vala_code_node_unref (st), NULL)), _tmp3);
+		}
+		(st == NULL) ? NULL : (st = (vala_code_node_unref (st), NULL));
 	}
 	return self->priv->boolean_type;
 }
@@ -575,33 +559,25 @@ gboolean vala_struct_is_boolean_type (ValaStruct* self) {
  */
 gboolean vala_struct_is_integer_type (ValaStruct* self) {
 	g_return_val_if_fail (self != NULL, FALSE);
-	{
-		GeeIterator* _type_it;
-		_type_it = gee_iterable_iterator ((GeeIterable*) self->priv->base_types);
-		while (gee_iterator_next (_type_it)) {
-			ValaDataType* type;
-			ValaStruct* _tmp1;
-			ValaTypeSymbol* _tmp0;
-			ValaStruct* st;
-			gboolean _tmp2;
-			type = (ValaDataType*) gee_iterator_get (_type_it);
-			_tmp1 = NULL;
-			_tmp0 = NULL;
-			st = (_tmp1 = (_tmp0 = vala_data_type_get_data_type (type), VALA_IS_STRUCT (_tmp0) ? ((ValaStruct*) _tmp0) : NULL), (_tmp1 == NULL) ? NULL : vala_code_node_ref (_tmp1));
+	if (vala_struct_get_base_type (self) != NULL) {
+		ValaStruct* _tmp1;
+		ValaTypeSymbol* _tmp0;
+		ValaStruct* st;
+		gboolean _tmp2;
+		_tmp1 = NULL;
+		_tmp0 = NULL;
+		st = (_tmp1 = (_tmp0 = vala_data_type_get_data_type (vala_struct_get_base_type (self)), VALA_IS_STRUCT (_tmp0) ? ((ValaStruct*) _tmp0) : NULL), (_tmp1 == NULL) ? NULL : vala_code_node_ref (_tmp1));
+		_tmp2 = FALSE;
+		if (st != NULL) {
+			_tmp2 = vala_struct_is_integer_type (st);
+		} else {
 			_tmp2 = FALSE;
-			if (st != NULL) {
-				_tmp2 = vala_struct_is_integer_type (st);
-			} else {
-				_tmp2 = FALSE;
-			}
-			if (_tmp2) {
-				gboolean _tmp3;
-				return (_tmp3 = TRUE, (type == NULL) ? NULL : (type = (vala_code_node_unref (type), NULL)), (st == NULL) ? NULL : (st = (vala_code_node_unref (st), NULL)), (_type_it == NULL) ? NULL : (_type_it = (gee_collection_object_unref (_type_it), NULL)), _tmp3);
-			}
-			(type == NULL) ? NULL : (type = (vala_code_node_unref (type), NULL));
-			(st == NULL) ? NULL : (st = (vala_code_node_unref (st), NULL));
 		}
-		(_type_it == NULL) ? NULL : (_type_it = (gee_collection_object_unref (_type_it), NULL));
+		if (_tmp2) {
+			gboolean _tmp3;
+			return (_tmp3 = TRUE, (st == NULL) ? NULL : (st = (vala_code_node_unref (st), NULL)), _tmp3);
+		}
+		(st == NULL) ? NULL : (st = (vala_code_node_unref (st), NULL));
 	}
 	return self->priv->integer_type;
 }
@@ -614,33 +590,25 @@ gboolean vala_struct_is_integer_type (ValaStruct* self) {
  */
 gboolean vala_struct_is_floating_type (ValaStruct* self) {
 	g_return_val_if_fail (self != NULL, FALSE);
-	{
-		GeeIterator* _type_it;
-		_type_it = gee_iterable_iterator ((GeeIterable*) self->priv->base_types);
-		while (gee_iterator_next (_type_it)) {
-			ValaDataType* type;
-			ValaStruct* _tmp1;
-			ValaTypeSymbol* _tmp0;
-			ValaStruct* st;
-			gboolean _tmp2;
-			type = (ValaDataType*) gee_iterator_get (_type_it);
-			_tmp1 = NULL;
-			_tmp0 = NULL;
-			st = (_tmp1 = (_tmp0 = vala_data_type_get_data_type (type), VALA_IS_STRUCT (_tmp0) ? ((ValaStruct*) _tmp0) : NULL), (_tmp1 == NULL) ? NULL : vala_code_node_ref (_tmp1));
+	if (vala_struct_get_base_type (self) != NULL) {
+		ValaStruct* _tmp1;
+		ValaTypeSymbol* _tmp0;
+		ValaStruct* st;
+		gboolean _tmp2;
+		_tmp1 = NULL;
+		_tmp0 = NULL;
+		st = (_tmp1 = (_tmp0 = vala_data_type_get_data_type (vala_struct_get_base_type (self)), VALA_IS_STRUCT (_tmp0) ? ((ValaStruct*) _tmp0) : NULL), (_tmp1 == NULL) ? NULL : vala_code_node_ref (_tmp1));
+		_tmp2 = FALSE;
+		if (st != NULL) {
+			_tmp2 = vala_struct_is_floating_type (st);
+		} else {
 			_tmp2 = FALSE;
-			if (st != NULL) {
-				_tmp2 = vala_struct_is_floating_type (st);
-			} else {
-				_tmp2 = FALSE;
-			}
-			if (_tmp2) {
-				gboolean _tmp3;
-				return (_tmp3 = TRUE, (type == NULL) ? NULL : (type = (vala_code_node_unref (type), NULL)), (st == NULL) ? NULL : (st = (vala_code_node_unref (st), NULL)), (_type_it == NULL) ? NULL : (_type_it = (gee_collection_object_unref (_type_it), NULL)), _tmp3);
-			}
-			(type == NULL) ? NULL : (type = (vala_code_node_unref (type), NULL));
-			(st == NULL) ? NULL : (st = (vala_code_node_unref (st), NULL));
 		}
-		(_type_it == NULL) ? NULL : (_type_it = (gee_collection_object_unref (_type_it), NULL));
+		if (_tmp2) {
+			gboolean _tmp3;
+			return (_tmp3 = TRUE, (st == NULL) ? NULL : (st = (vala_code_node_unref (st), NULL)), _tmp3);
+		}
+		(st == NULL) ? NULL : (st = (vala_code_node_unref (st), NULL));
 	}
 	return self->priv->floating_type;
 }
@@ -819,27 +787,19 @@ static char* vala_struct_real_get_type_id (ValaTypeSymbol* base) {
 	self = (ValaStruct*) base;
 	if (self->priv->type_id == NULL) {
 		if (!self->priv->_has_type_id) {
-			{
-				GeeIterator* _type_it;
-				_type_it = gee_iterable_iterator ((GeeIterable*) self->priv->base_types);
-				while (gee_iterator_next (_type_it)) {
-					ValaDataType* type;
-					ValaStruct* _tmp1;
-					ValaTypeSymbol* _tmp0;
-					ValaStruct* st;
-					type = (ValaDataType*) gee_iterator_get (_type_it);
-					_tmp1 = NULL;
-					_tmp0 = NULL;
-					st = (_tmp1 = (_tmp0 = vala_data_type_get_data_type (type), VALA_IS_STRUCT (_tmp0) ? ((ValaStruct*) _tmp0) : NULL), (_tmp1 == NULL) ? NULL : vala_code_node_ref (_tmp1));
-					if (st != NULL) {
-						char* _tmp2;
-						_tmp2 = NULL;
-						return (_tmp2 = vala_typesymbol_get_type_id ((ValaTypeSymbol*) st), (type == NULL) ? NULL : (type = (vala_code_node_unref (type), NULL)), (st == NULL) ? NULL : (st = (vala_code_node_unref (st), NULL)), (_type_it == NULL) ? NULL : (_type_it = (gee_collection_object_unref (_type_it), NULL)), _tmp2);
-					}
-					(type == NULL) ? NULL : (type = (vala_code_node_unref (type), NULL));
-					(st == NULL) ? NULL : (st = (vala_code_node_unref (st), NULL));
+			if (vala_struct_get_base_type (self) != NULL) {
+				ValaStruct* _tmp1;
+				ValaTypeSymbol* _tmp0;
+				ValaStruct* st;
+				_tmp1 = NULL;
+				_tmp0 = NULL;
+				st = (_tmp1 = (_tmp0 = vala_data_type_get_data_type (vala_struct_get_base_type (self)), VALA_IS_STRUCT (_tmp0) ? ((ValaStruct*) _tmp0) : NULL), (_tmp1 == NULL) ? NULL : vala_code_node_ref (_tmp1));
+				if (st != NULL) {
+					char* _tmp2;
+					_tmp2 = NULL;
+					return (_tmp2 = vala_typesymbol_get_type_id ((ValaTypeSymbol*) st), (st == NULL) ? NULL : (st = (vala_code_node_unref (st), NULL)), _tmp2);
 				}
-				(_type_it == NULL) ? NULL : (_type_it = (gee_collection_object_unref (_type_it), NULL));
+				(st == NULL) ? NULL : (st = (vala_code_node_unref (st), NULL));
 			}
 			if (vala_struct_is_simple_type (self)) {
 				char* _tmp4;
@@ -878,27 +838,19 @@ static char* vala_struct_real_get_marshaller_type_name (ValaTypeSymbol* base) {
 	const char* _tmp7;
 	self = (ValaStruct*) base;
 	if (self->priv->marshaller_type_name == NULL) {
-		{
-			GeeIterator* _type_it;
-			_type_it = gee_iterable_iterator ((GeeIterable*) self->priv->base_types);
-			while (gee_iterator_next (_type_it)) {
-				ValaDataType* type;
-				ValaStruct* _tmp1;
-				ValaTypeSymbol* _tmp0;
-				ValaStruct* st;
-				type = (ValaDataType*) gee_iterator_get (_type_it);
-				_tmp1 = NULL;
-				_tmp0 = NULL;
-				st = (_tmp1 = (_tmp0 = vala_data_type_get_data_type (type), VALA_IS_STRUCT (_tmp0) ? ((ValaStruct*) _tmp0) : NULL), (_tmp1 == NULL) ? NULL : vala_code_node_ref (_tmp1));
-				if (st != NULL) {
-					char* _tmp2;
-					_tmp2 = NULL;
-					return (_tmp2 = vala_typesymbol_get_marshaller_type_name ((ValaTypeSymbol*) st), (type == NULL) ? NULL : (type = (vala_code_node_unref (type), NULL)), (st == NULL) ? NULL : (st = (vala_code_node_unref (st), NULL)), (_type_it == NULL) ? NULL : (_type_it = (gee_collection_object_unref (_type_it), NULL)), _tmp2);
-				}
-				(type == NULL) ? NULL : (type = (vala_code_node_unref (type), NULL));
-				(st == NULL) ? NULL : (st = (vala_code_node_unref (st), NULL));
+		if (vala_struct_get_base_type (self) != NULL) {
+			ValaStruct* _tmp1;
+			ValaTypeSymbol* _tmp0;
+			ValaStruct* st;
+			_tmp1 = NULL;
+			_tmp0 = NULL;
+			st = (_tmp1 = (_tmp0 = vala_data_type_get_data_type (vala_struct_get_base_type (self)), VALA_IS_STRUCT (_tmp0) ? ((ValaStruct*) _tmp0) : NULL), (_tmp1 == NULL) ? NULL : vala_code_node_ref (_tmp1));
+			if (st != NULL) {
+				char* _tmp2;
+				_tmp2 = NULL;
+				return (_tmp2 = vala_typesymbol_get_marshaller_type_name ((ValaTypeSymbol*) st), (st == NULL) ? NULL : (st = (vala_code_node_unref (st), NULL)), _tmp2);
 			}
-			(_type_it == NULL) ? NULL : (_type_it = (gee_collection_object_unref (_type_it), NULL));
+			(st == NULL) ? NULL : (st = (vala_code_node_unref (st), NULL));
 		}
 		if (vala_struct_is_simple_type (self)) {
 			char* _tmp4;
@@ -935,27 +887,19 @@ static char* vala_struct_real_get_get_value_function (ValaTypeSymbol* base) {
 	ValaStruct * self;
 	self = (ValaStruct*) base;
 	if (self->priv->get_value_function == NULL) {
-		{
-			GeeIterator* _type_it;
-			_type_it = gee_iterable_iterator ((GeeIterable*) self->priv->base_types);
-			while (gee_iterator_next (_type_it)) {
-				ValaDataType* type;
-				ValaStruct* _tmp1;
-				ValaTypeSymbol* _tmp0;
-				ValaStruct* st;
-				type = (ValaDataType*) gee_iterator_get (_type_it);
-				_tmp1 = NULL;
-				_tmp0 = NULL;
-				st = (_tmp1 = (_tmp0 = vala_data_type_get_data_type (type), VALA_IS_STRUCT (_tmp0) ? ((ValaStruct*) _tmp0) : NULL), (_tmp1 == NULL) ? NULL : vala_code_node_ref (_tmp1));
-				if (st != NULL) {
-					char* _tmp2;
-					_tmp2 = NULL;
-					return (_tmp2 = vala_typesymbol_get_get_value_function ((ValaTypeSymbol*) st), (type == NULL) ? NULL : (type = (vala_code_node_unref (type), NULL)), (st == NULL) ? NULL : (st = (vala_code_node_unref (st), NULL)), (_type_it == NULL) ? NULL : (_type_it = (gee_collection_object_unref (_type_it), NULL)), _tmp2);
-				}
-				(type == NULL) ? NULL : (type = (vala_code_node_unref (type), NULL));
-				(st == NULL) ? NULL : (st = (vala_code_node_unref (st), NULL));
+		if (vala_struct_get_base_type (self) != NULL) {
+			ValaStruct* _tmp1;
+			ValaTypeSymbol* _tmp0;
+			ValaStruct* st;
+			_tmp1 = NULL;
+			_tmp0 = NULL;
+			st = (_tmp1 = (_tmp0 = vala_data_type_get_data_type (vala_struct_get_base_type (self)), VALA_IS_STRUCT (_tmp0) ? ((ValaStruct*) _tmp0) : NULL), (_tmp1 == NULL) ? NULL : vala_code_node_ref (_tmp1));
+			if (st != NULL) {
+				char* _tmp2;
+				_tmp2 = NULL;
+				return (_tmp2 = vala_typesymbol_get_get_value_function ((ValaTypeSymbol*) st), (st == NULL) ? NULL : (st = (vala_code_node_unref (st), NULL)), _tmp2);
 			}
-			(_type_it == NULL) ? NULL : (_type_it = (gee_collection_object_unref (_type_it), NULL));
+			(st == NULL) ? NULL : (st = (vala_code_node_unref (st), NULL));
 		}
 		if (vala_struct_is_simple_type (self)) {
 			char* _tmp4;
@@ -985,27 +929,19 @@ static char* vala_struct_real_get_set_value_function (ValaTypeSymbol* base) {
 	ValaStruct * self;
 	self = (ValaStruct*) base;
 	if (self->priv->set_value_function == NULL) {
-		{
-			GeeIterator* _type_it;
-			_type_it = gee_iterable_iterator ((GeeIterable*) self->priv->base_types);
-			while (gee_iterator_next (_type_it)) {
-				ValaDataType* type;
-				ValaStruct* _tmp1;
-				ValaTypeSymbol* _tmp0;
-				ValaStruct* st;
-				type = (ValaDataType*) gee_iterator_get (_type_it);
-				_tmp1 = NULL;
-				_tmp0 = NULL;
-				st = (_tmp1 = (_tmp0 = vala_data_type_get_data_type (type), VALA_IS_STRUCT (_tmp0) ? ((ValaStruct*) _tmp0) : NULL), (_tmp1 == NULL) ? NULL : vala_code_node_ref (_tmp1));
-				if (st != NULL) {
-					char* _tmp2;
-					_tmp2 = NULL;
-					return (_tmp2 = vala_typesymbol_get_set_value_function ((ValaTypeSymbol*) st), (type == NULL) ? NULL : (type = (vala_code_node_unref (type), NULL)), (st == NULL) ? NULL : (st = (vala_code_node_unref (st), NULL)), (_type_it == NULL) ? NULL : (_type_it = (gee_collection_object_unref (_type_it), NULL)), _tmp2);
-				}
-				(type == NULL) ? NULL : (type = (vala_code_node_unref (type), NULL));
-				(st == NULL) ? NULL : (st = (vala_code_node_unref (st), NULL));
+		if (vala_struct_get_base_type (self) != NULL) {
+			ValaStruct* _tmp1;
+			ValaTypeSymbol* _tmp0;
+			ValaStruct* st;
+			_tmp1 = NULL;
+			_tmp0 = NULL;
+			st = (_tmp1 = (_tmp0 = vala_data_type_get_data_type (vala_struct_get_base_type (self)), VALA_IS_STRUCT (_tmp0) ? ((ValaStruct*) _tmp0) : NULL), (_tmp1 == NULL) ? NULL : vala_code_node_ref (_tmp1));
+			if (st != NULL) {
+				char* _tmp2;
+				_tmp2 = NULL;
+				return (_tmp2 = vala_typesymbol_get_set_value_function ((ValaTypeSymbol*) st), (st == NULL) ? NULL : (st = (vala_code_node_unref (st), NULL)), _tmp2);
 			}
-			(_type_it == NULL) ? NULL : (_type_it = (gee_collection_object_unref (_type_it), NULL));
+			(st == NULL) ? NULL : (st = (vala_code_node_unref (st), NULL));
 		}
 		if (vala_struct_is_simple_type (self)) {
 			char* _tmp4;
@@ -1060,30 +996,19 @@ static char* vala_struct_real_get_default_value (ValaTypeSymbol* base) {
 		return (_tmp0 = self->priv->default_value, (_tmp0 == NULL) ? NULL : g_strdup (_tmp0));
 	}
 	/* inherit default value from base type*/
-	{
-		GeeIterator* _type_it;
-		/* inherit default value from base type*/
-		_type_it = gee_iterable_iterator ((GeeIterable*) self->priv->base_types);
-		/* inherit default value from base type*/
-		while (gee_iterator_next (_type_it)) {
-			ValaDataType* type;
-			ValaStruct* _tmp3;
-			ValaTypeSymbol* _tmp2;
-			ValaStruct* st;
-			/* inherit default value from base type*/
-			type = (ValaDataType*) gee_iterator_get (_type_it);
-			_tmp3 = NULL;
-			_tmp2 = NULL;
-			st = (_tmp3 = (_tmp2 = vala_data_type_get_data_type (type), VALA_IS_STRUCT (_tmp2) ? ((ValaStruct*) _tmp2) : NULL), (_tmp3 == NULL) ? NULL : vala_code_node_ref (_tmp3));
-			if (st != NULL) {
-				char* _tmp4;
-				_tmp4 = NULL;
-				return (_tmp4 = vala_typesymbol_get_default_value ((ValaTypeSymbol*) st), (type == NULL) ? NULL : (type = (vala_code_node_unref (type), NULL)), (st == NULL) ? NULL : (st = (vala_code_node_unref (st), NULL)), (_type_it == NULL) ? NULL : (_type_it = (gee_collection_object_unref (_type_it), NULL)), _tmp4);
-			}
-			(type == NULL) ? NULL : (type = (vala_code_node_unref (type), NULL));
-			(st == NULL) ? NULL : (st = (vala_code_node_unref (st), NULL));
+	if (vala_struct_get_base_type (self) != NULL) {
+		ValaStruct* _tmp3;
+		ValaTypeSymbol* _tmp2;
+		ValaStruct* st;
+		_tmp3 = NULL;
+		_tmp2 = NULL;
+		st = (_tmp3 = (_tmp2 = vala_data_type_get_data_type (vala_struct_get_base_type (self)), VALA_IS_STRUCT (_tmp2) ? ((ValaStruct*) _tmp2) : NULL), (_tmp3 == NULL) ? NULL : vala_code_node_ref (_tmp3));
+		if (st != NULL) {
+			char* _tmp4;
+			_tmp4 = NULL;
+			return (_tmp4 = vala_typesymbol_get_default_value ((ValaTypeSymbol*) st), (st == NULL) ? NULL : (st = (vala_code_node_unref (st), NULL)), _tmp4);
 		}
-		(_type_it == NULL) ? NULL : (_type_it = (gee_collection_object_unref (_type_it), NULL));
+		(st == NULL) ? NULL : (st = (vala_code_node_unref (st), NULL));
 	}
 	return NULL;
 }
@@ -1099,30 +1024,6 @@ static void vala_struct_set_default_value (ValaStruct* self, const char* value)
 }
 
 
-/**
- * Adds the specified struct to the list of base types of this struct.
- *
- * @param type a class or interface reference
- */
-void vala_struct_add_base_type (ValaStruct* self, ValaDataType* type) {
-	g_return_if_fail (self != NULL);
-	g_return_if_fail (type != NULL);
-	gee_collection_add ((GeeCollection*) self->priv->base_types, type);
-	vala_code_node_set_parent_node ((ValaCodeNode*) type, (ValaCodeNode*) self);
-}
-
-
-/**
- * Returns a copy of the base type list.
- *
- * @return list of base types
- */
-GeeList* vala_struct_get_base_types (ValaStruct* self) {
-	g_return_val_if_fail (self != NULL, NULL);
-	return (GeeList*) gee_read_only_list_new (VALA_TYPE_DATA_TYPE, (GBoxedCopyFunc) vala_code_node_ref, vala_code_node_unref, self->priv->base_types);
-}
-
-
 static gint vala_struct_real_get_type_parameter_index (ValaTypeSymbol* base, const char* name) {
 	ValaStruct * self;
 	gint i;
@@ -1156,33 +1057,25 @@ gboolean vala_struct_is_simple_type (ValaStruct* self) {
 	ValaAttribute* _tmp4;
 	gboolean _tmp5;
 	g_return_val_if_fail (self != NULL, FALSE);
-	{
-		GeeIterator* _type_it;
-		_type_it = gee_iterable_iterator ((GeeIterable*) self->priv->base_types);
-		while (gee_iterator_next (_type_it)) {
-			ValaDataType* type;
-			ValaStruct* _tmp1;
-			ValaTypeSymbol* _tmp0;
-			ValaStruct* st;
-			gboolean _tmp2;
-			type = (ValaDataType*) gee_iterator_get (_type_it);
-			_tmp1 = NULL;
-			_tmp0 = NULL;
-			st = (_tmp1 = (_tmp0 = vala_data_type_get_data_type (type), VALA_IS_STRUCT (_tmp0) ? ((ValaStruct*) _tmp0) : NULL), (_tmp1 == NULL) ? NULL : vala_code_node_ref (_tmp1));
+	if (vala_struct_get_base_type (self) != NULL) {
+		ValaStruct* _tmp1;
+		ValaTypeSymbol* _tmp0;
+		ValaStruct* st;
+		gboolean _tmp2;
+		_tmp1 = NULL;
+		_tmp0 = NULL;
+		st = (_tmp1 = (_tmp0 = vala_data_type_get_data_type (vala_struct_get_base_type (self)), VALA_IS_STRUCT (_tmp0) ? ((ValaStruct*) _tmp0) : NULL), (_tmp1 == NULL) ? NULL : vala_code_node_ref (_tmp1));
+		_tmp2 = FALSE;
+		if (st != NULL) {
+			_tmp2 = vala_struct_is_simple_type (st);
+		} else {
 			_tmp2 = FALSE;
-			if (st != NULL) {
-				_tmp2 = vala_struct_is_simple_type (st);
-			} else {
-				_tmp2 = FALSE;
-			}
-			if (_tmp2) {
-				gboolean _tmp3;
-				return (_tmp3 = TRUE, (type == NULL) ? NULL : (type = (vala_code_node_unref (type), NULL)), (st == NULL) ? NULL : (st = (vala_code_node_unref (st), NULL)), (_type_it == NULL) ? NULL : (_type_it = (gee_collection_object_unref (_type_it), NULL)), _tmp3);
-			}
-			(type == NULL) ? NULL : (type = (vala_code_node_unref (type), NULL));
-			(st == NULL) ? NULL : (st = (vala_code_node_unref (st), NULL));
 		}
-		(_type_it == NULL) ? NULL : (_type_it = (gee_collection_object_unref (_type_it), NULL));
+		if (_tmp2) {
+			gboolean _tmp3;
+			return (_tmp3 = TRUE, (st == NULL) ? NULL : (st = (vala_code_node_unref (st), NULL)), _tmp3);
+		}
+		(st == NULL) ? NULL : (st = (vala_code_node_unref (st), NULL));
 	}
 	_tmp4 = NULL;
 	return (_tmp5 = (_tmp4 = vala_code_node_get_attribute ((ValaCodeNode*) self, "SimpleType")) != NULL, (_tmp4 == NULL) ? NULL : (_tmp4 = (vala_code_node_unref (_tmp4), NULL)), _tmp5);
@@ -1204,18 +1097,8 @@ static void vala_struct_real_replace_type (ValaCodeNode* base, ValaDataType* old
 	self = (ValaStruct*) base;
 	g_return_if_fail (old_type != NULL);
 	g_return_if_fail (new_type != NULL);
-	{
-		gint i;
-		i = 0;
-		for (; i < gee_collection_get_size ((GeeCollection*) self->priv->base_types); i++) {
-			ValaDataType* _tmp0;
-			gboolean _tmp1;
-			_tmp0 = NULL;
-			if ((_tmp1 = (_tmp0 = (ValaDataType*) gee_list_get ((GeeList*) self->priv->base_types, i)) == old_type, (_tmp0 == NULL) ? NULL : (_tmp0 = (vala_code_node_unref (_tmp0), NULL)), _tmp1)) {
-				gee_list_set ((GeeList*) self->priv->base_types, i, new_type);
-				return;
-			}
-		}
+	if (vala_struct_get_base_type (self) == old_type) {
+		vala_struct_set_base_type (self, new_type);
 	}
 }
 
@@ -1227,26 +1110,17 @@ static gboolean vala_struct_real_is_subtype_of (ValaTypeSymbol* base, ValaTypeSy
 	if (VALA_TYPESYMBOL (self) == t) {
 		return TRUE;
 	}
-	{
-		GeeIterator* _base_type_it;
-		_base_type_it = gee_iterable_iterator ((GeeIterable*) self->priv->base_types);
-		while (gee_iterator_next (_base_type_it)) {
-			ValaDataType* base_type;
-			gboolean _tmp1;
-			base_type = (ValaDataType*) gee_iterator_get (_base_type_it);
+	if (vala_struct_get_base_type (self) != NULL) {
+		gboolean _tmp1;
+		_tmp1 = FALSE;
+		if (vala_data_type_get_data_type (vala_struct_get_base_type (self)) != NULL) {
+			_tmp1 = vala_typesymbol_is_subtype_of (vala_data_type_get_data_type (vala_struct_get_base_type (self)), t);
+		} else {
 			_tmp1 = FALSE;
-			if (vala_data_type_get_data_type (base_type) != NULL) {
-				_tmp1 = vala_typesymbol_is_subtype_of (vala_data_type_get_data_type (base_type), t);
-			} else {
-				_tmp1 = FALSE;
-			}
-			if (_tmp1) {
-				gboolean _tmp2;
-				return (_tmp2 = TRUE, (base_type == NULL) ? NULL : (base_type = (vala_code_node_unref (base_type), NULL)), (_base_type_it == NULL) ? NULL : (_base_type_it = (gee_collection_object_unref (_base_type_it), NULL)), _tmp2);
-			}
-			(base_type == NULL) ? NULL : (base_type = (vala_code_node_unref (base_type), NULL));
 		}
-		(_base_type_it == NULL) ? NULL : (_base_type_it = (gee_collection_object_unref (_base_type_it), NULL));
+		if (_tmp1) {
+			return TRUE;
+		}
 	}
 	return FALSE;
 }
@@ -1397,9 +1271,9 @@ static gboolean vala_struct_real_check (ValaCodeNode* base, ValaSemanticAnalyzer
 	gboolean _tmp10;
 	gboolean _tmp11;
 	gboolean _tmp12;
-	ValaStruct* _tmp16;
 	ValaStruct* _tmp15;
-	gboolean _tmp17;
+	ValaStruct* _tmp14;
+	gboolean _tmp16;
 	self = (ValaStruct*) base;
 	g_return_val_if_fail (analyzer != NULL, FALSE);
 	if (vala_code_node_get_checked ((ValaCodeNode*) self)) {
@@ -1420,31 +1294,23 @@ static gboolean vala_struct_real_check (ValaCodeNode* base, ValaSemanticAnalyzer
 	_tmp5 = NULL;
 	_tmp4 = NULL;
 	analyzer->current_struct = (_tmp5 = (_tmp4 = self, (_tmp4 == NULL) ? NULL : vala_code_node_ref (_tmp4)), (analyzer->current_struct == NULL) ? NULL : (analyzer->current_struct = (vala_code_node_unref (analyzer->current_struct), NULL)), _tmp5);
-	{
-		GeeIterator* _type_it;
-		_type_it = gee_iterable_iterator ((GeeIterable*) self->priv->base_types);
-		while (gee_iterator_next (_type_it)) {
-			ValaDataType* type;
-			type = (ValaDataType*) gee_iterator_get (_type_it);
-			vala_code_node_check ((ValaCodeNode*) type, analyzer);
-			if (!(VALA_IS_STRUCT_VALUE_TYPE (type))) {
-				char* _tmp8;
-				char* _tmp7;
-				char* _tmp6;
-				gboolean _tmp9;
-				vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
-				_tmp8 = NULL;
-				_tmp7 = NULL;
-				_tmp6 = NULL;
-				vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), _tmp8 = g_strdup_printf ("The base type `%s` of value type `%s` is not a struct", _tmp6 = vala_code_node_to_string ((ValaCodeNode*) vala_data_type_get_data_type (type)), _tmp7 = vala_symbol_get_full_name ((ValaSymbol*) self)));
-				_tmp8 = (g_free (_tmp8), NULL);
-				_tmp7 = (g_free (_tmp7), NULL);
-				_tmp6 = (g_free (_tmp6), NULL);
-				return (_tmp9 = FALSE, (type == NULL) ? NULL : (type = (vala_code_node_unref (type), NULL)), (_type_it == NULL) ? NULL : (_type_it = (gee_collection_object_unref (_type_it), NULL)), (old_source_file == NULL) ? NULL : (old_source_file = (vala_source_file_unref (old_source_file), NULL)), (old_symbol == NULL) ? NULL : (old_symbol = (vala_code_node_unref (old_symbol), NULL)), (old_struct == NULL) ? NULL : (old_struct = (vala_code_node_unref (old_struct), NULL)), _tmp9);
-			}
-			(type == NULL) ? NULL : (type = (vala_code_node_unref (type), NULL));
+	if (vala_struct_get_base_type (self) != NULL) {
+		vala_code_node_check ((ValaCodeNode*) vala_struct_get_base_type (self), analyzer);
+		if (!(VALA_IS_STRUCT_VALUE_TYPE (vala_struct_get_base_type (self)))) {
+			char* _tmp8;
+			char* _tmp7;
+			char* _tmp6;
+			gboolean _tmp9;
+			vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
+			_tmp8 = NULL;
+			_tmp7 = NULL;
+			_tmp6 = NULL;
+			vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), _tmp8 = g_strdup_printf ("The base type `%s` of struct `%s` is not a struct", _tmp6 = vala_code_node_to_string ((ValaCodeNode*) vala_struct_get_base_type (self)), _tmp7 = vala_symbol_get_full_name ((ValaSymbol*) self)));
+			_tmp8 = (g_free (_tmp8), NULL);
+			_tmp7 = (g_free (_tmp7), NULL);
+			_tmp6 = (g_free (_tmp6), NULL);
+			return (_tmp9 = FALSE, (old_source_file == NULL) ? NULL : (old_source_file = (vala_source_file_unref (old_source_file), NULL)), (old_symbol == NULL) ? NULL : (old_symbol = (vala_code_node_unref (old_symbol), NULL)), (old_struct == NULL) ? NULL : (old_struct = (vala_code_node_unref (old_struct), NULL)), _tmp9);
 		}
-		(_type_it == NULL) ? NULL : (_type_it = (gee_collection_object_unref (_type_it), NULL));
 	}
 	{
 		GeeIterator* _p_it;
@@ -1499,18 +1365,15 @@ static gboolean vala_struct_real_check (ValaCodeNode* base, ValaSemanticAnalyzer
 		_tmp12 = FALSE;
 	}
 	if (_tmp12) {
-		GeeList* _tmp13;
-		_tmp13 = NULL;
-		_tmp11 = gee_collection_get_size ((GeeCollection*) (_tmp13 = vala_struct_get_base_types (self))) == 0;
-		(_tmp13 == NULL) ? NULL : (_tmp13 = (gee_collection_object_unref (_tmp13), NULL));
+		_tmp11 = vala_struct_get_base_type (self) == NULL;
 	} else {
 		_tmp11 = FALSE;
 	}
 	if (_tmp11) {
-		GeeList* _tmp14;
-		_tmp14 = NULL;
-		_tmp10 = gee_collection_get_size ((GeeCollection*) (_tmp14 = vala_struct_get_fields (self))) == 0;
-		(_tmp14 == NULL) ? NULL : (_tmp14 = (gee_collection_object_unref (_tmp14), NULL));
+		GeeList* _tmp13;
+		_tmp13 = NULL;
+		_tmp10 = gee_collection_get_size ((GeeCollection*) (_tmp13 = vala_struct_get_fields (self))) == 0;
+		(_tmp13 == NULL) ? NULL : (_tmp13 = (gee_collection_object_unref (_tmp13), NULL));
 	} else {
 		_tmp10 = FALSE;
 	}
@@ -1519,10 +1382,27 @@ static gboolean vala_struct_real_check (ValaCodeNode* base, ValaSemanticAnalyzer
 	}
 	vala_semantic_analyzer_set_current_source_file (analyzer, old_source_file);
 	vala_semantic_analyzer_set_current_symbol (analyzer, old_symbol);
-	_tmp16 = NULL;
 	_tmp15 = NULL;
-	analyzer->current_struct = (_tmp16 = (_tmp15 = old_struct, (_tmp15 == NULL) ? NULL : vala_code_node_ref (_tmp15)), (analyzer->current_struct == NULL) ? NULL : (analyzer->current_struct = (vala_code_node_unref (analyzer->current_struct), NULL)), _tmp16);
-	return (_tmp17 = !vala_code_node_get_error ((ValaCodeNode*) self), (old_source_file == NULL) ? NULL : (old_source_file = (vala_source_file_unref (old_source_file), NULL)), (old_symbol == NULL) ? NULL : (old_symbol = (vala_code_node_unref (old_symbol), NULL)), (old_struct == NULL) ? NULL : (old_struct = (vala_code_node_unref (old_struct), NULL)), _tmp17);
+	_tmp14 = NULL;
+	analyzer->current_struct = (_tmp15 = (_tmp14 = old_struct, (_tmp14 == NULL) ? NULL : vala_code_node_ref (_tmp14)), (analyzer->current_struct == NULL) ? NULL : (analyzer->current_struct = (vala_code_node_unref (analyzer->current_struct), NULL)), _tmp15);
+	return (_tmp16 = !vala_code_node_get_error ((ValaCodeNode*) self), (old_source_file == NULL) ? NULL : (old_source_file = (vala_source_file_unref (old_source_file), NULL)), (old_symbol == NULL) ? NULL : (old_symbol = (vala_code_node_unref (old_symbol), NULL)), (old_struct == NULL) ? NULL : (old_struct = (vala_code_node_unref (old_struct), NULL)), _tmp16);
+}
+
+
+ValaDataType* vala_struct_get_base_type (ValaStruct* self) {
+	g_return_val_if_fail (self != NULL, NULL);
+	return self->priv->_base_type;
+}
+
+
+void vala_struct_set_base_type (ValaStruct* self, ValaDataType* value) {
+	ValaDataType* _tmp2;
+	ValaDataType* _tmp1;
+	g_return_if_fail (self != NULL);
+	vala_code_node_set_parent_node ((ValaCodeNode*) value, (ValaCodeNode*) self);
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_base_type = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : vala_code_node_ref (_tmp1)), (self->priv->_base_type == NULL) ? NULL : (self->priv->_base_type = (vala_code_node_unref (self->priv->_base_type), NULL)), _tmp2);
 }
 
 
@@ -1587,7 +1467,7 @@ static void vala_struct_instance_init (ValaStruct * self) {
 	self->priv->constants = (GeeList*) gee_array_list_new (VALA_TYPE_CONSTANT, (GBoxedCopyFunc) vala_code_node_ref, vala_code_node_unref, g_direct_equal);
 	self->priv->fields = (GeeList*) gee_array_list_new (VALA_TYPE_FIELD, (GBoxedCopyFunc) vala_code_node_ref, vala_code_node_unref, g_direct_equal);
 	self->priv->methods = (GeeList*) gee_array_list_new (VALA_TYPE_METHOD, (GBoxedCopyFunc) vala_code_node_ref, vala_code_node_unref, g_direct_equal);
-	self->priv->base_types = (GeeList*) gee_array_list_new (VALA_TYPE_DATA_TYPE, (GBoxedCopyFunc) vala_code_node_ref, vala_code_node_unref, g_direct_equal);
+	self->priv->_base_type = NULL;
 	self->priv->default_value = NULL;
 	self->priv->_has_type_id = TRUE;
 }
@@ -1600,7 +1480,7 @@ static void vala_struct_finalize (ValaCodeNode* obj) {
 	(self->priv->constants == NULL) ? NULL : (self->priv->constants = (gee_collection_object_unref (self->priv->constants), NULL));
 	(self->priv->fields == NULL) ? NULL : (self->priv->fields = (gee_collection_object_unref (self->priv->fields), NULL));
 	(self->priv->methods == NULL) ? NULL : (self->priv->methods = (gee_collection_object_unref (self->priv->methods), NULL));
-	(self->priv->base_types == NULL) ? NULL : (self->priv->base_types = (gee_collection_object_unref (self->priv->base_types), NULL));
+	(self->priv->_base_type == NULL) ? NULL : (self->priv->_base_type = (vala_code_node_unref (self->priv->_base_type), NULL));
 	self->priv->cname = (g_free (self->priv->cname), NULL);
 	self->priv->const_cname = (g_free (self->priv->const_cname), NULL);
 	self->priv->type_id = (g_free (self->priv->type_id), NULL);
