@@ -25,7 +25,6 @@
 #include <vala/valascope.h>
 #include <vala/valasourcereference.h>
 #include <vala/valasourcefile.h>
-#include <vala/valanamespace.h>
 
 
 
@@ -343,45 +342,32 @@ char* vala_symbol_lower_case_to_camel_case (const char* lower_case) {
 
 
 /* get the top scope from where this symbol is still accessible*/
-ValaScope* vala_symbol_get_top_accessible_scope (ValaSymbol* self) {
+ValaScope* vala_symbol_get_top_accessible_scope (ValaSymbol* self, gboolean is_internal) {
 	g_return_val_if_fail (self != NULL, NULL);
-	if (self->priv->_access != VALA_SYMBOL_ACCESSIBILITY_PUBLIC) {
+	if (self->priv->_access == VALA_SYMBOL_ACCESSIBILITY_PRIVATE) {
 		ValaScope* _tmp0;
-		ValaScope* scope;
 		/* private symbols are accessible within the scope where the symbol has been declared*/
 		_tmp0 = NULL;
-		scope = (_tmp0 = vala_symbol_get_owner (self), (_tmp0 == NULL) ? NULL : vala_scope_ref (_tmp0));
-		while (TRUE) {
-			gboolean _tmp1;
-			gboolean _tmp2;
-			ValaScope* _tmp4;
-			ValaScope* _tmp3;
-			_tmp1 = FALSE;
-			_tmp2 = FALSE;
-			if (scope != NULL) {
-				_tmp2 = VALA_IS_NAMESPACE (vala_scope_get_owner (scope));
-			} else {
-				_tmp2 = FALSE;
-			}
-			if (_tmp2) {
-				_tmp1 = vala_scope_get_owner (scope)->priv->_name != NULL;
-			} else {
-				_tmp1 = FALSE;
-			}
-			if (!_tmp1) {
-				break;
-			}
-			_tmp4 = NULL;
-			_tmp3 = NULL;
-			scope = (_tmp4 = (_tmp3 = vala_scope_get_parent_scope (scope), (_tmp3 == NULL) ? NULL : vala_scope_ref (_tmp3)), (scope == NULL) ? NULL : (scope = (vala_scope_unref (scope), NULL)), _tmp4);
-		}
-		return scope;
+		return (_tmp0 = vala_symbol_get_owner (self), (_tmp0 == NULL) ? NULL : vala_scope_ref (_tmp0));
+	}
+	if (self->priv->_access == VALA_SYMBOL_ACCESSIBILITY_INTERNAL) {
+		is_internal = TRUE;
 	}
 	if (vala_symbol_get_parent_symbol (self) == NULL) {
-		return NULL;
+		/* this is the root symbol*/
+		if (is_internal) {
+			ValaScope* _tmp2;
+			/* only accessible within the same library
+			 return root scope*/
+			_tmp2 = NULL;
+			return (_tmp2 = vala_symbol_get_scope (self), (_tmp2 == NULL) ? NULL : vala_scope_ref (_tmp2));
+		} else {
+			/* unlimited access*/
+			return NULL;
+		}
 	}
 	/* if this is a public symbol, it's equally accessible as the parent symbol*/
-	return vala_symbol_get_top_accessible_scope (vala_symbol_get_parent_symbol (self));
+	return vala_symbol_get_top_accessible_scope (vala_symbol_get_parent_symbol (self), is_internal);
 }
 
 
