@@ -1,6 +1,7 @@
 /* valasymbolresolver.vala
  *
- * Copyright (C) 2006-2008  Jürg Billeter, Raffaele Sandrini
+ * Copyright (C) 2006-2009  Jürg Billeter
+ * Copyright (C) 2006-2008  Raffaele Sandrini
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -45,7 +46,11 @@
 #include <vala/valaerrorcode.h>
 #include <vala/valaobjecttype.h>
 #include <vala/valaobjecttypesymbol.h>
-#include <vala/valavaluetype.h>
+#include <vala/valabooleantype.h>
+#include <vala/valaintegertype.h>
+#include <vala/valafloatingtype.h>
+#include <vala/valastructvaluetype.h>
+#include <vala/valaenumvaluetype.h>
 #include <vala/valareferencetype.h>
 
 
@@ -232,17 +237,43 @@ static void vala_symbol_resolver_real_visit_struct (ValaCodeVisitor* base, ValaS
 	ValaSymbolResolver * self;
 	ValaScope* _tmp1;
 	ValaScope* _tmp0;
-	ValaScope* _tmp3;
-	ValaScope* _tmp2;
+	ValaScope* _tmp8;
+	ValaScope* _tmp7;
 	self = (ValaSymbolResolver*) base;
 	g_return_if_fail (st != NULL);
 	_tmp1 = NULL;
 	_tmp0 = NULL;
 	self->priv->current_scope = (_tmp1 = (_tmp0 = vala_symbol_get_scope ((ValaSymbol*) st), (_tmp0 == NULL) ? NULL : vala_scope_ref (_tmp0)), (self->priv->current_scope == NULL) ? NULL : (self->priv->current_scope = (vala_scope_unref (self->priv->current_scope), NULL)), _tmp1);
 	vala_code_node_accept_children ((ValaCodeNode*) st, (ValaCodeVisitor*) self);
-	_tmp3 = NULL;
-	_tmp2 = NULL;
-	self->priv->current_scope = (_tmp3 = (_tmp2 = vala_scope_get_parent_scope (self->priv->current_scope), (_tmp2 == NULL) ? NULL : vala_scope_ref (_tmp2)), (self->priv->current_scope == NULL) ? NULL : (self->priv->current_scope = (vala_scope_unref (self->priv->current_scope), NULL)), _tmp3);
+	if (vala_struct_get_base_type (st) != NULL) {
+		ValaStruct* _tmp3;
+		ValaTypeSymbol* _tmp2;
+		ValaStruct* base_type;
+		_tmp3 = NULL;
+		_tmp2 = NULL;
+		base_type = (_tmp3 = (_tmp2 = vala_data_type_get_data_type (vala_struct_get_base_type (st)), VALA_IS_STRUCT (_tmp2) ? ((ValaStruct*) _tmp2) : NULL), (_tmp3 == NULL) ? NULL : vala_code_node_ref (_tmp3));
+		if (base_type != NULL) {
+			if (vala_typesymbol_is_subtype_of ((ValaTypeSymbol*) base_type, (ValaTypeSymbol*) st)) {
+				char* _tmp6;
+				char* _tmp5;
+				char* _tmp4;
+				vala_code_node_set_error ((ValaCodeNode*) st, TRUE);
+				_tmp6 = NULL;
+				_tmp5 = NULL;
+				_tmp4 = NULL;
+				vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) base_type), _tmp6 = g_strdup_printf ("Base struct cycle (`%s' and `%s')", _tmp4 = vala_symbol_get_full_name ((ValaSymbol*) st), _tmp5 = vala_symbol_get_full_name ((ValaSymbol*) base_type)));
+				_tmp6 = (g_free (_tmp6), NULL);
+				_tmp5 = (g_free (_tmp5), NULL);
+				_tmp4 = (g_free (_tmp4), NULL);
+				(base_type == NULL) ? NULL : (base_type = (vala_code_node_unref (base_type), NULL));
+				return;
+			}
+		}
+		(base_type == NULL) ? NULL : (base_type = (vala_code_node_unref (base_type), NULL));
+	}
+	_tmp8 = NULL;
+	_tmp7 = NULL;
+	self->priv->current_scope = (_tmp8 = (_tmp7 = vala_scope_get_parent_scope (self->priv->current_scope), (_tmp7 == NULL) ? NULL : vala_scope_ref (_tmp7)), (self->priv->current_scope == NULL) ? NULL : (self->priv->current_scope = (vala_scope_unref (self->priv->current_scope), NULL)), _tmp8);
 }
 
 
@@ -511,7 +542,7 @@ static ValaSymbol* vala_symbol_resolver_resolve_symbol (ValaSymbolResolver* self
 			ValaSymbol* sym;
 			ValaScope* _tmp1;
 			ValaScope* scope;
-			ValaSymbol* _tmp18;
+			ValaSymbol* _tmp19;
 			sym = NULL;
 			_tmp1 = NULL;
 			scope = (_tmp1 = self->priv->current_scope, (_tmp1 == NULL) ? NULL : vala_scope_ref (_tmp1));
@@ -561,55 +592,62 @@ static ValaSymbol* vala_symbol_resolver_resolve_symbol (ValaSymbolResolver* self
 					_ns_it = gee_iterable_iterator ((GeeIterable*) self->priv->current_using_directives);
 					while (gee_iterator_next (_ns_it)) {
 						ValaUsingDirective* ns;
-						ValaSymbol* local_sym;
 						gboolean _tmp9;
+						ValaSymbol* local_sym;
 						gboolean _tmp10;
+						gboolean _tmp11;
 						ns = (ValaUsingDirective*) gee_iterator_get (_ns_it);
+						_tmp9 = FALSE;
 						if (vala_code_node_get_error ((ValaCodeNode*) ns)) {
+							_tmp9 = TRUE;
+						} else {
+							_tmp9 = VALA_IS_UNRESOLVED_SYMBOL (vala_using_directive_get_namespace_symbol (ns));
+						}
+						if (_tmp9) {
 							(ns == NULL) ? NULL : (ns = (vala_code_node_unref (ns), NULL));
 							continue;
 						}
 						local_sym = vala_scope_lookup (vala_symbol_get_scope (vala_using_directive_get_namespace_symbol (ns)), vala_symbol_get_name ((ValaSymbol*) unresolved_symbol));
-						_tmp9 = FALSE;
 						_tmp10 = FALSE;
+						_tmp11 = FALSE;
 						if (VALA_IS_NAMESPACE (local_sym)) {
+							_tmp11 = TRUE;
+						} else {
+							_tmp11 = VALA_IS_TYPESYMBOL (local_sym);
+						}
+						if (_tmp11) {
 							_tmp10 = TRUE;
 						} else {
-							_tmp10 = VALA_IS_TYPESYMBOL (local_sym);
-						}
-						if (_tmp10) {
-							_tmp9 = TRUE;
-						} else {
-							_tmp9 = VALA_IS_TYPEPARAMETER (sym);
+							_tmp10 = VALA_IS_TYPEPARAMETER (sym);
 						}
 						/* only look for types and type containers*/
-						if (!(_tmp9)) {
-							ValaSymbol* _tmp11;
-							_tmp11 = NULL;
-							local_sym = (_tmp11 = NULL, (local_sym == NULL) ? NULL : (local_sym = (vala_code_node_unref (local_sym), NULL)), _tmp11);
+						if (!(_tmp10)) {
+							ValaSymbol* _tmp12;
+							_tmp12 = NULL;
+							local_sym = (_tmp12 = NULL, (local_sym == NULL) ? NULL : (local_sym = (vala_code_node_unref (local_sym), NULL)), _tmp12);
 						}
 						if (local_sym != NULL) {
+							ValaSymbol* _tmp18;
 							ValaSymbol* _tmp17;
-							ValaSymbol* _tmp16;
 							if (sym != NULL) {
+								char* _tmp15;
 								char* _tmp14;
 								char* _tmp13;
-								char* _tmp12;
-								ValaSymbol* _tmp15;
+								ValaSymbol* _tmp16;
 								vala_code_node_set_error ((ValaCodeNode*) unresolved_symbol, TRUE);
+								_tmp15 = NULL;
 								_tmp14 = NULL;
 								_tmp13 = NULL;
-								_tmp12 = NULL;
-								vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) unresolved_symbol), _tmp14 = g_strdup_printf ("`%s' is an ambiguous reference between `%s' and `%s'", vala_symbol_get_name ((ValaSymbol*) unresolved_symbol), _tmp12 = vala_symbol_get_full_name (sym), _tmp13 = vala_symbol_get_full_name (local_sym)));
+								vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) unresolved_symbol), _tmp15 = g_strdup_printf ("`%s' is an ambiguous reference between `%s' and `%s'", vala_symbol_get_name ((ValaSymbol*) unresolved_symbol), _tmp13 = vala_symbol_get_full_name (sym), _tmp14 = vala_symbol_get_full_name (local_sym)));
+								_tmp15 = (g_free (_tmp15), NULL);
 								_tmp14 = (g_free (_tmp14), NULL);
 								_tmp13 = (g_free (_tmp13), NULL);
-								_tmp12 = (g_free (_tmp12), NULL);
-								_tmp15 = NULL;
-								return (_tmp15 = NULL, (ns == NULL) ? NULL : (ns = (vala_code_node_unref (ns), NULL)), (local_sym == NULL) ? NULL : (local_sym = (vala_code_node_unref (local_sym), NULL)), (_ns_it == NULL) ? NULL : (_ns_it = (gee_collection_object_unref (_ns_it), NULL)), (sym == NULL) ? NULL : (sym = (vala_code_node_unref (sym), NULL)), (scope == NULL) ? NULL : (scope = (vala_scope_unref (scope), NULL)), _tmp15);
+								_tmp16 = NULL;
+								return (_tmp16 = NULL, (ns == NULL) ? NULL : (ns = (vala_code_node_unref (ns), NULL)), (local_sym == NULL) ? NULL : (local_sym = (vala_code_node_unref (local_sym), NULL)), (_ns_it == NULL) ? NULL : (_ns_it = (gee_collection_object_unref (_ns_it), NULL)), (sym == NULL) ? NULL : (sym = (vala_code_node_unref (sym), NULL)), (scope == NULL) ? NULL : (scope = (vala_scope_unref (scope), NULL)), _tmp16);
 							}
+							_tmp18 = NULL;
 							_tmp17 = NULL;
-							_tmp16 = NULL;
-							sym = (_tmp17 = (_tmp16 = local_sym, (_tmp16 == NULL) ? NULL : vala_code_node_ref (_tmp16)), (sym == NULL) ? NULL : (sym = (vala_code_node_unref (sym), NULL)), _tmp17);
+							sym = (_tmp18 = (_tmp17 = local_sym, (_tmp17 == NULL) ? NULL : vala_code_node_ref (_tmp17)), (sym == NULL) ? NULL : (sym = (vala_code_node_unref (sym), NULL)), _tmp18);
 						}
 						(ns == NULL) ? NULL : (ns = (vala_code_node_unref (ns), NULL));
 						(local_sym == NULL) ? NULL : (local_sym = (vala_code_node_unref (local_sym), NULL));
@@ -617,24 +655,24 @@ static ValaSymbol* vala_symbol_resolver_resolve_symbol (ValaSymbolResolver* self
 					(_ns_it == NULL) ? NULL : (_ns_it = (gee_collection_object_unref (_ns_it), NULL));
 				}
 			}
-			_tmp18 = NULL;
-			return (_tmp18 = sym, (scope == NULL) ? NULL : (scope = (vala_scope_unref (scope), NULL)), _tmp18);
+			_tmp19 = NULL;
+			return (_tmp19 = sym, (scope == NULL) ? NULL : (scope = (vala_scope_unref (scope), NULL)), _tmp19);
 		} else {
 			ValaSymbol* parent_symbol;
-			ValaSymbol* _tmp21;
+			ValaSymbol* _tmp22;
 			parent_symbol = vala_symbol_resolver_resolve_symbol (self, vala_unresolved_symbol_get_inner (unresolved_symbol));
 			if (parent_symbol == NULL) {
-				char* _tmp19;
-				ValaSymbol* _tmp20;
+				char* _tmp20;
+				ValaSymbol* _tmp21;
 				vala_code_node_set_error ((ValaCodeNode*) unresolved_symbol, TRUE);
-				_tmp19 = NULL;
-				vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) vala_unresolved_symbol_get_inner (unresolved_symbol)), _tmp19 = g_strdup_printf ("The symbol `%s' could not be found", vala_symbol_get_name ((ValaSymbol*) vala_unresolved_symbol_get_inner (unresolved_symbol))));
-				_tmp19 = (g_free (_tmp19), NULL);
 				_tmp20 = NULL;
-				return (_tmp20 = NULL, (parent_symbol == NULL) ? NULL : (parent_symbol = (vala_code_node_unref (parent_symbol), NULL)), _tmp20);
+				vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) vala_unresolved_symbol_get_inner (unresolved_symbol)), _tmp20 = g_strdup_printf ("The symbol `%s' could not be found", vala_symbol_get_name ((ValaSymbol*) vala_unresolved_symbol_get_inner (unresolved_symbol))));
+				_tmp20 = (g_free (_tmp20), NULL);
+				_tmp21 = NULL;
+				return (_tmp21 = NULL, (parent_symbol == NULL) ? NULL : (parent_symbol = (vala_code_node_unref (parent_symbol), NULL)), _tmp21);
 			}
-			_tmp21 = NULL;
-			return (_tmp21 = vala_scope_lookup (vala_symbol_get_scope (parent_symbol), vala_symbol_get_name ((ValaSymbol*) unresolved_symbol)), (parent_symbol == NULL) ? NULL : (parent_symbol = (vala_code_node_unref (parent_symbol), NULL)), _tmp21);
+			_tmp22 = NULL;
+			return (_tmp22 = vala_scope_lookup (vala_symbol_get_scope (parent_symbol), vala_symbol_get_name ((ValaSymbol*) unresolved_symbol)), (parent_symbol == NULL) ? NULL : (parent_symbol = (vala_code_node_unref (parent_symbol), NULL)), _tmp22);
 		}
 	}
 }
@@ -643,7 +681,7 @@ static ValaSymbol* vala_symbol_resolver_resolve_symbol (ValaSymbolResolver* self
 static ValaDataType* vala_symbol_resolver_resolve_type (ValaSymbolResolver* self, ValaUnresolvedType* unresolved_type) {
 	ValaDataType* type;
 	ValaSymbol* sym;
-	ValaDataType* _tmp22;
+	ValaDataType* _tmp26;
 	g_return_val_if_fail (self != NULL, NULL);
 	g_return_val_if_fail (unresolved_type != NULL, NULL);
 	type = NULL;
@@ -651,7 +689,7 @@ static ValaDataType* vala_symbol_resolver_resolve_type (ValaSymbolResolver* self
 	if (_vala_strcmp0 (vala_symbol_get_name ((ValaSymbol*) vala_unresolved_type_get_unresolved_symbol (unresolved_type)), "void") == 0) {
 		ValaDataType* _tmp0;
 		_tmp0 = NULL;
-		return (_tmp0 = (ValaDataType*) vala_void_type_new (), (type == NULL) ? NULL : (type = (vala_code_node_unref (type), NULL)), _tmp0);
+		return (_tmp0 = (ValaDataType*) vala_void_type_new (NULL), (type == NULL) ? NULL : (type = (vala_code_node_unref (type), NULL)), _tmp0);
 	}
 	sym = vala_symbol_resolver_resolve_symbol (self, vala_unresolved_type_get_unresolved_symbol (unresolved_type));
 	if (sym == NULL) {
@@ -702,35 +740,58 @@ static ValaDataType* vala_symbol_resolver_resolve_type (ValaSymbolResolver* self
 						type = (_tmp9 = (ValaDataType*) vala_object_type_new ((ValaObjectTypeSymbol*) VALA_INTERFACE (sym)), (type == NULL) ? NULL : (type = (vala_code_node_unref (type), NULL)), _tmp9);
 					} else {
 						if (VALA_IS_STRUCT (sym)) {
-							ValaDataType* _tmp10;
+							ValaStruct* _tmp10;
+							ValaStruct* st;
 							_tmp10 = NULL;
-							type = (_tmp10 = (ValaDataType*) vala_value_type_new ((ValaTypeSymbol*) VALA_STRUCT (sym)), (type == NULL) ? NULL : (type = (vala_code_node_unref (type), NULL)), _tmp10);
-						} else {
-							if (VALA_IS_ENUM (sym)) {
+							st = (_tmp10 = VALA_STRUCT (sym), (_tmp10 == NULL) ? NULL : vala_code_node_ref (_tmp10));
+							if (vala_struct_is_boolean_type (st)) {
 								ValaDataType* _tmp11;
 								_tmp11 = NULL;
-								type = (_tmp11 = (ValaDataType*) vala_value_type_new ((ValaTypeSymbol*) VALA_ENUM (sym)), (type == NULL) ? NULL : (type = (vala_code_node_unref (type), NULL)), _tmp11);
+								type = (_tmp11 = (ValaDataType*) vala_boolean_type_new (st), (type == NULL) ? NULL : (type = (vala_code_node_unref (type), NULL)), _tmp11);
 							} else {
-								if (VALA_IS_ERROR_DOMAIN (sym)) {
+								if (vala_struct_is_integer_type (st)) {
 									ValaDataType* _tmp12;
 									_tmp12 = NULL;
-									type = (_tmp12 = (ValaDataType*) vala_error_type_new (VALA_ERROR_DOMAIN (sym), NULL, vala_code_node_get_source_reference ((ValaCodeNode*) unresolved_type)), (type == NULL) ? NULL : (type = (vala_code_node_unref (type), NULL)), _tmp12);
+									type = (_tmp12 = (ValaDataType*) vala_integer_type_new (st, NULL, NULL), (type == NULL) ? NULL : (type = (vala_code_node_unref (type), NULL)), _tmp12);
 								} else {
-									if (VALA_IS_ERROR_CODE (sym)) {
+									if (vala_struct_is_floating_type (st)) {
 										ValaDataType* _tmp13;
 										_tmp13 = NULL;
-										type = (_tmp13 = (ValaDataType*) vala_error_type_new (VALA_ERROR_DOMAIN (vala_symbol_get_parent_symbol (sym)), VALA_ERROR_CODE (sym), vala_code_node_get_source_reference ((ValaCodeNode*) unresolved_type)), (type == NULL) ? NULL : (type = (vala_code_node_unref (type), NULL)), _tmp13);
+										type = (_tmp13 = (ValaDataType*) vala_floating_type_new (st), (type == NULL) ? NULL : (type = (vala_code_node_unref (type), NULL)), _tmp13);
 									} else {
-										char* _tmp15;
-										char* _tmp14;
-										ValaDataType* _tmp16;
-										_tmp15 = NULL;
+										ValaDataType* _tmp14;
 										_tmp14 = NULL;
-										vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) unresolved_type), _tmp15 = g_strdup_printf ("internal error: `%s' is not a supported type", _tmp14 = vala_symbol_get_full_name (sym)));
-										_tmp15 = (g_free (_tmp15), NULL);
-										_tmp14 = (g_free (_tmp14), NULL);
-										_tmp16 = NULL;
-										return (_tmp16 = (ValaDataType*) vala_invalid_type_new (), (type == NULL) ? NULL : (type = (vala_code_node_unref (type), NULL)), (sym == NULL) ? NULL : (sym = (vala_code_node_unref (sym), NULL)), _tmp16);
+										type = (_tmp14 = (ValaDataType*) vala_struct_value_type_new (st), (type == NULL) ? NULL : (type = (vala_code_node_unref (type), NULL)), _tmp14);
+									}
+								}
+							}
+							(st == NULL) ? NULL : (st = (vala_code_node_unref (st), NULL));
+						} else {
+							if (VALA_IS_ENUM (sym)) {
+								ValaDataType* _tmp15;
+								_tmp15 = NULL;
+								type = (_tmp15 = (ValaDataType*) vala_enum_value_type_new (VALA_ENUM (sym)), (type == NULL) ? NULL : (type = (vala_code_node_unref (type), NULL)), _tmp15);
+							} else {
+								if (VALA_IS_ERROR_DOMAIN (sym)) {
+									ValaDataType* _tmp16;
+									_tmp16 = NULL;
+									type = (_tmp16 = (ValaDataType*) vala_error_type_new (VALA_ERROR_DOMAIN (sym), NULL, vala_code_node_get_source_reference ((ValaCodeNode*) unresolved_type)), (type == NULL) ? NULL : (type = (vala_code_node_unref (type), NULL)), _tmp16);
+								} else {
+									if (VALA_IS_ERROR_CODE (sym)) {
+										ValaDataType* _tmp17;
+										_tmp17 = NULL;
+										type = (_tmp17 = (ValaDataType*) vala_error_type_new (VALA_ERROR_DOMAIN (vala_symbol_get_parent_symbol (sym)), VALA_ERROR_CODE (sym), vala_code_node_get_source_reference ((ValaCodeNode*) unresolved_type)), (type == NULL) ? NULL : (type = (vala_code_node_unref (type), NULL)), _tmp17);
+									} else {
+										char* _tmp19;
+										char* _tmp18;
+										ValaDataType* _tmp20;
+										_tmp19 = NULL;
+										_tmp18 = NULL;
+										vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) unresolved_type), _tmp19 = g_strdup_printf ("internal error: `%s' is not a supported type", _tmp18 = vala_symbol_get_full_name (sym)));
+										_tmp19 = (g_free (_tmp19), NULL);
+										_tmp18 = (g_free (_tmp18), NULL);
+										_tmp20 = NULL;
+										return (_tmp20 = (ValaDataType*) vala_invalid_type_new (), (type == NULL) ? NULL : (type = (vala_code_node_unref (type), NULL)), (sym == NULL) ? NULL : (sym = (vala_code_node_unref (sym), NULL)), _tmp20);
 									}
 								}
 							}
@@ -739,16 +800,16 @@ static ValaDataType* vala_symbol_resolver_resolve_type (ValaSymbolResolver* self
 				}
 			}
 		} else {
-			char* _tmp18;
-			char* _tmp17;
-			ValaDataType* _tmp19;
-			_tmp18 = NULL;
-			_tmp17 = NULL;
-			vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) unresolved_type), _tmp18 = g_strdup_printf ("`%s' is not a type", _tmp17 = vala_symbol_get_full_name (sym)));
-			_tmp18 = (g_free (_tmp18), NULL);
-			_tmp17 = (g_free (_tmp17), NULL);
-			_tmp19 = NULL;
-			return (_tmp19 = (ValaDataType*) vala_invalid_type_new (), (type == NULL) ? NULL : (type = (vala_code_node_unref (type), NULL)), (sym == NULL) ? NULL : (sym = (vala_code_node_unref (sym), NULL)), _tmp19);
+			char* _tmp22;
+			char* _tmp21;
+			ValaDataType* _tmp23;
+			_tmp22 = NULL;
+			_tmp21 = NULL;
+			vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) unresolved_type), _tmp22 = g_strdup_printf ("`%s' is not a type", _tmp21 = vala_symbol_get_full_name (sym)));
+			_tmp22 = (g_free (_tmp22), NULL);
+			_tmp21 = (g_free (_tmp21), NULL);
+			_tmp23 = NULL;
+			return (_tmp23 = (ValaDataType*) vala_invalid_type_new (), (type == NULL) ? NULL : (type = (vala_code_node_unref (type), NULL)), (sym == NULL) ? NULL : (sym = (vala_code_node_unref (sym), NULL)), _tmp23);
 		}
 	}
 	vala_code_node_set_source_reference ((ValaCodeNode*) type, vala_code_node_get_source_reference ((ValaCodeNode*) unresolved_type));
@@ -762,12 +823,12 @@ static ValaDataType* vala_symbol_resolver_resolve_type (ValaSymbolResolver* self
 	}
 	vala_data_type_set_is_dynamic (type, vala_data_type_get_is_dynamic ((ValaDataType*) unresolved_type));
 	{
-		GeeList* _tmp20;
-		GeeIterator* _tmp21;
+		GeeList* _tmp24;
+		GeeIterator* _tmp25;
 		GeeIterator* _type_arg_it;
-		_tmp20 = NULL;
-		_tmp21 = NULL;
-		_type_arg_it = (_tmp21 = gee_iterable_iterator ((GeeIterable*) (_tmp20 = vala_data_type_get_type_arguments ((ValaDataType*) unresolved_type))), (_tmp20 == NULL) ? NULL : (_tmp20 = (gee_collection_object_unref (_tmp20), NULL)), _tmp21);
+		_tmp24 = NULL;
+		_tmp25 = NULL;
+		_type_arg_it = (_tmp25 = gee_iterable_iterator ((GeeIterable*) (_tmp24 = vala_data_type_get_type_arguments ((ValaDataType*) unresolved_type))), (_tmp24 == NULL) ? NULL : (_tmp24 = (gee_collection_object_unref (_tmp24), NULL)), _tmp25);
 		while (gee_iterator_next (_type_arg_it)) {
 			ValaDataType* type_arg;
 			type_arg = (ValaDataType*) gee_iterator_get (_type_arg_it);
@@ -776,8 +837,8 @@ static ValaDataType* vala_symbol_resolver_resolve_type (ValaSymbolResolver* self
 		}
 		(_type_arg_it == NULL) ? NULL : (_type_arg_it = (gee_collection_object_unref (_type_arg_it), NULL));
 	}
-	_tmp22 = NULL;
-	return (_tmp22 = type, (sym == NULL) ? NULL : (sym = (vala_code_node_unref (sym), NULL)), _tmp22);
+	_tmp26 = NULL;
+	return (_tmp26 = type, (sym == NULL) ? NULL : (sym = (vala_code_node_unref (sym), NULL)), _tmp26);
 }
 
 
