@@ -21,6 +21,7 @@
  */
 
 #include <vala/valavoidtype.h>
+#include <vala/valacodenode.h>
 
 
 
@@ -32,25 +33,27 @@ static gboolean vala_void_type_real_stricter (ValaDataType* base, ValaDataType*
 static char* vala_void_type_real_to_qualified_string (ValaDataType* base, ValaScope* scope);
 static char* vala_void_type_real_get_cname (ValaDataType* base);
 static ValaDataType* vala_void_type_real_copy (ValaDataType* base);
+static char* vala_void_type_real_get_type_id (ValaDataType* base);
 static gpointer vala_void_type_parent_class = NULL;
 
 
 
-ValaVoidType* vala_void_type_construct (GType object_type) {
+ValaVoidType* vala_void_type_construct (GType object_type, ValaSourceReference* source_reference) {
 	ValaVoidType* self;
-	self = ((ValaVoidType*) (g_type_create_instance (object_type)));
+	self = (ValaVoidType*) g_type_create_instance (object_type);
+	vala_code_node_set_source_reference ((ValaCodeNode*) self, source_reference);
 	return self;
 }
 
 
-ValaVoidType* vala_void_type_new (void) {
-	return vala_void_type_construct (VALA_TYPE_VOID_TYPE);
+ValaVoidType* vala_void_type_new (ValaSourceReference* source_reference) {
+	return vala_void_type_construct (VALA_TYPE_VOID_TYPE, source_reference);
 }
 
 
 static gboolean vala_void_type_real_stricter (ValaDataType* base, ValaDataType* type2) {
 	ValaVoidType * self;
-	self = ((ValaVoidType*) (base));
+	self = (ValaVoidType*) base;
 	g_return_val_if_fail (type2 != NULL, FALSE);
 	return (VALA_IS_VOID_TYPE (type2));
 }
@@ -58,22 +61,29 @@ static gboolean vala_void_type_real_stricter (ValaDataType* base, ValaDataType*
 
 static char* vala_void_type_real_to_qualified_string (ValaDataType* base, ValaScope* scope) {
 	ValaVoidType * self;
-	self = ((ValaVoidType*) (base));
+	self = (ValaVoidType*) base;
 	return g_strdup ("void");
 }
 
 
 static char* vala_void_type_real_get_cname (ValaDataType* base) {
 	ValaVoidType * self;
-	self = ((ValaVoidType*) (base));
+	self = (ValaVoidType*) base;
 	return g_strdup ("void");
 }
 
 
 static ValaDataType* vala_void_type_real_copy (ValaDataType* base) {
 	ValaVoidType * self;
-	self = ((ValaVoidType*) (base));
-	return ((ValaDataType*) (vala_void_type_new ()));
+	self = (ValaVoidType*) base;
+	return (ValaDataType*) vala_void_type_new (vala_code_node_get_source_reference ((ValaCodeNode*) self));
+}
+
+
+static char* vala_void_type_real_get_type_id (ValaDataType* base) {
+	ValaVoidType * self;
+	self = (ValaVoidType*) base;
+	return g_strdup ("G_TYPE_NONE");
 }
 
 
@@ -83,6 +93,7 @@ static void vala_void_type_class_init (ValaVoidTypeClass * klass) {
 	VALA_DATA_TYPE_CLASS (klass)->to_qualified_string = vala_void_type_real_to_qualified_string;
 	VALA_DATA_TYPE_CLASS (klass)->get_cname = vala_void_type_real_get_cname;
 	VALA_DATA_TYPE_CLASS (klass)->copy = vala_void_type_real_copy;
+	VALA_DATA_TYPE_CLASS (klass)->get_type_id = vala_void_type_real_get_type_id;
 }
 
 
