@@ -28,6 +28,7 @@
 #include <stdlib.h>
 #include <string.h>
 #include <vala/valadatatype.h>
+#include <vala/valasourcereference.h>
 #include <vala/valascope.h>
 
 G_BEGIN_DECLS
@@ -57,8 +58,8 @@ struct _ValaVoidTypeClass {
 };
 
 
-ValaVoidType* vala_void_type_construct (GType object_type);
-ValaVoidType* vala_void_type_new (void);
+ValaVoidType* vala_void_type_construct (GType object_type, ValaSourceReference* source_reference);
+ValaVoidType* vala_void_type_new (ValaSourceReference* source_reference);
 GType vala_void_type_get_type (void);
 
 
