@@ -47,11 +47,15 @@ struct _ValaWhileStatement {
 	ValaCodeNode parent_instance;
 	ValaWhileStatementPrivate * priv;
 };
+
 struct _ValaWhileStatementClass {
 	ValaCodeNodeClass parent_class;
 };
 
+
+ValaWhileStatement* vala_while_statement_construct (GType object_type, ValaExpression* condition, ValaBlock* body, ValaSourceReference* source_reference);
 ValaWhileStatement* vala_while_statement_new (ValaExpression* condition, ValaBlock* body, ValaSourceReference* source_reference);
+ValaBlock* vala_while_statement_prepare_condition_split (ValaWhileStatement* self, ValaSemanticAnalyzer* analyzer);
 ValaExpression* vala_while_statement_get_condition (ValaWhileStatement* self);
 void vala_while_statement_set_condition (ValaWhileStatement* self, ValaExpression* value);
 ValaBlock* vala_while_statement_get_body (ValaWhileStatement* self);
