@@ -1,6 +1,6 @@
 /* valamarkupreader.vala
  *
- * Copyright (C) 2008  Jürg Billeter
+ * Copyright (C) 2008-2009  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -87,7 +87,7 @@ ValaMarkupReader* vala_markup_reader_new (const char* filename) {
 char* vala_markup_reader_get_attribute (ValaMarkupReader* self, const char* attr) {
 	g_return_val_if_fail (self != NULL, NULL);
 	g_return_val_if_fail (attr != NULL, NULL);
-	return (char*) gee_map_get ((GeeMap*) self->priv->attributes, attr);
+	return (char*) gee_map_get (self->priv->attributes, attr);
 }
 
 
@@ -160,111 +160,152 @@ ValaMarkupTokenType vala_markup_reader_read_token (ValaMarkupReader* self, ValaS
 				if (self->priv->current[0] == '?') {
 				} else {
 					if (self->priv->current[0] == '!') {
+						gboolean _tmp1;
+						gboolean _tmp2;
+						/* comment or doctype*/
+						self->priv->current++;
+						_tmp1 = FALSE;
+						_tmp2 = FALSE;
+						if (self->priv->current < (self->priv->end - 1)) {
+							_tmp2 = self->priv->current[0] == '-';
+						} else {
+							_tmp2 = FALSE;
+						}
+						if (_tmp2) {
+							_tmp1 = self->priv->current[1] == '-';
+						} else {
+							_tmp1 = FALSE;
+						}
+						if (_tmp1) {
+							/* comment*/
+							self->priv->current = self->priv->current + (2);
+							while (self->priv->current < (self->priv->end - 2)) {
+								gboolean _tmp3;
+								gboolean _tmp4;
+								_tmp3 = FALSE;
+								_tmp4 = FALSE;
+								if (self->priv->current[0] == '-') {
+									_tmp4 = self->priv->current[1] == '-';
+								} else {
+									_tmp4 = FALSE;
+								}
+								if (_tmp4) {
+									_tmp3 = self->priv->current[2] == '>';
+								} else {
+									_tmp3 = FALSE;
+								}
+								if (_tmp3) {
+									/* end of comment*/
+									self->priv->current = self->priv->current + (3);
+									break;
+								}
+								self->priv->current++;
+							}
+							/* ignore comment, read next token*/
+							return vala_markup_reader_read_token (self, &(*token_begin), &(*token_end));
+						}
 					} else {
 						if (self->priv->current[0] == '/') {
-							char* _tmp1;
-							gboolean _tmp2;
+							char* _tmp6;
+							gboolean _tmp7;
 							type = VALA_MARKUP_TOKEN_TYPE_END_ELEMENT;
 							self->priv->current++;
-							_tmp1 = NULL;
-							vala_markup_reader_set_name (self, _tmp1 = vala_markup_reader_read_name (self));
-							_tmp1 = (g_free (_tmp1), NULL);
-							_tmp2 = FALSE;
+							_tmp6 = NULL;
+							vala_markup_reader_set_name (self, _tmp6 = vala_markup_reader_read_name (self));
+							_tmp6 = (g_free (_tmp6), NULL);
+							_tmp7 = FALSE;
 							if (self->priv->current >= self->priv->end) {
-								_tmp2 = TRUE;
+								_tmp7 = TRUE;
 							} else {
-								_tmp2 = self->priv->current[0] != '>';
+								_tmp7 = self->priv->current[0] != '>';
 							}
-							if (_tmp2) {
+							if (_tmp7) {
 							}
 							/* error*/
 							self->priv->current++;
 						} else {
-							char* _tmp3;
-							gboolean _tmp10;
+							char* _tmp8;
+							gboolean _tmp15;
 							type = VALA_MARKUP_TOKEN_TYPE_START_ELEMENT;
-							_tmp3 = NULL;
-							vala_markup_reader_set_name (self, _tmp3 = vala_markup_reader_read_name (self));
-							_tmp3 = (g_free (_tmp3), NULL);
+							_tmp8 = NULL;
+							vala_markup_reader_set_name (self, _tmp8 = vala_markup_reader_read_name (self));
+							_tmp8 = (g_free (_tmp8), NULL);
 							vala_markup_reader_space (self);
 							while (TRUE) {
-								gboolean _tmp4;
-								gboolean _tmp5;
+								gboolean _tmp9;
+								gboolean _tmp10;
 								char* attr_name;
-								gboolean _tmp6;
-								gboolean _tmp7;
+								gboolean _tmp11;
+								gboolean _tmp12;
 								gchar* attr_begin;
 								char* attr_value;
-								gboolean _tmp9;
-								_tmp4 = FALSE;
-								_tmp5 = FALSE;
+								gboolean _tmp14;
+								_tmp9 = FALSE;
+								_tmp10 = FALSE;
 								if (self->priv->current < self->priv->end) {
-									_tmp5 = self->priv->current[0] != '>';
+									_tmp10 = self->priv->current[0] != '>';
 								} else {
-									_tmp5 = FALSE;
+									_tmp10 = FALSE;
 								}
-								if (_tmp5) {
-									_tmp4 = self->priv->current[0] != '/';
+								if (_tmp10) {
+									_tmp9 = self->priv->current[0] != '/';
 								} else {
-									_tmp4 = FALSE;
+									_tmp9 = FALSE;
 								}
-								if (!_tmp4) {
+								if (!_tmp9) {
 									break;
 								}
 								attr_name = vala_markup_reader_read_name (self);
-								_tmp6 = FALSE;
+								_tmp11 = FALSE;
 								if (self->priv->current >= self->priv->end) {
-									_tmp6 = TRUE;
+									_tmp11 = TRUE;
 								} else {
-									_tmp6 = self->priv->current[0] != '=';
+									_tmp11 = self->priv->current[0] != '=';
 								}
-								if (_tmp6) {
+								if (_tmp11) {
 								}
 								/* error*/
 								self->priv->current++;
-								_tmp7 = FALSE;
+								_tmp12 = FALSE;
 								if (self->priv->current >= self->priv->end) {
-									_tmp7 = TRUE;
+									_tmp12 = TRUE;
 								} else {
-									_tmp7 = self->priv->current[0] != '"';
+									_tmp12 = self->priv->current[0] != '"';
 								}
 								/* FIXME allow single quotes*/
-								if (_tmp7) {
+								if (_tmp12) {
 								}
 								/* error*/
 								self->priv->current++;
 								attr_begin = self->priv->current;
 								while (TRUE) {
-									gboolean _tmp8;
-									_tmp8 = FALSE;
+									gboolean _tmp13;
+									gunichar u;
+									_tmp13 = FALSE;
 									if (self->priv->current < self->priv->end) {
-										_tmp8 = self->priv->current[0] != '"';
+										_tmp13 = self->priv->current[0] != '"';
 									} else {
-										_tmp8 = FALSE;
+										_tmp13 = FALSE;
 									}
-									if (!_tmp8) {
+									if (!_tmp13) {
 										break;
 									}
-									if (self->priv->current[0] == '&') {
+									u = g_utf8_get_char_validated (((const char*) self->priv->current), (glong) (self->priv->end - self->priv->current));
+									if (u != ((gunichar) (-1))) {
+										self->priv->current = self->priv->current + (g_unichar_to_utf8 (u, NULL));
 									} else {
-										gunichar u;
-										/* process &amp; &gt; &lt; &quot; &apos;*/
-										u = g_utf8_get_char_validated (((const char*) self->priv->current), (glong) (self->priv->end - self->priv->current));
-										if (u != ((gunichar) (-1))) {
-											self->priv->current = self->priv->current + (g_unichar_to_utf8 (u, NULL));
-										} else {
-											vala_report_error (NULL, "invalid UTF-8 character");
-										}
+										vala_report_error (NULL, "invalid UTF-8 character");
 									}
 								}
+								/* TODO process &amp; &gt; &lt; &quot; &apos;*/
 								attr_value = g_strndup (((const char*) attr_begin), self->priv->current - attr_begin);
-								_tmp9 = FALSE;
+								_tmp14 = FALSE;
 								if (self->priv->current >= self->priv->end) {
-									_tmp9 = TRUE;
+									_tmp14 = TRUE;
 								} else {
-									_tmp9 = self->priv->current[0] != '"';
+									_tmp14 = self->priv->current[0] != '"';
 								}
-								if (_tmp9) {
+								if (_tmp14) {
 								}
 								/* error*/
 								self->priv->current++;
@@ -280,13 +321,13 @@ ValaMarkupTokenType vala_markup_reader_read_token (ValaMarkupReader* self, ValaS
 							} else {
 								self->priv->empty_element = FALSE;
 							}
-							_tmp10 = FALSE;
+							_tmp15 = FALSE;
 							if (self->priv->current >= self->priv->end) {
-								_tmp10 = TRUE;
+								_tmp15 = TRUE;
 							} else {
-								_tmp10 = self->priv->current[0] != '>';
+								_tmp15 = self->priv->current[0] != '>';
 							}
-							if (_tmp10) {
+							if (_tmp15) {
 							}
 							/* error*/
 							self->priv->current++;
@@ -299,26 +340,22 @@ ValaMarkupTokenType vala_markup_reader_read_token (ValaMarkupReader* self, ValaS
 			vala_markup_reader_space (self);
 			text_begin = self->priv->current;
 			while (TRUE) {
-				gboolean _tmp11;
-				_tmp11 = FALSE;
+				gboolean _tmp16;
+				gunichar u;
+				_tmp16 = FALSE;
 				if (self->priv->current < self->priv->end) {
-					_tmp11 = self->priv->current[0] != '<';
+					_tmp16 = self->priv->current[0] != '<';
 				} else {
-					_tmp11 = FALSE;
+					_tmp16 = FALSE;
 				}
-				if (!_tmp11) {
+				if (!_tmp16) {
 					break;
 				}
-				if (self->priv->current[0] == '&') {
+				u = g_utf8_get_char_validated (((const char*) self->priv->current), (glong) (self->priv->end - self->priv->current));
+				if (u != ((gunichar) (-1))) {
+					self->priv->current = self->priv->current + (g_unichar_to_utf8 (u, NULL));
 				} else {
-					gunichar u;
-					/* process &amp; &gt; &lt; &quot; &apos;*/
-					u = g_utf8_get_char_validated (((const char*) self->priv->current), (glong) (self->priv->end - self->priv->current));
-					if (u != ((gunichar) (-1))) {
-						self->priv->current = self->priv->current + (g_unichar_to_utf8 (u, NULL));
-					} else {
-						vala_report_error (NULL, "invalid UTF-8 character");
-					}
+					vala_report_error (NULL, "invalid UTF-8 character");
 				}
 			}
 			if (text_begin == self->priv->current) {
@@ -329,7 +366,8 @@ ValaMarkupTokenType vala_markup_reader_read_token (ValaMarkupReader* self, ValaS
 			type = VALA_MARKUP_TOKEN_TYPE_TEXT;
 		}
 	}
-	/* string text = ((string) text_begin).ndup (current - text_begin);*/
+	/* TODO process &amp; &gt; &lt; &quot; &apos;
+	 string text = ((string) text_begin).ndup (current - text_begin);*/
 	self->priv->column = self->priv->column + ((gint) (self->priv->current - begin));
 	(*token_end).pos = self->priv->current;
 	(*token_end).line = self->priv->line;
@@ -415,8 +453,7 @@ static GObject * vala_markup_reader_constructor (GType type, guint n_construct_p
 				if (inner_error->domain == G_FILE_ERROR) {
 					goto __catch3_g_file_error;
 				}
-				g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, inner_error->message);
-				g_clear_error (&inner_error);
+				goto __finally3;
 			}
 			self->priv->begin = g_mapped_file_get_contents (self->priv->mapped_file);
 			self->priv->end = self->priv->begin + g_mapped_file_get_length (self->priv->mapped_file);
@@ -439,7 +476,10 @@ static GObject * vala_markup_reader_constructor (GType type, guint n_construct_p
 			}
 		}
 		__finally3:
-		;
+		if (inner_error != NULL) {
+			g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, inner_error->message);
+			g_clear_error (&inner_error);
+		}
 	}
 	return obj;
 }
@@ -447,6 +487,7 @@ static GObject * vala_markup_reader_constructor (GType type, guint n_construct_p
 
 static void vala_markup_reader_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	ValaMarkupReader * self;
+	gpointer boxed;
 	self = VALA_MARKUP_READER (object);
 	switch (property_id) {
 		case VALA_MARKUP_READER_FILENAME:
