@@ -254,7 +254,7 @@ static void vala_vapi_check_add_symbol (ValaVAPICheck* self, const char* name, c
 
 static char* vala_vapi_check_get_scope (ValaVAPICheck* self) {
 	g_return_val_if_fail (self != NULL, NULL);
-	return (char*) gee_list_get ((GeeList*) self->priv->_scope, gee_collection_get_size ((GeeCollection*) self->priv->_scope) - 1);
+	return (char*) gee_list_get (self->priv->_scope, gee_collection_get_size ((GeeCollection*) self->priv->_scope) - 1);
 }
 
 
